function sigSum = addsig(sig1, sig2)

%ADDSIG Adds two radar signals.
%
%--------
%Synopsis:
%  sigSum = addsig(sig1, sig2)
%
%Description:
%  Adds two radar signals. First, it copies the fields of "sig1" to the
%  output signal "sigSum" and then adds the "signals" field of "sig2" to
%  the "signals" field of "sigSum".
%
%Output and Input:
%  sigSum (RxRadarSigT): Output radar signal.
%  sig1 (RxRadarSigT): First input radar signal. The fields of this radar signal
%    will be retained in the output radar signal "sigSum".
%  sig2 (RxRadarSigT): Second input radar signal.
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 980525 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:19:57 $ $Author: svabj $.
%  $Revision: 1.5 $
% *****************************************************************************

sigSum = sig1;
sigSum.signals = sig1.signals + sig2.signals;
