function b = aic(Rx,plotopt)

% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  function b = aic(Rx)
%
%  Estimates the number of signals using An Information Criterion (AIC).
%
%  b (IntScalarT): Estimated number of signals.
%  Rx (RxCorrMatT): Correlation matrix data.
%  plotopt (StringT): Plot option:
%    = 'plot': Plots a bar plot of the AIC function.
%
%  Start        : 961120 Fredrik Athley (freath).
%  Latest change: $Date: 2000/10/16 15:19:58 $ $Author: svabj $.
%  $Revision: 1.9 $
% *****************************************************************************
if nargin<2
  plotopt =  [];
end

chkdtype(Rx, 'RxCorrMatT');
R = Rx.corrMat;
N = Rx.noSamples;	% Number of samples or snapshots used to estimate
  			% the correlation matrix.
[u,s,v] = svd(R);
K = size(R,1);		% Number of antenna channels.
egv = diag(s);
a = zeros(1,K);
for m=0:K-1
  negv = egv(m+1:K);
  Tsph = mean(negv)/((prod(negv))^(1/(K-m)));
  a(m+1) = N*(K-m)*log(Tsph) + m*(2*K-m);
end
[y,b] = min(a);
%K
b = b - 1;
if strcmp(plotopt,'plot')
  bar(0:K-1,10*log10(a));
  title('AIC function');xmin(-1);grid on;
  xlabel('number of signals');ylabel('[dB]')
end
