function antenna = defaimtexant2hlp(posErr, subArrWeights)

%DEFAIMTEXANT2HLP Definition of the receiving antenna in the AIMT application example.
%  Kernel function.
%
%  posErr (Vector of PosT): Position errors [m] for the 51 elements.
%    Size = (1 X 51).
%  subArrWeights (CxMatrixT):
%

%
%     *    DBT, A Matlab Toolbox for Radar Signal Processing    *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%    Start        : 98xxxx Svante Bjrklund (svabj).
%    Latest change: $Date: 2000/10/16 15:39:19 $ $Author: svabj $.
%    $Revision: 1.4 $
% *****************************************************************************


  % -------  Extend the positioning errors with y and z coordinates.  -------
  noElem = 51;
  posErrUse = zeros(3,noElem);
  posErrUse(1:size(posErr,1),:) = posErr;

  % -------  Create antenna elements. -------
  nElem = 51;
  elem21 = defant('pattFuncElem', 'sqrt(cos(x(1,:)))');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n
  %elem2 = repmat({},1,nElem);	% Alternative way to create elem2.

  % -------  Create beamforming matrix to do subarray beamforming.  -------
  T = zeros(nElem,25);
  for n=1:25
    T((2*n-1):(2*n-1)+2,n) = subArrWeights;
  end%for n
  elemPos = [[0:0.5:25]*0.1; zeros(2,51)] + posErrUse;
  antenna = defant('BFArray',elemPos,[],elem2,T);

