function sigOut = aimtexfa2dbt(sigFa, noRangeBins, noPulses, noCPI, pulsecode, lambda)

%AIMTEXFA2DBT Converts a radar signal for the aimtEx radar system from FA data format to DBT format.
%
%--------
%Synopsis:
%  sigOut = aimtexfa2dbt(sigFa, noRangeBins, noPulses, noCPI, pulsecode, lambda)
%
%Description:
%  Converts a radar signal for the aimtEx radar system from FA's data
%  format to DBT format.
%
%Output and Input:
%  sigOut (RxRadarSigT): Output radar signal in DBT format.
%  sigFa (CxMultiMatrixT): Input radar signal matrix. XX(space,pulse,range,cpi).
%  noRangeBins (IntScalarT):
%  noPulses (IntScalarT):
%  noCPI (IntScalarT):
%  pulsecode (CxVectorT):
%  lambda (RealScalarT):
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%  This function is not tested yet.
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  simsig2

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 981112 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:31 $ $Author: svabj $.
%  $Revision: 1.3 $
% *****************************************************************************

%lambda = 0.1;	% Wavelength [m]
sampleTime = 1e-6;   % SubPulseLength [s].

waveform = defwave(lambda, noRangeBins, noPulses, pulsecode, sampleTime,noCPI);
antenna = defant('aimtEx');

shiftStep = -1;
sigOut = RxRadarSigT(permute(shiftdim(sigFa,shiftStep),[2,3,1,0,4]-shiftStep), { antenna, waveform});
