function sig = crbsto(antenna,doas,S,N,lambda)
% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  function sig = crbsto(antenna,theta,S,N,lambda)
%
%  Computes the Stochastic Cramer-Rao Bound
%
%  sig      RealVectorT CRB, standard deviations [radians]
%  antenna  AntDefT
%  doas     Vector of DoaT  Directions of arrival
%  S     RealMatrixT Source signal covariance matrix
%  N     IntScalarT  Number of snapshots
%  lambda       RealScalarT     Wavelength [m].

%  Start        : 961120 Fredrik Athley (freath).
%  Latest change: $Date: 2000/10/16 15:20:18 $ $Author: svabj $.
%  $Revision: 1.9 $
% *****************************************************************************

%lambda =   antenna.lambda;
K =      antenna.noElem;

A = spastemat(antenna,doas,lambda);
D = dspastemat(antenna,doas,lambda);
[m,n] = size(A);
[Q,R] = qr(A);
Q2 = Q(:,n+1:m);
Paperp = Q2*Q2';
R = A*S*A' + eye(K);
B = sqrt(1/(2*N)*inv(real((D'*Paperp*D).*(S*A'*inv(R)*A*S).')));
sig = diag(B)';


