function dbcfileinfo(calFileName)

%DBCFILEINFO Displays information about a DBC-file.
%
%--------
%Synopsis:
%  dbcfileinfo(calFileName)
%
%Description:
%   Displays information about a DBS-file.
%
%Output and Input:
%  signalFileName (StringT): Name of DBC file with or without the extension 
%    ".dbc".
%
%Global Variables:
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%  [2]: Pettersson L., Danestig M., Sjstrm U.: "An Experimental S-Band
%    Digital Beamforming Antenna", IEEE AES Systems Magazine, November 1997,
%    p.19-26.
%
%See Also:
%  expsig1

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 991118 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:20:20 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Handle input parameters.
% ----------------------------------------------------------------------- %

if (isempty(findstr(calFileName,'.dbc')))
  calFileName = [calFileName,'.dbc'];
end%if

% ----------------------------------------------------------------------- %
% Do the work.
% ----------------------------------------------------------------------- %


fprintf('\nContents in the %s DBC-file:\n',calFileName)
S = load(calFileName,'-mat')
