function dbtloopinfo(funcName, dummy, pulLoop, noPulLoop, ranLoop, noRanLoop, spaLoop, noSpaLoop, extraLoop, noExtraLoop, cpiLoop, noCpiLoop, trialLoop, noTrialLoop)

%DBTLOOPINFO Displays loop information when looping over the dimensions of a radar signal.
%
%--------
%Synopsis:
%  dbtloopinfo(funcName, [], pulLoop, noPulLoop, ranLoop, noRanLoop,
%    spaLoop, noSpaLoop, extraLoop, noExtraLoop, cpiLoop, noCpiLoop,
%    trialLoop, noTrialLoop)
%
%Description:
%  Displays loop information when looping over the dimensions of a radar
%  signal.
%
%  Symbols used: t=trial, c=CPI, e=extra, s=space, r=range bin, p=pulse.
%  When simultaneously using a whole dimension in the caclulations the
%  number 58 is displayed (character code for ':').
%
%Output and Input:
%  funcName (StringT): Name of function which contains the loops.
%  pulLoop, ranLoop, spaLoop (IntScalarT or = ':'): Current loop count for 
%    respective dimension. The value ':' means the whole dimesnion at once.
%  noPulLoop, noRanLoop, noSpaLoop (IntScalarT): Maximum loop count for
%    respective dimension.
%  extraLoop, cpiLoop, trialLoop [D](IntScalarT or = ':'): See "pulLoop".
%  noExtraLoop,  noCpiLoop, noTrialLoop [D](IntScalarT): See "noPulLoop".
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%  See the function "pulfilt" for an example.
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  dbtinfo, eetimebegin, eetimeend, eetimeloop, eetimepreloop

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 991026 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:20:25 $ $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters
% ----------------------------------------------------------------------- %

arginNo=8;
if (nargin < arginNo)
  error('DBT-Error: To few input parameters.')
end
arginNo = arginNo +1;

% ****************** Add missing input parameters ******************

if (nargin < arginNo)
  extraLoop = [];
end
arginNo = arginNo +1;
if (nargin < arginNo)
  noExtraLoop = [];
end
arginNo = arginNo +1;
if (nargin < arginNo)
  cpiLoop = [];
end
arginNo = arginNo +1;
if (nargin < arginNo)
  noCpiLoop = [];
end
arginNo = arginNo +1;
if (nargin < arginNo)
  trialLoop = [];
end
arginNo = arginNo +1;
if (nargin < arginNo)
  noTrialLoop = [];
end
arginNo = arginNo +1;


% ****************** Default values ******************

if isempty(extraLoop)
  extraLoop = 1;
end%if
if isempty(noExtraLoop)
  noExtraLoop = 1;
end%if
if isempty(cpiLoop)
  cpiLoop = 1;
end%if
if isempty(noCpiLoop)
  noCpiLoop = 1;
end%if
if isempty(trialLoop)
  trialLoop = 1;
end%if
if isempty(noTrialLoop)
  noTrialLoop = 1;
end%if


% ************* Pick out some more fields from input parameters. *************


% ****************** Error check input parameters ******************

%chkdtype(sigIn, 'RxRadarSigT')


% ----------------------------------------------------------------------- %
% Display on screen.
% ----------------------------------------------------------------------- %

infoStr = sprintf('%s: t=%d(%d), c=%d(%d), e=%d(%d), s=%d(%d), r=%d(%d), p=%d(%d) \r', funcName, trialLoop, noTrialLoop, cpiLoop, noCpiLoop, extraLoop, noExtraLoop, spaLoop, noSpaLoop,  ranLoop, noRanLoop, pulLoop, noPulLoop);

dbtinfo(infoStr,1);
