function jamerdef = defjammer(jamType, jamPower, jamWaveform, trgRange, trgDOA, jamVel)

%DEFJAMMER Defines a jammer in a structure of type JammerDefT.
%
%Synopsis:
%  jamerdef = defjammer
%  jamerdef = defjammer(jamType)
%  jamerdef = defjammer(jamType, jamPower)
%  jamerdef = defjammer(jamType, jamPower, jamWaveform)
%  jamerdef = defjammer(jamType, jamPower, jamWaveform, trgRange)
%  jamerdef = defjammer(jamType, jamPower, jamWaveform, trgRange, trgDOA)
%  jamerdef = defjammer(jamType, jamPower, jamWaveform, trgRange, trgDOA, 
%    jamVel)
%
%Description:
%  NOTE: The output of this function can not yet be used for simulation.
%
%  Defines a struct variable containing all information needed by the
%  function "simradarsig" in combination with the function "simjammer"
%  to simulate the radarsignal from a jammer.
%
%Input:
%  jamType [D](JammerDefT)   : Type of jammer
%  jamPower [D](RealScalarT) : Power of jammer at recieving antenna
%  jamWaveform [D](WaveformT): Jammer waveform.
%  trgRange [D](RealScalarT) : Range to Jammer. Default is 2000 [m].
%  trgDOA [D](DoaT)          : Direction to target. Default is straight forward.
%  jamVel [D](RealVectorT)   : Radial velocity of target relative radar. 
%                              Default is 0 [m/s].
%
%OutPut:
%  jammerdef (JammerDefT) : A definition of the jammer in a struct.
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in
%  [1] or by "help dbtdata".
%
%Examples:
%
%Software Quality:
%  This function is only a prototype of what to come!!!!
%
%Known Bugs:
%  The output of this functio can not yet be used for simulation.
%
%References:
%  [1]: Bjrklund S., Rejdemyhr D. Athley F.: "DBT, A MATLAB Toolbox
%       for Radar Signal Processing. Reference Guide",
%       FOA-D--9x-00xxx-408--SE, To be published.
%
%See also:
%  defnoise defclutter deftarget simradarsig

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
%  (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Initiation    : 981001 David Rejdemyhr (davrej).
%  Latest change : $Date: 2000/10/16 15:20:31 $ $Author: svabj $.
%  $Revision     : 1.0 $
%*************************************************************************

%  jamPos (RealVectorT)   : Position of jammer. Not used.

%-------------------------------------------------------------------------
%----         In-parameter control & default values handling          ----
%-------------------------------------------------------------------------

dbterror('This functionality is not yet available.')

if nargin < 6
  jamVel = 0;			    % Default radial velocity in m/s.
end%if

if nargin < 5 | isempty(trgDOA)
  trgDOA = d2r([35; 0]);	    % Default DOA in degrees.                  
end%if

if nargin < 4 | isempty(trgRange)
  trgRange = 2000;                  % Defaults to 1 km distant
end%if

%if nargin < x
%  jamPos = [1000 0 0];  % Defaults to 1 km distant straight forward. Not used.
%end%if

if nargin < 3 | isempty(jamWaveform)
  jamWaveform = [];                  % Defaults to 2 km distant
end%if

if nargin < 2
  jamPower = 10;
end%if

if nargin < 1
  jamType = 'swerling0';
end%if


%------------------------------------------------------------------------
%----              Setting up the output parameter                   ----
%------------------------------------------------------------------------

jamerdef.dataType    = 'TargetT;
jamerdef.TargetType  = trgType;
jamerdef.Power       = trgPower; % Might be replaced by RCS later on
jamerdef.jamWaveform = jamWaveform;
%jamerdef.Pos         = trgPos;
jamerdef.Range       = trgRange;
jamerdef.DOA         = trgDOA;
jamerdef.Velocity    = trgVel;

%End Of File

