function  rects = doa2rect(doas)

%DOA2RECT Converts between DOA coordinates and rectangular coordinates.
%
%--------
%Synopsis:
%  rects = doa2rect(doas)
%Description:
%  Converts between DOA coordinates and rectangular coordinates.
%
%Output and Input:
%  rects (Vector of PosT): Output rectangular coordinates.
%  doas (Vector of DoaT): Input DOA coordinates.
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 980526 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:20:39 $ $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************

r = 1;
theta = doas(1,:);
if (size(doas,1) == 2)
  phi = doas(2,:);
else
  phi = zeros(1,size(doas,2));
end%if

rCosPhi = r.*cos(phi);
x = rCosPhi.*sin(theta);
y = rCosPhi.*cos(theta);
z = - r.*sin(phi);
rects = [x; y; z];
