function  wavevec = doa2wavevec(doas,lambda)

%DOA2WAVEVEC Computes the wavevector for several waves.
%
%--------
%Synopsis:
%  wavevec = doa2wavevec(doas,lambda)
%
%Description:
%  Computes the wavevector for several waves.
%
%Output and Input:
%  wavevec (Vector of PosT):
%  doas (Vector of DoaT): Directions seen from the antenna to calculate
%    the wavevectors at. Note that the look directions of the antenna are
%    the opposite to the directions of the wavevectors.
%  lambda (RealScalarT): Wavelength of the carrier [m].
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 980515 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:20:40 $ $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************

directions = - doa2rect(doas);
wavevec = (2*pi/lambda) * directions * diag(sparse(1./vecnorm2(directions)));
