function a = dspastevec(antenna, doas, lambda, ranges)

% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  function a = dspastevec(antenna, doas, lambda, ranges)
%
%  Calculates the derivative of the ideal steering vector with respect to
%  the doa for specified angles for a particular distance.
%  This function should not be called. Use "dspastemat" instead.
%
%  antenna  AntDefT
%  doas     Vector of DoaT    (= RealMatrixT M x 2)
%  lambda   RealScalarT
%  ranges   RealVectorT (Only a scalar is implemented)

%
%  Start        : 960327 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:20:49 $ $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************

global thSign
  % Defines the reference direction for the theta angle in DOA:s.
  % Defined in "defant".

antennaType = antenna.antennaType;
if ~(strcmp(antennaType,'isotropULA') | strcmp(antennaType,'ULA') ...
     | strcmp(antennaType,'LA'))
  error('DBT-Error: Not implemented for the desired antenna type.')
end
if (nargin < 4)
  ranges = Inf;
end
if (ranges ~= Inf)
   error('DBT-Error: Only focus on infinity is implemented.')
end
if (size(doas,1) > 1)
  error('DBT-Error: spastevec is only implemented for one DOA angle (theta).')
end
theta = doas(:,1);

if isfield(antenna,'name')
  if (strcmp(antenna.name,'aimtEx'))
    error('DBT-Error: Not implemented.')
  elseif (strcmp(antennaType,'ULA') | strcmp(antennaType,'LA'))
    element = antenna.element;
    eType = element.antennaType;
    pType = element.patternType;
    if (strcmp(eType,'elem') & strcmp(pType,'isotrop'))
      noElem   = antenna.noElem;
      if (strcmp(antennaType,'ULA'))
        distElem = antenna.distElem;
        elemPos = distElem*(0:noElem-1)';
      else
        elemPos = antenna.elemPos;
      end%if
      a = thSign*j*2*pi*(elemPos/lambda)*cos(theta) .* exp(thSign*j*2*pi * ...
         (elemPos/lambda) * sin(theta));
    end%if
  else
    error('DBT-Error: Not implemented.')
  end%if
else
  error('DBT-Error: Antenna definition too old. Contact programmers.')
end%if exist name

