function fig(figNo, axesNo)

%FIG Short form of figure(figNo),subplot(?,?,axesNo) to select figure and axes.
%
%--------
%Synopsis:
%  fig(figNo, axesNo)
%  fig(figNo)
%
%Description:
%  Short form of figure(figNo),subplot(?,?,axesNo) to select figure and axes.
%
%Output and Input:
%  figNo (IntscalarT): Figure number to select.
%  axesNo (IntscalarT): Axes number to select within a figure. Numberd in
%  the same way with "subplot", ie numbered row-wise.
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  figure, subplot

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 981012 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:20:58 $ $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************

if ischar(figNo)
  figNo = str2num(figNo);
end%if

figure(figNo)

if (nargin > 1)
  if ischar(axesNo)
    axesNo = str2num(axesNo);
  end%if
  axes_handle_vec = get(gcf,'Children');
  axes_handle_vec = axes_handle_vec(:);
  axes_handle_vec = flipud(axes_handle_vec);
  axes_handle = axes_handle_vec(axesNo);
  set(gcf,'CurrentAxes',axes_handle);
end%if
