function [ROut,noData] = getcorrmkernel(sigMatIn, sigDim, dataChoice, modifyParam, pulLoop, ranLoop, spaLoop, extraLoop, cpiLoop, trialLoop)

%GETCORRMKERNEL Gets a (possibly modified) correlation matrix from a signal matrix.
%
%--------
%Synopsis:
%  [ROut,T] = getcorrmkernel(sigMatIn, sigDim, dataChoice, modifyParam, ...
%    pulLoop, ranLoop, spaLoop, extraLoop, cpiLoop, trialLoop)
%
%Description:
%  Gets a correlation matrix from a signal matrix, including a possible 
%  modification of the correlation matrix.
%
%  The correlation matrix is estimated from snapshots in the signal matrix.
%  The snapshots can be chosen as a "rectangular" area in the signal matrix.
%  The "rectangular" area can have more or less dimensions than two.
%  After the snapshot choice, a correlation matrix is estimated by the 
%  standard formula
%    ROut = 1/noData * corrmData*corrmData' ,
%  where "corrmData" contains the snapshots and "noData" is the number of 
%  snapshots.
%  Finally, a possible modification of the correlation matrix is done 
%  according to the input parameter "modifyParam". The modification is
%  performed by the function "modcorrmkernel". See this function for
%  possible modification methods.
%
%  This function is not aimed at the end user but at the extension programmer.
%
%Output and Input:
%  ROut (CxMatrixT): Output correlation matrix.
%  T (CxMatrixT): If the method of modification changes the size of the
%    correlation matrix, this output parameter is the transformation 
%    matrix which is stored in the output correlation matrix (RxCorrMatT)
%    and specifies the change of size.
%
%  sigMatIn (CxMultiMatrixT): Input signal matrix with the six dimensions
%    "pulse", "range", "space", "extra", "cpi" and "trial".
%  sigDim (IntScalarT): This dimension in "sigMatIn" is to be treated as
%    the "signal" dimension. This means that the output correlation matrix
%    will contain the correlation between the elements in the signal
%    dimension.
%  dataChoice (CellArrayT):
%  modifyParam (CellArrayT):
%  pulLoop (IntScalarT or =':'):
%  ranLoop (IntScalarT or =':'):
%  spaLoop (IntScalarT or =':'):
%  extraLoop (IntScalarT or =':'):
%  cpiLoop (IntScalarT or =':'):
%  trialLoop (IntScalarT or =':'):
%
%--------
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%  See the function "calcfiltsig".
%
%Algoritm:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  modcorrmkernel, getsnapshots, eccorrm, basecorrm


%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
% Start        : 991022 Svante Bjrklund (svabj).
% Latest change: $Date: 2000/10/16 15:20:58 $ $Author: svabj $.
% $Revision: 1.3 $
% *****************************************************************************
  
???

  [corrmData, noData] = getsnapshots(sigMatIn, sigDim, dataChoice{:})
  ROut = 1/noData * corrmData*corrmData';
  [ROut,T] = modcorrmkernel(ROut, modifyParam{:});
    % Maybe, there should be the possibility to modify the correlation
    % matrix in several steps. Use a loop and let "modifyParam" be a
    % cell array of cell arrays. Each element of "modifyParam" on the
    % highest level contain all the parameters for the function 
    % "modcorrmkernel".

%endfunction getcorrmkernel
