function ranBinLen = getranbinlen(waveform, propSpeed)

%GETRANBINLEN Gets the length of a range bin.
%
%--------
%Synopsis:
%  ranBinLen = getranbinlen(waveform, propSpeed)
%
%Description:
%  Delivers the length of a range bin [m].
%
%Output and Input:
%  waveform (WaveformT) : Waveform of the transmitted radarsignal.
%  propSpeed [D](RealScalarT):Propagation speed of the radar wave [m/s].
%    Default is speed of light in empty space.
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1].
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.
%   Known bugs.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  ran2ranbin

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990301 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:21:00 $ $Author: svabj $.
%  $Revision: 1.3 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters
% ----------------------------------------------------------------------- %

% ****************** Add missing input parameters ******************

arginNo=1;
if (nargin < arginNo)
  error('DBT-Error: To few input parameters.')
end
arginNo = arginNo +1;

if (nargin < arginNo)
  propSpeed = [];
end
arginNo = arginNo +1;

% ****************** Default values ******************

if isempty(propSpeed)
  propSpeed = speedoflight;
end%if

% ****************** Error check input parameters ******************

chkdtype(waveform, 'WaveformT')
chkdtype(propSpeed, 'RealScalarT')


% ----------------------------------------------------------------------- %
% Do the work.
% ----------------------------------------------------------------------- %

ranBinLen = (propSpeed * waveform.sampleTime)/2;

%End Of File
