function lppolar(fi,R,rmax,rmin,rticks,fimax,fimin,fiticks)

%LPPOLAR Polar coordinate plot.
%
%--------
%Synopsis:
%  lppolar(fi,R,rmax,rmin,rticks,fimax,fimin,fiticks)
%
%Description:
%  Plottar polra diagram, frbttring av matlabs 'polar'
%  function lppolar(fi,R,rmax,rmin,rticks,fimax,fimin,fiticks)
%
%  Argumenten r fi-vinkel, R-variabel, min och max av R-vrdet i
%  centrum och ytterst samt antel cirklar. Dessutom kan min, max och
%  antal radier fr fi anges om inte hela varvet nskas.
%  R,rmax,rmin: Alla linjra eller i dB.
%  fimax,fimin: radianer.
%
%--------
%See Also:
%  polar

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 9xxxxx Lars Pettersson (larpet).
%  Latest change: $Date: 2000/10/16 15:21:07 $ $Author: svabj $.
%  $Revision: 1.6 $
% *****************************************************************************


holdin = ishold;

R=max(R-rmin,0);	% Plotradie

if size(fi,2) ~= 1;	fi=fi';	end
if size(fi,2) ~= 1;	error('DBT-Error: fi ska vara en vektor');	end
if size(fi,1) == size(R,2)
	R=R';
elseif size(fi,1) ~= size(R,1)
	error('DBT-Error: Dimensioner stmmer inte i lppolar');
end

nplot=size(R,2);

if nargin < 6;	fimin=0;	fimax=2*pi;	fiticks=12;	end
ficirk=linspace(fimin,fimax,181)';

if nargin < 5; rticks=1;	end
rcirk=linspace(0,rmax-rmin,rticks+1);	rcirk=rcirk(2:rticks+1);

if nargin >=6 & nargin < 8;	fiticks=1;	end
firad=linspace(fimin,fimax,fiticks+1);
if nargin < 6;	firad=firad(1:fiticks);	end
rrad=[0;rmax-rmin];

% Rita grid
plot(cos(ficirk)*rcirk,sin(ficirk)*rcirk,'--')
hold on
plot(rrad*cos(firad),rrad*sin(firad),'--')

axis('off');	axis('equal')

% Plotta resultatet
plot((cos(fi)*ones(1,nplot)).*R,(sin(fi)*ones(1,nplot)).*R)

%text(1.2*(rmax-rmin),-rmax+rmin,['Full Scale = ',num2str(rmin),...
%	' to ',num2str(rmax)],'HorizontalAlignment','right');
text(max(cos(ficirk))*(rmax-rmin),min(sin(ficirk)-0.1)*(rmax-rmin),...
['Full Scale = ',num2str(rmin),' to ',num2str(rmax)],'HorizontalAlignment','right');

if ~holdin,	hold off;	end
