function [pat1,pat2] = pantpat(antenna, taperType, taperParam,theta,theta1,theta2,plotopt,lambda)

% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  function [pat1,pat2] = pantpat(antenna, taperType, taperParam,
%                theta, theta1, theta2, plotopt, lambda)
%
%  Plots the antenna pattern.
%
%  NOTE: This function pantpat is not tested.
%
%  pat1     ?
%  pat2     ?
%  antenna  AntDefT
%  taperType   StringT     : Tapering to use.
%  taperParam  Type and contents depends on taperType, see below.
%
%  taperType =
%    'notaper' : No tapering.
%    'taylor'  : Taylor tapering.
%       taperParam(1)  RealScalarT : Sidelobe level SLL in dB (SLL > 0).
%  taperParam(1)  RealScalarT : The nbar parameter
%    'cheby'
%    'custom'
%       taperParam  CxVextorT
%    'norm' : No tapering. Normalized weights.
%  theta Vector of DoaT: Angle grid on which the pattern will
%           be computed
%  theta1   DoaT  : Pointing direction of the main array
%  theta2   DoaT  : Pointing direction of the subarrays
%  plotopt  StringT  : Which plots to produce
%  plotopt =
%  'main'      : Plot only main array pattern
%  'subarray'  : Plot only subarray pattern
%  'both'      : Plot both main array and subarray pattern
%  lambda   RealScalarT : Wavelength [m].

%
%  Start        : 9xxxxx Fredrik Athley (freath).
%  Latest change: $Date: 2000/10/16 15:21:14 $ $Author: svabj $.
%  $Revision: 1.20 $
% *****************************************************************************

disp('Warning: The function pantpat is obsolete and will be removed. Use pantpat3 instead.')

global thSign
  % Defines the reference direction for the theta angle in DOA:s.
  % Defined in "defant".


%lambda = antenna.lambda;
d = antenna.distElem;
K = antenna.noElem;
k = 0:K-1;

if (nargin < 2)
  taperType = 'notaper';
  taperParam = [];
end

if nargin<4
  theta = d2r(-90:.5:90);
end
if nargin<5
  theta1 = 0;
end
if nargin<6
  theta2 = 0;
end
if (nargin < 7)
  plotopt = 'main';
end


% ----------------------------------------------------------------------- %
% Tapering.
% ----------------------------------------------------------------------- %
if (strcmp(taperType,'notaper'))
  taper = ones(K,1).';
elseif (strcmp(taperType,'taylor'))
  SLL = taperParam(1);
  if length(taperParam)==2
    nbar = taperParam(2)
  else
    nbar = 12;
  end
  taper = tayltap(SLL,nbar,K);
else
  error('DBT-Error: Desired taper type not implemented.')
end



poserr = 0;
dmek = k*d + poserr;
A = spastemat(antenna,theta,lambda,Inf,theta2,poserr);
%disp('A');size(A)
w = exp(-thSign*i*2*pi*dmek'/lambda*(sin(theta1))).';
taperMatrix = sparse(diag(taper.*w));

At = taperMatrix*A;
p = 20*log10(abs(sum(At)));
%size(theta)
%size(p)
plot(r2d(theta),p);grid on;title('Antenna pattern')
xlabel('azimuth angle [degrees]');ylabel('[dB]')

pat1.dataType = 'DoaSpecT';
pat1.specSmpl = p;
pat1.doaPos = theta;
pat1.spectrumType = 'Antenna Pattern';

