function B = pulstemat(waveform, freqs)

%PULSTEMAT Calculation of pulse (slow time) steering matrix.
%
%--------
%Synopsis:
%  B = pulstemat(waveform, freqs)
%
%Description:
%  Calculates the pulse (slow time) steering matrix for specified frequencies.
%  This function is normally not called by the end user but
%  by the extension programmer that extends the toolbox DBT with new signal
%  processing methods etc.
%
%
%Output and Input:
%  B (CxMatrix): The calculated pulse steering matrix. The size is 
%   (noPulses, noFreqs), where noPulses is the number of time samples
%    and noFreqs is the number of frequencies.
%  waveform (WaveformT): The waveform definition.
%  freqs (RealVectorT.'): Frequencies to calculate the steering vectors at [Hz].
%
%--------
%Uniform Linear Time.
%Synopsis:
%
%Description:
%
%Algoritm:
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  defwave

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990222 Svante Bjvrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:21:27 $ (17:08) $Author: svabj $.
%  $Revision: 1.6 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters.
% ----------------------------------------------------------------------- %

if (nargin < 2)
  error('DBT-Error: To few input parameters.')
end

% ****************** Add missing input parameters ******************

% ****************** Default values ******************

% ****************** Error check input parameters ******************
if (size(freqs,1) > 1)
  error('DBT-Error: "freqs" must be a row vector.')
end%if

% ----------------------------------------------------------------------- %
% Perform the calculations.
% ----------------------------------------------------------------------- %

pri = (waveform.noRangeBins * waveform.sampleTime);
prf = 1/pri;

t = (0:(waveform.noPulses-1)).';
B = exp(j*2*pi*pri*t*freqs);
