%WIDEEX1 Test of direction-of-arrival estimation with conventional beamforming and MUSIC using simulated wideband signals.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 981212 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:37 $ $Author: svabj $.
%  $Revision: 1.7 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %

lambda	= 0.1;			% wavelength.
D 	= 0.45*lambda;		% Element separation.
T 	= 16;			% Number of snapshots.
K 	= 12;			% Number of digital antenna channels.

theta	= d2r([25 40]).';	% Target angles. The number of targets is
				%  given by the number of target angles.
MMu	= 2;			% Number of targets that MUSIC believes in.
SNR = 0;



% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

ant = defant('isotropULA',[K,D]);		% Define the antenna.

antenna = ant;
noSrc = 2;
propSpeed = speedoflight;		% [m/s].
carrierFreq = propSpeed / lambda	% [Hz].	(3 GHz)
bandwidth = 2e9				% [Hz].
noTimes = T;
noTrials = 1;
srcType = 'randn';
srcSignals = [];
srcDoas = theta.';
srcPowers = ones(noSrc,1);
noiseType = 'randn';
noisePower = srcPowers(1) / (10^(SNR/10))
srcCorr = [];
orthSig = [];

sig = simwidebandkernel(antenna, [], carrierFreq, bandwidth, noTimes, ...
  noTrials, propSpeed, srcType, srcSignals, srcPowers, srcDoas, [], ...
  {srcCorr}, [], noiseType, noisePower, [], orthSig);
  % Generate simulated received antenna signals.



spect1 = sdoaspc('music',sig,[],MMu);		% Estimate the DOA-spectrum
						%  with MUSIC.

R = ecorrm(sig);				% Estimate the antenna signals
						%  correlation matrix.

spect2 = sdoaspc('cbf',R);			% Estimate the DOA-spectrum
						%  with conventional beamform.
splot2(spect1,'',spect2)			% Plot both DOA-spectrums.
legend('Music','Conventional beamforming')
plotxline(r2d(srcDoas),'m','--')

%printfm wideex1a1.eps [] 12

