/******************************************************************************
% RECVAR, A package for new data types in Matlab 4. 
% RECVAR was written by Svante Bjrklund.
% (c) FOA 1997. See the file rvright.m for copyright notice.

    Compile with:
      cmex matvar.c
  
    Start        : 95/12/11 Svante Bjrklund(svabj).
    Latest change: $Date: 1997/08/01 18:13:08 $ $Author: svabj $.
 ******************************************************************************/

#define V4_COMPAT	// Matlab kompatible with version 4.

#include <string.h>	/* strcmp(), strncpy(), memcpy() */
#include <stdlib.h>	/* calloc(), free() */
#include <limits.h>	/* INT_MAX, SHRT_MAX */
#include "mex.h"	/* Functions to use in mex-programs. */
#include "mat.h"	/* Functions to handle Matlab matrices, 
			   including mxSetDispMode() */

static const char *rcsid = "$Id: matvar.c,v 2.12 1997/08/01 18:13:08 svabj Exp $";

/* #define DYNAMIC_RECORDS */	/* If storing pointers to the fields in the 
				   Matlab matrix */

enum Boolown { FALSK, SANN };	/* Vr bool-datatyp */
typedef enum Boolown 	BoolT;

#if defined(unix) || defined(__WIN32__)
 typedef int		Int32T;
 typedef short		Int16T;
 #define INT16T_MAX	SHRT_MAX
 typedef unsigned int	UInt32T;
 #define UINT32T_MAX	UINT_MAX
 typedef unsigned short	UInt16T;
 typedef unsigned char	UInt8T;
 typedef float		Float32T;
 typedef double		Float64T;
 #define StringT	string
 #define FPT
 #elif defined(__WATCOMC__)
 typedef long		Int32T;
 typedef short		Int16T;
 #define INT16T_MAX	SHRT_MAX
 typedef unsigned long	UInt32T;
 #define UINT32T_MAX	ULONG_MAX
 typedef unsigned short	UInt16T;
 typedef unsigned char	UInt8T;
 typedef float		Float32T;
 typedef double		Float64T;
 #define StringT	string
 #define FPT _far
#else
 typedef long		Int32T;
 typedef short		Int16T;
 #define INT16T_MAX	SHRT_MAX
 typedef unsigned long	UInt32T;
 #define UINT32T_MAX	ULONG_MAX
 typedef unsigned short	UInt16T;
 typedef unsigned char	UInt8T;
 typedef float		Float32T;
 typedef double		Float64T;
 #define StringT	string
 #define FPT _far
#endif

typedef unsigned long int ULIntT;

#if defined(unix) || defined(__WIN32__)
  typedef double FloatMatlabT;
#else
  typedef double FloatMatlabT;
#endif
typedef FloatMatlabT* 	FloatMatlabPT;


void assertFunktion(int test, int rad, char* fil, const char* msg)
{
  if (!test)
  {
    mexPrintf("Assert error on line %d in file %s : %s\n", rad, fil, msg);
  }
}

#define ASSERT_ON

#ifdef ASSERT_ON
  #define assert(test, msg) assertFunktion(test, __LINE__, __FILE__, msg)
#else
  #define assert(test, msg) 	
#endif

const char* accessFieldErrMsg = "Trying to access invalid FieldHeadT.";
const char* accessNullErrMsg = "Trying to access with NULL pointer.";

#define TEXT    1                       /* mat.type indicating text */
#define MATRIX  0                       /* mat.type indicating matrix */

typedef Matrix* 	MatrixPT;
typedef MatrixPT*	MatrixPPT;

const   sizeOfFM = sizeof(FloatMatlabT);
typedef UInt32T  SizeFMT;		/* For sizes in multiples of
					   sizeof(FloatMatlabT) */


/*****************************************************************************
// Declarations for storing Matlab matrices in the pr-block of a Matlab Matrix. 
 *****************************************************************************/

/*=========================================================================
//=========================================================================*/

#define RECVARVERSION 3		     /* Om struct RecordHeadT eller 
					struct FieldHeadT ndras ska denna
					siffra kas. Sedan mste man testa p 
					vrdet av detta makro i koden. Den 
					gamla koden
					mste finnas kvar (fr lagrade gamla
					variabler). */

/*const FloatMatlabT NaNconst = (FloatMatlabT) 0x7FF0000000000010;*/
const FloatMatlabT NaNconst = 9.876545678e34;

typedef struct recordHead 
{
  FloatMatlabT  introNaN;	     /* To distinguish between a record variable
					and an ordinary Matlab variable. */
  UInt8T	type;
  UInt8T 	version;
  UInt16T	notUsed;
  /* SizeFMT	allocatedSize; */	/* The size of the pr-block of the 
					Matlab matrix (including RecordHeadT) 
					in multiples of sizeof(FloatMatlabT) */
  Int32T	firstFieldRPtr;	     /* The distance in bytes between the 
					beginning of
					this RecordHeadT and the first
					FieldHeadT. A relative pointer */
  Int32T	nextFieldRPtr;	     /* Not used yet. Can be used when accessing
					the next field in a list. */
  FloatMatlabT	alignmentAdjuster;
} RecordHeadT;

typedef RecordHeadT* RecordHeadPT;

/*=========================================================================
//=========================================================================*/

/* const Int16T maxFieldName = 24; */
#define MAXFIELDNAME 23
#define MAXROWCOL UINT32T_MAX
const UInt32T introFieldConst = 0xa5cd;	

typedef struct fieldHead
{
  UInt32T	introField;		/* A number with low probalilty. 
					   To recoginize a FieldHeadT. */
  char 		name[MAXFIELDNAME+1];
  UInt8T	mType;
  UInt8T 	displayMode;
  UInt8T	storage;		/* Not used yet. Sparse fields not 
					   implemented. */
  UInt8T	notUsed;
  UInt32T 	m;			/* Number of rows. Should be int. */
  UInt32T 	n;			/* Number of columns. Should be int. */
  Int32T	rpr;			/* relative pointer in bytes relative 
					   the beginning of the FieldHeadT. */
  Int32T	rpi;			/* relative pointer in bytes relative 
					   the beginning of the FieldHeadT. */
  Int32T	nextFieldRPtr;		/* relative pointer to next field
					   in bytes */
  SizeFMT	allocSize;		/* Size of the pr- and pi-blocks 
					   together of the field 
					   ( sizeof(FieldHeadT) not 
					   included. ) in multiples of 
					   sizeof(FloatMatlabT). */

  FloatMatlabT	alignmentAdjuster;	/* This is a dummy field, whose purpose 
					   is to make the follwing pr-part to 
					   start on an 8-byte boundary. This 
					   field must be the last in this 
					   struct. */
} FieldHeadT;

typedef FieldHeadT* FieldHeadPT;

/*****************************************************************************
   Help functions
 *****************************************************************************/


/*=========================================================================
// Kontroll att en Matlabvariabel lagrar en strng.
//=========================================================================*/
void checkParamStrang(Matrix* param)
{
	if (!mxIsString(param)) 
	{
		mexErrMsgTxt("Inparametern mste vara en strng.");
	}
} /*endfunction checkParamStrang */


/*=========================================================================
// Kontroll av antal inparametrar.
//=========================================================================*/
void checkAntalInParam(int antParam, int minAnt, int maxAnt)
{
  if ((antParam < minAnt) || (antParam > maxAnt))
  {
	mexErrMsgTxt("Wrong number of input parameters.");
  }
}


/*=========================================================================
// Kontroll av antal utparametrar.
//=========================================================================*/
void checkAntalUtParam(int antParam, int minAnt, int maxAnt)
{
  if ((antParam < minAnt) || (antParam > maxAnt))
  {
	mexErrMsgTxt("Wrong number of output parameters.");
  }
}


/*=========================================================================
// Plockar ut en strng ur en Matlabvariabel.
//=========================================================================*/
void getMatlabString(Matrix* instr, char** utstr)
{
  int	strlen = mxGetN(instr)+1;
  *utstr= (char*)mxCalloc(strlen,1);	/* Avallokeras automatiskt. */
  if (mxGetString(instr,*utstr,strlen)) 
	mexErrMsgTxt("Internal error at string copy.");
  return;
}


/*=========================================================================
// Skapar en Matlabvariabel och lagrar en skalr i den.
//=========================================================================*/
void createMatlabSkalar(Matrix** resultatmatrisPP, Float64T varde)
{
	    (*resultatmatrisPP) = mxCreateFull(1,1, REAL); 
      	    if ((*resultatmatrisPP) == NULL) 
		mexErrMsgTxt("Out of memory for UTMATRIS.");
            (*mxGetPr( (*resultatmatrisPP))) = varde;
}


/*=========================================================================
// Fyller en matlabvariabel med en lista av C-strngar.
//=========================================================================*/

Matrix* createMatlabStringList(char** cStringList, int noStrings)
{
        Matrix* utmatris;
	int 	maxlen = 0;	/* Lngd av lngsta strngen, utan \0-tecknet.*/
	int  	strnr;		/* Loop-rknare: strngnummer. */
	int  	tknnr;		/* Loop-rknare: teckennummer inom strng. */
	int	len;
	char*   str;
	FloatMatlabT* pr;

        if  (noStrings > 0)
    	{
	    /* Ta reda p lngsta strngen. (Strngar i Matlab-matris r 
	       lika lnga). */
	    for (strnr=0; strnr<noStrings; strnr++)
            {
		if (strlen(cStringList[strnr]) > maxlen) 
		    maxlen = strlen(cStringList[strnr]);
            }/*endfor*/


 	    /* Skapa returmatris.*/
  	    utmatris = mxCreateFull(noStrings, maxlen, REAL); 
      	    if (utmatris == NULL) mexErrMsgTxt("Out of memory for utmatris in "
					       "createMatlabStringList().");
    	    pr = mxGetPr(utmatris);

	    /* Fyll returmatrisen.*/
	    for (strnr=0; strnr<noStrings; strnr++)
            {
		for (tknnr=0; tknnr<maxlen; tknnr++)
		{
		    len = strlen(cStringList[strnr]);
		    str = cStringList[strnr];
		    if ((tknnr+1) <= len)
		    {
			/* Kopiera och konvertera.*/
			pr[tknnr*noStrings + strnr] = (FloatMatlabT)str[tknnr];
			/* Observera den omvnda ordningen p index!*/
		    }
		    else
			pr[tknnr*noStrings + strnr] = 0; /* Avsluta med */
							 /* \0-tecken.  */
		}/*endfor tknnr*/
            }/*endfor strnr*/
        } else 
	/* Returnera tom matris pga att inga mtningar finns i databasen.*/
        {   
	    utmatris = mxCreateFull(0,0, REAL); 
      	    if (utmatris == NULL) mexErrMsgTxt("Out of memory for utmatris in "
					       "createMatlabStringList().");
	    mxSetPr(utmatris,NULL);	
        }/*endif*/
        return utmatris;
}


/*=========================================================================
// Kopierar en matlabvariabel till en ny matlabvariabel.
//=========================================================================*/

MatrixPT copyMatlabMatrix(MatrixPT fromp)
{
  MatrixPT 	utmatris;
  int  		m,n;
  utmatris = NULL;

  if (fromp == NULL)
  {
    return NULL;
  }
  if (mxIsSparse(fromp)) mexErrMsgTxt("Copy for sparse matrices is not "
				      "implemented.");
  else
  { 
    if (mxIsComplex(fromp)) mexErrMsgTxt("Copy for complex matrices is not "
					 " implemented.");
    else
    { 
      m = mxGetM(fromp);
      n = mxGetN(fromp);
      utmatris = mxCreateFull(m,n, REAL); 
            if (utmatris == NULL) mexErrMsgTxt("Out of memory in copyMatlabMatrix()");
      /* set name, diplay mode, storage ! */
      memcpy(mxGetPr(utmatris), mxGetPr(fromp), sizeof(FloatMatlabT)*m*n);
      return utmatris;
    }
  }

  return NULL; /* AG, This line makes no sense, but else a warning is made by*/
               /* the WATCOM compiler concerning a missing return value*/
} /* endfunc copyMatlabMatrix */



/*****************************************************************************
//
 *****************************************************************************/

/*=========================================================================

=========================================================================*/


Matrix* createEmptyFullMatlabMatrix(void)
{
  Matrix* utmatris;
  utmatris = mxCreateFull(0,0, REAL); 
  if (utmatris == NULL) mexErrMsgTxt("Out of memory in "
				     "createEmptyFullMatlabMatrix().");
  mxSetPr(utmatris,NULL);
  return utmatris;	
}


void setMatlabMatrixDisplayMode(Matrix* utmatris, int mode)
{
  mxSetDispMode(utmatris, mode); /* Is this allowed? */
}


int isEmptyMatlabMatrix(Matrix* mMatrix)
{
  assert(mMatrix != NULL, accessNullErrMsg);
  return ((mxGetM(mMatrix) + mxGetM(mMatrix)) == 0);
}


void printMatlabMatrix(MatrixPT mMatrix)
{
  char* disp ="disp";
  Matrix** pekInParam;
  Matrix*  pekInParam0;

  pekInParam = &pekInParam0;
  pekInParam[0] = mMatrix;
  mexCallMATLAB(0,NULL,1,pekInParam,disp);
}


SizeFMT dataSizeMatlabMatrix(Matrix * mMatrix)
{
  if (mxIsSparse(mMatrix)) 
    mexErrMsgTxt("Calculation of data size of a sparse matrix is not implemented.");
  else if (mxIsComplex(mMatrix))
    return (mxGetM(mMatrix) * mxGetN(mMatrix) * 2);
  else /* Real matrix */
    return (mxGetM(mMatrix) * mxGetN(mMatrix));

  return NULL; /* AG, This line makes no sense, but else a warning is made by*/
               /* the WATCOM compiler concerning a missing return value*/
}


/*****************************************************************************
//
 *****************************************************************************/
/*=========================================================================

=========================================================================*/


Matrix* createRecordVar(SizeFMT msize)
{
  Matrix*	 utmatris;
  RecordHeadT* 	recordHead;

  utmatris = mxCreateFull(msize , 1, REAL); 
  if (utmatris == NULL) mexErrMsgTxt("Out of memory in setRecord()");
  recordHead = (RecordHeadT*)mxGetPr(utmatris);
  recordHead->introNaN = NaNconst;
  /*recordHead->type=*/
  recordHead->version = RECVARVERSION;
  /* recordHead->allocatedSize = msize; */
  recordHead->firstFieldRPtr = 0;
  return utmatris;
}


int isRecordVar(Matrix* mMatrix)
{
  RecordHeadT* 	recordHead;
  BoolT isRecordHead;

  if (!isEmptyMatlabMatrix(mMatrix))
  {
    assert(mMatrix != NULL, accessNullErrMsg);
    recordHead = (RecordHeadT*)mxGetPr(mMatrix);
    assert(recordHead != NULL, accessNullErrMsg);
    isRecordHead =  (recordHead->introNaN == NaNconst);
    if (isRecordHead)
    {
      if (recordHead->version < RECVARVERSION)
        mexPrintf("Warning: The record variable is of earlier version than "
	  "this program.");
    }
  }
  else
  {
    isRecordHead = FALSK;
  }
  return isRecordHead;
}


int isFieldHead(FieldHeadT* field)
{
  if (field == NULL) return 0;
  return (field->introField == introFieldConst);
}


void setFirstFieldRPtr(Matrix* mMatrix, FieldHeadT* field)
{
  RecordHeadT* 	recordHead;

  recordHead = (RecordHeadT*)mxGetPr(mMatrix);
  recordHead->firstFieldRPtr =  (Int32T)field - (Int32T)recordHead;
}


void setNextFieldRPtr(FieldHeadT* fieldToSet, FieldHeadT* fieldToPointTo)
{
  assert(isFieldHead(fieldToSet), accessFieldErrMsg);
  fieldToSet->nextFieldRPtr  = (Int32T)fieldToPointTo - (Int32T)fieldToSet;
}


FieldHeadT* getFirstField(Matrix* mMatrix)
{
  RecordHeadT* 	recordHead;

  recordHead = (RecordHeadT*)mxGetPr(mMatrix); 
  if (recordHead->firstFieldRPtr == 0) 
    return NULL;
  else 
    return (FieldHeadT*)((Int32T)recordHead 
            + (Int32T)recordHead->firstFieldRPtr);
}


FieldHeadT* getFirstEmptyField(Matrix* mMatrix)
{
  RecordHeadT* 	recordHead;
  recordHead = (RecordHeadT*)mxGetPr(mMatrix);
  return (FieldHeadT*)((Int32T)recordHead + (Int32T)sizeof(RecordHeadT));
  /* Check if there is any place! */
}



FieldHeadT* getNextField(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  if (field->nextFieldRPtr == 0) 
    return NULL;
  else 
    return (FieldHeadT*)((Int32T)field + (Int32T)field->nextFieldRPtr);
  /* Search for the next free space if any !?! */
}


FieldHeadT* getNextEmptyField(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return (FieldHeadT*)((Int32T)field + (Int32T)(sizeof(FieldHeadT)) 
         + (Int32T)((field->allocSize)*sizeOfFM));
  /* Search for the first free space if any !?! */
}



char* getFieldName(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return field->name;
}

UInt8T getFieldmType(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return field->mType;
}

char* getFieldDisplayMode(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  if (field->displayMode == TEXT)
    return "TEXT";
  else if (field->displayMode == MATRIX)
    return "MATRIX";
  else
    return "UNKNOWN";
}

SizeFMT getFieldAllocSize(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return field->allocSize;
}

FloatMatlabT* getFieldPr(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  if (field->rpr == 0) 
    return NULL;
  else 
    return (FloatMatlabT*)((Int32T)field + (Int32T)(field->rpr)); 
}

FloatMatlabT* getFieldPi(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  if (field->rpi == 0) 
    return NULL;
  else 
    return (FloatMatlabT*)((Int32T)field + (Int32T)(field->rpi)); 
}


int isComplexField(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return (field->rpi != 0);
}

int isRealField(FieldHeadT* field)
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return (!isComplexField(field));
}


/*=========================================================================

=========================================================================*/

UInt32T getFieldRelativePr(FieldHeadT* field)
/* Only used to inspect the value of this component of the struct */
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return (field->rpr);
}

UInt32T getFieldRelativePi(FieldHeadT* field)
/* Only used to inspect the value of this component of the struct */
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return (field->rpi);
}

UInt32T getNextFieldRelativePtr(FieldHeadT* field)
/* Only used to inspect the value of this component of the struct */
{
  assert(isFieldHead(field), accessFieldErrMsg);
  return (field->nextFieldRPtr);
}


/*****************************************************************************
//
 *****************************************************************************/
Matrix* copyField2MatlabMatrix(FieldHeadT* field)
{
  Matrix* utmatris;
  int  m,n;

  assert(isFieldHead(field), accessFieldErrMsg);
  if ((field->m > INT_MAX) || (field->n > INT_MAX))
    mexErrMsgTxt("To many rows or columns of Field Matrix in "
	  "copyField2MatlabMatrix");
  m = field->m;
  n = field->n;
  if ((m==0) || (n==0))
  {
    utmatris = createEmptyFullMatlabMatrix();
  }
  else if (isRealField(field))
  {
    utmatris = mxCreateFull(m, n, REAL); 
    if (utmatris == NULL) mexErrMsgTxt("Out of memory in "
				       "copyField2MatlabMatrix()");
    memcpy(mxGetPr(utmatris), getFieldPr(field), sizeOfFM*m*n);
  }
  else if (isComplexField(field))
  {
    utmatris = mxCreateFull(m, n, COMPLEX); 
    if (utmatris == NULL) mexErrMsgTxt("Out of memory in "
				       "copyField2MatlabMatrix()");
    memcpy(mxGetPr(utmatris), getFieldPr(field), sizeOfFM*m*n);
    memcpy(mxGetPi(utmatris), getFieldPi(field), sizeOfFM*m*n);
  }
  else
  {
    mexErrMsgTxt("Illegal Matlab Matrix type in copyField2MatlabMatrix()");
  }
  /*
  mxSetName(utmatris, field->name);
  */
  setMatlabMatrixDisplayMode(utmatris, field->displayMode);
  return utmatris;
} /* endfunc copyField2MatlabMatrix */



void copyMatlabMatrix2Field(Matrix* mMatrix, FieldHeadT* field, char *fieldname)
{

  int  	m,n;

/*By disable following test, you can handle empty matrices as field object, by AG*/
/*  if (isEmptyMatlabMatrix(mMatrix))
  {
    mexErrMsgTxt("Can not copy an empty Matlab Matrix in copyMatlabMatrix2Field.");
  }
*/
  if (mxIsSparse(mMatrix)) mexErrMsgTxt("Copy for sparse matrices is not "
				      "implemented.");
  else
  { 
      field->introField = introFieldConst;
      strncpy(field->name, fieldname, MAXFIELDNAME+1);
      field->name[MAXFIELDNAME] = '\0';
      /* field->mType = */
      if (mxIsString(mMatrix))
        field->displayMode = TEXT;
      else if (mxIsNumeric(mMatrix))
        field->displayMode = MATRIX;
      else
	mexErrMsgTxt("Unknown display mode in copyMatlabMatrix2Field.");
      m = mxGetM(mMatrix);
      n = mxGetN(mMatrix);
      if ((m>MAXROWCOL) || (n>MAXROWCOL)) 
	mexErrMsgTxt("To many rows or columns of Matlab Matrix in "
	  "copyMatlabMatrix2Field");
      field->m = m;
      field->n = n;
      field->rpr = sizeof(FieldHeadT);
      memcpy(getFieldPr(field), mxGetPr(mMatrix), sizeOfFM*m*n);
      field->nextFieldRPtr = 0;			/* This is the last field ! */

      if (mxIsComplex(mMatrix)) 
      {
        field->rpi = field->rpr + m*n*sizeOfFM;
        memcpy(getFieldPi(field), mxGetPi(mMatrix), sizeOfFM*m*n);
        field->allocSize = m*n*2;	/* Uses the double memory space */
      }
      else /* Real matrix */
      { 
        field->rpi = 0;			/* Not in use. */
        field->allocSize = m*n;
      }/*endif*/
  }
} /* endfunc copyMatlabMatrix2Field */


void copyField2Field(FieldHeadT* oldField, FieldHeadT* newField)
{
  SizeFMT	rowsTimesCols;

  assert(isFieldHead(oldField), accessFieldErrMsg);
  (*newField) = (*oldField);	/* The whole struct is copied. */
  rowsTimesCols = (oldField->m)*(oldField->n);
  /* newField->rpr Doesn't need to be changed. */
  memcpy(getFieldPr(newField), getFieldPr(oldField), rowsTimesCols*sizeOfFM);

  if (isRealField(oldField))
  {
    newField->allocSize = rowsTimesCols;
  }
  else /* Complex field */
  {
    /* newField->rpi Must be changed if we want to pack. */
    newField->rpi = newField->rpr + (newField->m)*(newField->n)*sizeOfFM;
    memcpy(getFieldPi(newField), getFieldPi(oldField), rowsTimesCols*sizeOfFM);
    newField->allocSize = rowsTimesCols*2;
  }
  newField->nextFieldRPtr = 0;
} /* endfunc copyField2Field */


/*****************************************************************************
//
 *****************************************************************************/
/*=========================================================================

=========================================================================*/

FieldHeadT* searchFieldName(Matrix* recordVar, char* fieldName)
/* Returns NULL if the field was not found. */
{
  FieldHeadT*	field;

  field = getFirstField(recordVar);
  while (field != NULL)
  {    
    if (!strcmp(getFieldName(field), fieldName))
    {
      return field;
    }
    else
    {
      field = getNextField(field);
    }
  }
  return NULL;
} /* endfunc searchFieldName */



/*=========================================================================
  Returns a list with the field names of a record variable.

  return values:
    via return : char** list of strings.
    nFieldsp   : The number of fields found.
=========================================================================*/
char** getFieldNameList(MatrixPT recordVar, int* nFieldsp)
{
  const 	maxNoFields = 100;
  FieldHeadT*	field;
  char**	dirlista;
  int 		fieldIndex;

  if (isRecordVar(recordVar))
  {  
    fieldIndex = 0;
    field = getFirstField(recordVar);
    if (field == NULL)
    {
        *nFieldsp = 0;
	return NULL;
    }/*endif*/
    dirlista = calloc(maxNoFields, sizeof(char*));
    while (field != NULL)
    {   
	if (fieldIndex > maxNoFields-1) mexErrMsgTxt("Too many fields in record "
						 "variable in recdir().");

	dirlista[fieldIndex] = getFieldName(field);
      	field = getNextField(field);
	fieldIndex++;
    }/*endwhile*/
    *nFieldsp = fieldIndex;
    return dirlista;
  }
  else
  {
    mexErrMsgTxt("Can not get a directory of fields from a non-record variable.");
  }/*endif*/

  return NULL; /* AG, This line makes no sense, but else a warning is made by*/
               /* the WATCOM compiler concerning a missing return value*/
}/*endfunc getFieldNameList*/


/*****************************************************************************
// Functions to print the contents of RecordHeadT and FieldHeadT.
//
 *****************************************************************************/
void printRecordHeadT(MatrixPT recordVar)
{
  RecordHeadPT	rh;
  int m,n;
  unsigned long int mn;

  rh = (RecordHeadT*)mxGetPr(recordVar);
  m = mxGetM(recordVar);
  n = mxGetN(recordVar);
  mn = ((ULIntT)m) * ((ULIntT)n);

  if ( ! isRecordVar(recordVar))
    mexPrintf("Warning: This is not a record variable.\n");
  mexPrintf("RecordHeadT. Addr= %p. 1st addr after pr-block = %p\n", rh, 
    (FieldHeadT*)((Int32T)rh + (Int32T)(mn*sizeOfFM)));
  mexPrintf("  introNaN = %g. type = %d. version = %d.\n", rh->introNaN, 
    rh->type, rh->version);
  mexPrintf("  M = %d. N = %d. M*N = %lu sizeOfFM = %lu bytes.\n", m, n, mn, 
    mn*sizeOfFM );
  mexPrintf("  firstFieldRptr = %lu (%lx hex). Addr 1st field = %p.\n", 
    (ULIntT)(rh->firstFieldRPtr), (ULIntT)(rh->firstFieldRPtr), 
    getFirstField(recordVar));
  /* mexPrintf("\n"); */
}


void printFieldHeadT(FieldHeadPT fh)
{
  unsigned long int m,n,mn, allocSize;

  m = fh->m;
  n = fh->n;
  mn = ((ULIntT)m) * ((ULIntT)n);
  allocSize = (ULIntT)getFieldAllocSize(fh);

/*  mexPrintf("FieldHeadT. Addr= %p. 1st addr after field = %p\n", fh, (FieldHeadT*)((Int32T)fh + (Int32T)(mn*sizeOfFM) + (Int32T)sizeof(FieldHeadT))); */
  mexPrintf("FieldHeadT. Addr= %p. Addr next empt field = %p\n", fh, 
    getNextEmptyField(fh));
  mexPrintf("  name = '%s'. mType = %u. displayMode = %s.\n", getFieldName(fh), 
    (unsigned int)getFieldmType(fh), getFieldDisplayMode(fh));
  mexPrintf("  m = %lu. n = %lu. m*n = %lu sizeOfFM = %lu bytes.\n", m, n, mn, 
    mn*sizeOfFM);
  mexPrintf("  allocSize = %lu sizeOfFM = %lu bytes.\n", allocSize, 
    allocSize*sizeOfFM);
  mexPrintf("  rpr = %lu (%lx hex). Addr = %p.\n",
    (ULIntT)getFieldRelativePr(fh), (ULIntT)getFieldRelativePr(fh),
    getFieldPr(fh));
  mexPrintf("  rpi = %lu (%lx hex). Addr = %p.\n", 
    (ULIntT)getFieldRelativePi(fh), (ULIntT)getFieldRelativePi(fh),
    getFieldPi(fh));
  mexPrintf("  nextFieldRPtr = %lu (%lx hex). Addr next field = %p.\n", 
    (ULIntT)getNextFieldRelativePtr(fh), (ULIntT)getNextFieldRelativePtr(fh), 
    getNextField(fh));
  if (allocSize != mn) mexPrintf("Warning: allocSize != m*n .\n");
}


const UInt16T maxPrintFields = 100;

void printAllHead(MatrixPT recordVar)
{
  FieldHeadPT field;
  UInt16T n;

  printRecordHeadT(recordVar);
  if (isRecordVar(recordVar))
  {
    field = getFirstField(recordVar);
    n = 1;
    while (field != NULL)
    {
      if (n > maxPrintFields) 
        mexPrintf("Warning: More than %d fields. Probably an error. "
	  "Stopping the printout.\n");
      printFieldHeadT(field);
      field = getNextField(field);
      n++;
    }/* endwhile */
    mexPrintf("\n");
  } /* endif */
} /* endfunc */




/*****************************************************************************
   Funktioner fr att .
 *****************************************************************************/


/*=========================================================================
  Tilldelar ett flt i en postvariabel.
=========================================================================*/
#define RECORDVAR	pekInParam[0]
#define FIELDNAME	pekInParam[1]
#define FIELDVAR	pekInParam[2]
#define UTMATRIS	pekUtParam[0]

void setRecord(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
		 Matrix *pekInParam[])
{
  char* 	fieldname;
  FieldHeadT*   searchedOldField;
  SizeFMT	searchedOldFieldAllocSize;
  SizeFMT	newFieldHeadSize;
  FieldHeadT*	oldField;
  FieldHeadT*	newField;
  FieldHeadT*	newFieldBefore;
  SizeFMT	msize;		/* Storlek p pr-blocket i antal 8-bytes */
  SizeFMT	rsize;		/* Size of the RecordHead in multiples 
				   of 8 bytes */
  SizeFMT	fsize;		/* Size of the FieldHead in multiples 
				   of 8 bytes */

  checkAntalInParam(antalInParam, 3, 3);
  checkParamStrang(FIELDNAME);
  getMatlabString(FIELDNAME, &fieldname);
  checkAntalUtParam(antalUtParam, 1, 1);

/* removed by AG 961112 to suit WATCOM.
  if ((sizeof(RecordHeadT) % sizeOfFM) != 0)
     mexErrMsgTxt("sizeof(RecordHeadT) is not an multiple of sizeOfFM.");
*/
/* Removed by svabj 961113. This test should be unnecessary and can cause problems on some systems.
  if ((sizeof(FieldHeadT) % sizeOfFM) != 0)
	mexErrMsgTxt("sizeof(FieldHeadT) is not an multiple of sizeOfFM.");
*/  
  if (isEmptyMatlabMatrix(RECORDVAR))
  {
    
    /* Calculate the size of the new Matlab record variable and allocate
       the new record variable. */
  
    /* rsize = (sizeof(RecordHeadT) % sizeOfFM) 
	? sizeof(RecordHeadT) / sizeOfFM 
	: sizeof(RecordHeadT) / sizeOfFM + 1; */

    if ((sizeof(RecordHeadT) % sizeOfFM) == 0)
      rsize = sizeof(RecordHeadT) / sizeOfFM;
    else
      rsize = sizeof(RecordHeadT) / sizeOfFM + 1;
    fsize = sizeof(FieldHeadT) / sizeOfFM;
    msize =  rsize + fsize + dataSizeMatlabMatrix(FIELDVAR);
    UTMATRIS = createRecordVar(msize);

    /* Copy the the field to the Matlab Variable. */
    newField = getFirstEmptyField(UTMATRIS);
    copyMatlabMatrix2Field(FIELDVAR, newField, fieldname);	
    /* Copy the field to the new Matlab variable. */
    setFirstFieldRPtr(UTMATRIS, newField);
  }
  else if(isRecordVar(RECORDVAR))
  {
      	/* Tar reda p pekare och storlek till aktuellt flt om det existerar.*/
 	searchedOldField = searchFieldName(RECORDVAR,fieldname); 
  	if (searchedOldField == NULL)	/* The field did not exist earlier. */
  	{
	  searchedOldFieldAllocSize = 0;
          newFieldHeadSize = sizeof(FieldHeadT) / sizeOfFM;
  	}
  	else 	/* The field did exist earlier. */
  	{
	  searchedOldFieldAllocSize = getFieldAllocSize(searchedOldField);
	  newFieldHeadSize = 0;
  	}

  	/* Calculate the size of the new Matlab record variable and allocate
  	   the new record variable. */
  	msize = (mxGetM(RECORDVAR) * mxGetN(RECORDVAR)) 
          	- searchedOldFieldAllocSize
 		+ newFieldHeadSize
          	+ dataSizeMatlabMatrix(FIELDVAR);
        /* Did not use dataSizeMatlabMatrix for RECORDVAR in case this 
           matrix is not a real full matrix. */
  	UTMATRIS = createRecordVar(msize);

  	/* Copy the new version of the searched field to the Matlab Variable. */
  	newField = getFirstEmptyField(UTMATRIS);
  	copyMatlabMatrix2Field(FIELDVAR, newField, fieldname);	
        /* Copy the new field to the new Matlab variable. */
  	setFirstFieldRPtr(UTMATRIS, newField);
  

  	/* Copy all fields exept for the old version of the searced field 
  	   from the old to the new Matlab Matrix. */
  	newFieldBefore = newField;
  	newField = getNextEmptyField(newField);
  	oldField = getFirstField(RECORDVAR);
  	while (oldField != NULL)
  	{
    	  if (oldField != searchedOldField) /* Don't copy the old version of the
	  				   searched field if it exists */
    	  {
	    copyField2Field(oldField, newField);
	    setNextFieldRPtr(newFieldBefore, newField);
     	    newFieldBefore = newField;
    	    newField = getNextEmptyField(newField);
    	  }
    	  oldField = getNextField(oldField);
  	} /*endwhile*/
  }
  else
  {
    mexErrMsgTxt("Can not change a matrix, which is not a record variable.");
  } /*endif*/  
} /* endfunc setRecord  */



/*=========================================================================
  Lser ett flt i en postvariabel.
=========================================================================*/
#define RECORDVAR	pekInParam[0]
#define FIELDNAME	pekInParam[1]
#define UTMATRIS	pekUtParam[0]

void getRecord(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
		 Matrix *pekInParam[])
{
  char* 	fieldname;
  FieldHeadT*	f;

  checkAntalInParam(antalInParam, 2, 2);
  checkParamStrang(FIELDNAME);
  getMatlabString(FIELDNAME, &fieldname);
  checkAntalUtParam(antalUtParam, 1, 1);

  if (isRecordVar(RECORDVAR))
  {  
    f = searchFieldName(RECORDVAR,fieldname);
    if (f != NULL)
    {
      UTMATRIS = copyField2MatlabMatrix(f);
      return;
    }
    else
    {
      mexErrMsgTxt("The field not found.");
     /*
      UTMATRIS = createEmptyFullMatlabMatrix();
      return;
     */
    };
  }
  else
  {
    mexErrMsgTxt("Can not get a field from a non-record variable.");
  }/*endif*/
} /* endfunc getRecord */



/*=========================================================================
=========================================================================*/
#define RECORDVAR	pekInParam[0]
#define FIELDNAME	pekInParam[1]
#define UTMATRIS	pekUtParam[0]

void existField(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
  char* 	fieldname;
  FieldHeadT*	f;

  checkAntalInParam(antalInParam, 2, 2);
  checkParamStrang(FIELDNAME);
  getMatlabString(FIELDNAME, &fieldname);
  checkAntalUtParam(antalUtParam, 1, 1);

  UTMATRIS = mxCreateFull(1, 1, REAL); 
  if (UTMATRIS == NULL) mexErrMsgTxt("Out of memory in isRecVar()");

  if (isRecordVar(RECORDVAR))
  {  
    f = searchFieldName(RECORDVAR,fieldname);
    (*mxGetPr(UTMATRIS)) = (FloatMatlabT) (f != NULL);
  }
  else
  {
    mexErrMsgTxt("Can not get a field from a non-record variable.");
  }/*endif*/

}/*endfunc */



/*=========================================================================
  Returnerar en lista i en Matlab-variabel med fltnamnen hos en postvariabel.
=========================================================================*/
#define RECORDVAR	pekInParam[0]
#define UTMATRIS	pekUtParam[0]

void recDir(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
		 Matrix *pekInParam[])
{
  char**	dirlista;
  int 		nFields;

  checkAntalInParam(antalInParam, 1, 1);
  checkAntalUtParam(antalUtParam, 1, 1);
  dirlista = getFieldNameList(RECORDVAR, &nFields);
  if (dirlista == NULL)
  {
	UTMATRIS = createEmptyFullMatlabMatrix();
	return;
  }
  else
  {
  	UTMATRIS = createMatlabStringList(dirlista, nFields);
	free(dirlista);
  }/*endif*/
} /* endfunc matDir */





/*=========================================================================
=========================================================================*/
#define RECORDVAR	pekInParam[0]

void showFields(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
		 Matrix *pekInParam[])
{
  char**	dirlista;
  int 		nFields;
  int 		n;
  FieldHeadT*	f;

  checkAntalInParam(antalInParam, 1, 1);
  dirlista = getFieldNameList(RECORDVAR, &nFields);
  mexPrintf("%s:\n", mxGetName(RECORDVAR));
  if (dirlista == NULL)
  {
    mexPrintf(" No fields.\n");
    return;
  }
  else
  {
    for (n=0; n < nFields; n++)
    {
      mexPrintf(" %s = \n",dirlista[n]);
      f = searchFieldName(RECORDVAR,dirlista[n]);
      if (f == NULL) mexErrMsgTxt("Internal error in showFields().");
      /*mexPrintf("                ");*/
      printMatlabMatrix(copyField2MatlabMatrix(f));
      mexPrintf("\n");
    }
    free(dirlista);
  }; /* endif */ 
}/*endfunc */


/*=========================================================================
=========================================================================*/
#define RECORDVAR	pekInParam[0]

void showWhosr(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
		 Matrix *pekInParam[])
{
  char**	dirlista;
  int 		nFields;
  int 		n;
  FieldHeadT*	f;
  ULIntT	totElem = 0;
  ULIntT	totBytes = 0;

  checkAntalInParam(antalInParam, 1, 1);
  dirlista = getFieldNameList(RECORDVAR, &nFields);
  mexPrintf("%s:\n", mxGetName(RECORDVAR));
  mexPrintf("%15s %12s %9s %3s %7s %8s %8s %8s \n\n","Name","Type","Size"," ","Elements","Bytes","Density","Complex");
  if (dirlista == NULL)
  {
    mexPrintf(" No fields.\n");
    return;
  }
  else
  {
    for (n=0; n < nFields; n++)
    {
      f = searchFieldName(RECORDVAR,dirlista[n]);
      if (f == NULL) mexErrMsgTxt("Internal error in showWhosr().");
      mexPrintf("%15s ",dirlista[n]);
      mexPrintf("%12s "," ");
      mexPrintf("%5lu by %-5lu ",(ULIntT)f->m, (ULIntT)f->n);
      mexPrintf("%7lu ",(ULIntT)(f->m * f->n));
      mexPrintf("%8lu ", (ULIntT)(f->m * f->n * sizeOfFM));
      mexPrintf("%8s "," ");
      if (isComplexField(f))
        mexPrintf("   Yes   ");
      else
        mexPrintf("   No    ");
      mexPrintf("\n");
      totElem += (ULIntT)(f->m) * (ULIntT)(f->n);
      totBytes += (ULIntT)(f->m) * (ULIntT)(f->n * sizeOfFM);
    }
    free(dirlista);
    mexPrintf("\nGrand total is %d elements using %d bytes\n\n", totElem, totBytes);

  }; /* endif */ 
}/*endfunc */




/*=========================================================================
=========================================================================*/
#define RECORDVAR	pekInParam[0]
#define UTMATRIS	pekUtParam[0]


void isRecVar(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
    checkAntalInParam(antalInParam, 1, 1);
    checkAntalUtParam(antalUtParam, 1, 1);
    UTMATRIS = mxCreateFull(1, 1, REAL); 
    if (UTMATRIS == NULL) mexErrMsgTxt("Out of memory in isRecVar()");
    (*mxGetPr(UTMATRIS)) = (FloatMatlabT) isRecordVar(RECORDVAR);
}/*endfunc */



/*=========================================================================
=========================================================================*/
#define RECORDVAR	pekInParam[0]

void printHead(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
    checkAntalInParam(antalInParam, 1, 1);
    checkAntalUtParam(antalUtParam, 1, 1);
    printAllHead(RECORDVAR);
}/*endfunc */


/*=========================================================================
=========================================================================*/
#define UTMATRIS	pekUtParam[0]

void recVersion(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
    checkAntalInParam(antalInParam, 0, 0);
    checkAntalUtParam(antalUtParam, 1, 1);
    UTMATRIS = mxCreateString(rcsid);
    if (UTMATRIS == NULL) mexErrMsgTxt("Out of memory in recVersion()");
}/*endfunc */




/*****************************************************************************
// Functions for implementing multidimensional matrices.
 *****************************************************************************/

/* const int antalIndexVektorer = 6;  removed by AG. Changed to #define (Standard C) */
#define ANTAL_INDEXVEKTORER 6


/*=========================================================================
=========================================================================*/
void getNoIndexHlp(UInt32T* noIndexOut1, UInt32T* noIndexOut2, 
	           int antalIndexVekt, UInt32T antalIndex[])
{
  BoolT klar1;
  BoolT klar2;
  int n;

  /* Check that not more than two indices are vectors. */
  klar1 = FALSK;
  klar2 = FALSK;
  (*noIndexOut1) = 1;
  (*noIndexOut2) = 1;

  for (n = 0; n < antalIndexVekt; n++)
  {
    if ((antalIndex[n] > 1) && (klar1==FALSK))
    {
      (*noIndexOut1) = antalIndex[n];
      klar1 = SANN;	
    }
    else if ((antalIndex[n] > 1) && (klar1==SANN) && (klar2==FALSK))
    {
      (*noIndexOut2) = antalIndex[n];
      klar2 = SANN;	
    }
    else if ((antalIndex[n] > 1) && (klar2==SANN))
    {
      mexErrMsgTxt("More than two indices are vectors.");
    };
  }
}



/*=========================================================================
=========================================================================*/
#define SIZEMM		pekInParam[0]
/* #define INDEX1		pekInParam[1] */
#define NO_INDEX_OUT1	pekUtParam[0]
#define NO_INDEX_OUT2	pekUtParam[1]


void getNoIndex(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
  const ixStart = 1;		/* pekInParam[1] = INDEX1 */
  UInt32T antalIndex[ANTAL_INDEXVEKTORER];
  UInt32T antalIndex1;
  UInt32T antalIndex2;
  MatrixPPT  inPek;
  int n;

  checkAntalInParam(antalInParam, ANTAL_INDEXVEKTORER+ixStart, ANTAL_INDEXVEKTORER+ixStart);
  checkAntalUtParam(antalUtParam, 2, 2);
  if (mxGetN(SIZEMM) != ANTAL_INDEXVEKTORER)
    mexErrMsgTxt("Wrong number of indices.");

  inPek = pekInParam+ixStart;
  for (n=0; n< ANTAL_INDEXVEKTORER; n++)
  {
    antalIndex[n] = mxGetN(*inPek);
    inPek++;
  }

  getNoIndexHlp(&antalIndex1, &antalIndex2, ANTAL_INDEXVEKTORER, antalIndex);
  createMatlabSkalar(&NO_INDEX_OUT1, antalIndex1);
  createMatlabSkalar(&NO_INDEX_OUT2, antalIndex2);

}/*endfunc */



/*=========================================================================
=========================================================================*/
#define SIZEMM		pekInParam[0]
/* #define INDEX1		pekInParam[1] */
#define UTMATRIS	pekUtParam[0]


void expandIx(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
  const ixStart = 1;		/* pekInParam[1] = INDEX1 */
  int 		n;
  FloatMatlabPT indexPr[ANTAL_INDEXVEKTORER];
  FloatMatlabPT indexPrEnd[ANTAL_INDEXVEKTORER];
  UInt32T   	index[ANTAL_INDEXVEKTORER];
  UInt32T	antalIndex[ANTAL_INDEXVEKTORER];
  UInt32T 	antalIndex1;
  UInt32T 	antalIndex2;
  UInt32T   	blockSize[ANTAL_INDEXVEKTORER+1]; /* The last element is not used
					        but needed in the loop below. */
  UInt32T   	sum;
  MatrixPPT	inPek;
  FloatMatlabPT sizePek;
  FloatMatlabPT outPr;

  checkAntalInParam(antalInParam, ANTAL_INDEXVEKTORER+ixStart, ANTAL_INDEXVEKTORER+ixStart);
  checkAntalUtParam(antalUtParam, 1, 1);
  if (mxGetN(SIZEMM) != ANTAL_INDEXVEKTORER)
    mexErrMsgTxt("Wrong number of indices.");

  blockSize[0] = 1;
  inPek = pekInParam+ixStart;
  sizePek = mxGetPr(SIZEMM);

  for (n=0; n<ANTAL_INDEXVEKTORER; n++)
  {
    antalIndex[n]  = mxGetN(*inPek);
    blockSize[n+1] = blockSize[n] * (UInt32T)(*sizePek);
    indexPrEnd[n]  = mxGetPr(*inPek) + antalIndex[n];
    inPek++;
    sizePek++;
  }

  getNoIndexHlp(&antalIndex1, &antalIndex2, ANTAL_INDEXVEKTORER, antalIndex);
  UTMATRIS = mxCreateFull(1, antalIndex1 * antalIndex2, REAL); 
  if (UTMATRIS == NULL) mexErrMsgTxt("Out of memory in expandIx()");
  outPr = mxGetPr(UTMATRIS);

  /* Loopa genom alla indexvektorer. */
  /* inPek = pekInParam+ixStart; */
  for (indexPr[5] = mxGetPr(pekInParam[ixStart + 5]); indexPr[5] < indexPrEnd[5]; indexPr[5]++)
  {
      index[5] = (UInt32T)(*indexPr[5]);
      for (indexPr[4] = mxGetPr(pekInParam[ixStart + 4]); indexPr[4] < indexPrEnd[4]; indexPr[4]++)
      {
          index[4] = (UInt32T)(*indexPr[4]);
          for (indexPr[3] = mxGetPr(pekInParam[ixStart + 3]); indexPr[3] < indexPrEnd[3]; 
	       indexPr[3]++)
      	  { 
              index[3] = (UInt32T)(*indexPr[3]);
              for (indexPr[2] = mxGetPr(pekInParam[ixStart + 2]); indexPr[2] < indexPrEnd[2]; 
		   indexPr[2]++)
              {
                  index[2] = (UInt32T)(*indexPr[2]);
                  for (indexPr[1] = mxGetPr(pekInParam[ixStart + 1]); indexPr[1] < indexPrEnd[1]; 
		       indexPr[1]++)
                  {
                      index[1] = (UInt32T)(*indexPr[1]);
                      for (indexPr[0] = mxGetPr(pekInParam[ixStart + 0]); indexPr[0] < indexPrEnd[0]; 
		           indexPr[0]++)
                      {
                        index[0] = (UInt32T)(*indexPr[0]);

		        sum = 0;
  		        for (n=0; n<ANTAL_INDEXVEKTORER; n++)
  		        {
    			  sum += (index[n]-1)*blockSize[n];
  		        }
		        (*outPr) = (FloatMatlabT)(sum+1);
		        outPr++;

                    } /* endfor indexPr[0] */
                  } /* endfor indexPr[1] */
              } /* endfor indexPr[2] */
          } /* endfor indexPr[3] */
      } /* endfor indexPr[4] */
  } /* endfor indexPr[5] */

}/*endfunc expandIx */



/*****************************************************************************
//
 *****************************************************************************/

/*=========================================================================
// A test function. Can be filled with any contents that you wish. Can also be removed.
=========================================================================*/
#define RECORDVAR	pekInParam[0]

void testr(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
	      	Matrix *pekInParam[])
{
   FieldHeadPT f;
   /* f = 0x123; */
   f = getFirstField(RECORDVAR);
   assert(isFieldHead(f), accessFieldErrMsg);
}/*endfunc */



/*****************************************************************************
//
 *****************************************************************************/

/*=========================================================================
  mexFunction : Anropspunkt frn Matlab.
=========================================================================*/

#define KOMMANDO	pekInParam[0]

void mexFunction(int antalUtParam, Matrix *pekUtParam[], int antalInParam, 
		 Matrix *pekInParam[])
{
  char* kommando;
  checkParamStrang(KOMMANDO);
  getMatlabString(KOMMANDO, &kommando);

  if (!strcmp(kommando,"setr")) 
	setRecord(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"getr")) 
	getRecord(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"existr"))
	existField(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"recdir")) 
	recDir(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"showr")) 
	showFields(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"whosr")) 
	showWhosr(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"isrecvar")) 
	isRecVar(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"prheadr")) 
	printHead(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"versionr")) 
	recVersion(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"getnoix")) 
	getNoIndex(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"expandix")) 
	expandIx(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"testr")) 
	testr(antalUtParam, pekUtParam, antalInParam-1, pekInParam+1);
  else if (!strcmp(kommando,"sizer")) 
	/* Ingenting */;
  else if (!strcmp(kommando,"copyr")) 
	/* Ingenting */;
  else if (!strcmp(kommando,"typeofr")) 
	/* Ingenting */;
  else if (!strcmp(kommando,"nothing")) 
	/* Ingenting */;
  else
	mexErrMsgTxt("Internal error. The function doesn't exist");
  return;
}/* endfunc mexFunction */
