% *****************************************************************************
% RECVAR, A package for new data types in Matlab. 
% (c) FOA 1998. See the file rvright.m for copyright notice.
%
% 	Multidimensional matrices in RECVAR
% 	-----------------------------------
%
% A multidimentional matrix, "multimatrix" is a matrix with more than
% two indices. There is no direct way to access more than two dimensions
% in MATLAB 4. In Matlab 5 there exist multimatrices.
%
% Ex:)
%	>> MM = zerosm([2 2 2]);			% Create a 2*2*2 matrix.
%       >> MM = setm(MM,[1 2; 3 4], 1:2, ':', 1);	% Fill the multimatrix.
%       >> MM = setm(MM,[5 6; 7 8], ':', ':', 2);	% Fill the multimatrix.
%       >> getm(MM, ':', ':', 1)
%       ans =
%	     1     2
% 	     3     4
%       >> getm(MM, 2 ,1:2 ,':')'
%       ans =
%	     3     4
%	     7     8
%       >> getm(MM, ':', 2, ':')
%       ans =
%	     2     6
%	     4     8
%       >> getm(MM, 1, 2, ':')
%       ans =
%	     2
%	     6
%       >> 
%
% The following functions are currently implemented:
%
%	zerosm	: To create an multimatrix. Should always be used first.
%	setm	: To assign a scalar, a vector or a two dimensional matrix to
%		  a part of a multimatrix.
%	getm	: To get a scalar, a vector or a two dimensional matrix from
%		  a part of a multimatrix.
%	getm2	: Like getm but behaviour same as squeeze(A(...)) in Matlab 5.
%	sizem	: Returns the size of a multimatrix.
%	reshapem: Like reshape but for multimatrices.
% 	ismulmat: Returns true if the argument is a multimatrix.
%
% For more information about the functions use 'help' for the corresponding 
% function. 
%
%Matlab 4:
%---------
% It is possible to get slices of the multimatrix in different dimensions.
% The multimatrices can only contain complex numbers, no other datatypes. 
% Presently there is a limit of six dimensions.
% Sparse multimatrices are not implemented. 
% 
% There are the same restrictions on the allowed operations on a multimatrix as
% on a record variable, since multimatrices are implemented using record 
% variables. See help recvar.
%
%Matlab 5:
%---------
% recvars multimatrices are implemented using Matlab 5's multidimensional 
% matrices, see [1].
%
%Other data structures in RECVAR:
%--------------------------------
% Use 'help recvar' for information record type variables.
% Use 'help listhelp' for information about the data structure "list".
%
%References:
% [1] "Using Matlab Version 5", The MathWorks, Inc., 1997. 
% *****************************************************************************

%  Start        : 96xxxx Svante Bjrklund (svabj).
%  Latest change: $Date: 1998/05/12 10:42:07 $ $Author: svabj $.
%  $Revision: 2.10 $
