function dbtex1

%DBTEX1 An example of a main program using MUSIC and conventional beamforming on simulated signals from an ULA.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 951221 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:42 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %

lambda	= 0.03;			% wavelength.
D 	= 0.45*lambda;		% Element separation.
T 	= 24;			% Number of snapshots.
K 	= 12;			% Number of digital antenna channels.

theta	= d2r([25 32])';	% Target angles. The number of targets is
				%  given by the number of target angles.
phi	= zeros(size(theta));	% Target angles.
SNR	= [10 5]';		% Signal to noise ratio in dB at each
				%  antenna element!?!
alpha	= d2r([0 16])';		% Start phases of the target signals.
dalpha	= d2r([34 -13])';	% A constant phase shift between snapshots.
				%  Means targets movements at constant velocity.
dist=Inf*ones(size(theta));	% Distances to the sources.			
tgtModel      	= 'const';	% Target type to simulate.
noiseModel     	= 'rndnw';	% Noise type to simulate.
%noiseModel     	= 'rndn';	% Noise type to simulate.
MMu	= 2;			% Number of targets that MUSIC believes in.


% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

ant = defant('isotropULA',[K,D]);		% Define the antenna.

sig = compsim4(ant, lambda, T, tgtModel, [theta, ...
  phi, SNR, alpha, dalpha, dist, ...		% Generate simulated received
  eye(size(theta,1))], noiseModel, eye(K)); 	% antenna signals.


spect1 = sdoaspc('music',sig,[],MMu);		% Estimate the DOA-spectrum
						%  with MUSIC.

R = ecorrm(sig);				% Estimate the antenna signals
						%  correlation matrix.

spect2 = sdoaspc('cbf',R);			% Estimate the DOA-spectrum
						%  with conventional beamform.
spect3 = sdoaspc('eigvec',R);			% Estimate the DOA-spectrum
spect4 = sdoaspc('pisa',R);			% Estimate the DOA-spectrum

figure,splot2(spect1,'',spect2,'',spect3,'',spect4) % Plot all DOA-spectrums.
legend('Music','Conventional beamforming','Eigenvector method','Pisarenko')

%printfm dbtex1a.eps [] 12
