%DBTEX10 An example of beamforming on measured data from the AIMT experimental antenna with calibration compensation on the signals.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 970615 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:43 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
			
MMu	= 3;			% Number of targets that MUSIC believes in.
doaStart = d2r([-5 0 5]);	% Start angles for parametric DOA-estimation.

% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Define the antenna.
ant = defant('expAnt');

% Read the received antenna signals.
sig = expsig1(ant,'dbtex.dbs',1);

% Compensate the signals for coupling but not for near field.
% Estimate a DOA-spectrum. The signal is compensated.
% Estimate the peaks of the spectrum.
sig2 = sigcomp2(sig,'dbtex.dbc','Ccmp',[],'nocomp',0);
setcal1('nocomp','dbtex.dbc','nearfldcomp')
spect1 = sdoaspc('music',sig2,d2r(-30:0.25:30),MMu);
disp('The signal is compensated.')
r2d(doapeak(spect1,'amir',MMu))

% Estimate a new DOA-spectrum and the peaks. The steering matrix is compensated.
setcal1('Ccmp','dbtex.dbc','nearfldcomp')
spect2 = sdoaspc('music',sig,d2r(-30:0.25:30),MMu);
disp('The steering matrix is compensated.')
r2d(doapeak(spect2,'amir',MMu))


% Plot all DOA-spectrums.
splot2(spect1,'',spect2, '')
legend('Signal compensated','Steering matrix compensated')

% printfm dbtex10a.eps [] 12
