%DBTEX15 An example of plotting antenna diagrams.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 980108 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:44 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

%Example 1:
%  This example shows an antenna pattern without and with adaptive
%  sidelobe cancellation.
  figure
  thetaDeg = [40 60];
  theta  = d2r(thetaDeg).';
  lambda =  0.03;
  ant = defant('isotropULA',[12, 0.45*lambda]);   % Define antenna.
  sigJam = compsim4(ant, lambda, 240, 'const', [theta,zeros(size(theta)),...
    [75 75]', d2r([0 16])', d2r([34 -13])', Inf*ones(size(theta)), ...
    eye(size(theta,1))], 'rndn', eye(12));
      % Generate simulated jammer signals
  Rjam = ecorrm(sigJam);
  hold on
  pantpat3(ant, d2r(10), [],[], 'taylor', 30,[],[],lambda, [],[],[], ...
    [],[],[],'r--')
    % Without adaptive sidelobe cancellation.
  pantpat3(ant, d2r(10), [],[], 'taylor', 30, Rjam, ...
    [], lambda,[],[],[], ...
    [],[],[],'b-')
    % With adaptive sidelobe cancellation.
  %plotxline(thetaDeg,'m','-.')
  legend('Without SLC', 'With SLC','Jammer DOA')
  ylim([-80 0])
  hold off


%Example 2:
%  This example shows how the pattern of subarrays and elements can
%  be plotted.
  lambda =  0.1;
  ant = defant('aimtEx');
  figure, hold on
  pantpat3(ant,[],[],[],[],[],[],[],lambda)
  subarr = ant.element;
  pantpat3(subarr, [], [], [], [], [], [], [], lambda, [], [], [],[], ...
    [], [], 'r--')
  elem = subarr.element;
  pantpat3(elem, [], [], [], [], [], [], [], lambda, [], [], [],[], ...
    [], [], 'm-.')
  legend('Total', 'Subarrays', 'Elements')

%Example 3:
%  This example shows two different polar plots. A user defined tapering
%  is used.
  lambda =  0.03;
  tap = cos(([-5.5:1:5.5].')./(5.5)*(pi/2)).^2;
    % A cos^2 tapering
  ant = defant('isotropULA',[12, 0.5*lambda]);
  figure
  s1 = pantpat3(ant, d2r(30), 0, [], 'user', tap, [], [], lambda, ...
    [],[],-70,[],[],'polar');
  figure
  s1 = pantpat3(ant, d2r(30), 0, [], 'user', tap, [], [], lambda, ...
    [],[],-70,[],[],'lppolar',[],[0,-60, 6,pi/2,-pi/2,6]);

% printfm dbtex15a1.eps 1
% printfm dbtex15a2.eps 2
% printfm dbtex15a3.eps 3
% printfm dbtex15a4.eps 4
