function dbtex2

%DBTEX2 An example with coherent signals. Music that can't handle coherent signals is used.

%
%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 951221 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:45 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
lambda	= 0.03;			% wavelength.
D 	= 0.45*lambda;		% Element separation.
T 	= 24;			% Number of snapshots.
K 	= 12;			% Number of digital antenna channels.

theta	= d2r([25 35])';	% Target angles. The number of targets is
				%  given by the number of target angles.
phi	= zeros(size(theta));	% Target angles.
SNR	= [10 5]';		% Signal to noise ratio in dB at each
				%  antenna element!?!
alpha	= d2r([0 0])';		% Start phases of the target signals.
dalpha	= d2r([0 0])';	% A constant phase shift between snapshots.
				%  Means targets movements at constant velocity.
dist=Inf*ones(size(theta));	% Distances to the sources.
			
tgtModel      	= 'rndn';	
noiseModel     	= 'rndn';	

MMu	= 2;			% Number of targets that MUSIC believes in.


% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Define the antenna.
ant = defant('isotropULA',[K,D]);

% Generate simulated received antenna signals.
sig = compsim4(ant, lambda, T, tgtModel, [theta, phi, SNR, alpha, dalpha, dist, ones(size(theta,1))], noiseModel, eye(K));

% Estimate the antenna signals correlation matrix.
R1 = ecorrm(sig);
R2 = ecorrm(R1,'spatsmooth',[],[],10);
R3 = ecorrm(R1,'forback');


% Estimate the DOA-spectrum with MUSIC.
spect1 = sdoaspc('music',R1,[],MMu);
spect2 = sdoaspc('music',R2,[],MMu);
spect3 = sdoaspc('music',R3,[],MMu);


% Plot both DOA-spectrums.
figure
splot2(spect1,'',spect2,'',spect3)
legend('Normal', 'Spatial smoothing', 'Forward-backward aver.')

%printfm dbtex2a.eps [] 12
