%DBTEX20 An example of using the radar signal simulator "simradarsig".

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
%  (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 98xxxx David Rejdemyhr (davrej).
%  Latest change: $Date: 2000/10/16 15:39:45 $ $Author: svabj $.
%  $Revision: 1.2 $
%*****************************************************************************

% Script for simradarsig.!

%clear all

% ----------------------------------------------------------------------- %
% Definition of the antenna.
% ----------------------------------------------------------------------- %

lambda  = 0.03;             % wavelength.
D   = 0.45*lambda;          % Element separation.
noChannels   = 12;          % Number of digital antenna channels.
recAnt = defant('isotropULA',[noChannels,D]);


% ----------------------------------------------------------------------- %
% Definition of the waveform.
% ----------------------------------------------------------------------- %

pri = 1e-3;
noPulses = 24;
noCPI = 1;
sampleTime = 1e-6;   % SubPulseLength [s]
noRangeBins = round(pri / sampleTime);
noRangeBins = 100; %I know this is not good! (two different values!!)
pModulation = getmod('barker','13');  % Barker-13 has sidelobes 1/13 of the main peak.
%pModulation =[];
waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);


% ----------------------------------------------------------------------- %
% Definition of the sources.
% ----------------------------------------------------------------------- %

%target = deftarget(trgType, trgPower, trgRange, trgDOA, trgVel);
trg1 = deftarget('swerling0', 10^1.2, 6000, [d2r(25); 0], 2);
trg2 = deftarget('swerling0', 10^0.6, 1000, [d2r(18); 0], -2);
trg3 = deftarget('swerling0', 10^0.8, 730000, [d2r(-3); 0], 0);

%noiseSrc = defnoise(noiseType, noisePower, corrMx);
noiseSrc1 = defnoise('Gaussian', 0.3, eye(noChannels));

%clutterdef = defclutter(clutterType, clutterTypeParam, clutterPower, clutterPatchDOAs, transAnt)
clutterSrc1 = defclutter('MIT-LCE', {6000 4 50}, 10, d2r(-30):0.01:d2r(30));

%srcDef = defsources(srcList, trgCorrMx)
sources = defsources({trg1 trg2 trg3 noiseSrc1 clutterSrc1}, eye(3));


% ----------------------------------------------------------------------- %
% Simulation of radar signals.
% ----------------------------------------------------------------------- %

radarSig = simradarsig(recAnt, sources, waveform, pri);


% ----------------------------------------------------------------------- %
% Signal processing and plotting.
% ----------------------------------------------------------------------- %

%----  Pulse compression ----

radarSig=pulscomp(radarSig,pModulation);
figure


%----  Conventional beamforming  ----

%ranAxis = (0:99)*150;
ranAxis = (1:80)*150;
%spaAxis = (-10:0.5:40);
spaAxis = (-10:1:40);
sigFinal = dbf(radarSig,d2r(spaAxis));


%----  Plotting the final signal  ----

sigplot2(sigFinal,1,13:92,:,{'ranAxis', ranAxis, 'spaAxis', spaAxis});
ylabel('Ranges [m]')
xlabel('Direction [degrees]')
title('Simulation of three targets, clutter and noise')
shading('interp')
set(gcf,'NumberTitle','off')
set(gcf,'Name','1: Simulation of three targets. Current view is the direction vs range domain.')
set(gcf,'MenuBar','none')

%----  Calculation of DOA spectra  ----

snapshots = [ getm3(radarSig.signals,3,[],':',53,':') ...
              getm3(radarSig.signals,3,[],':',19,':') ...
              getm3(radarSig.signals,3,[],':',83,':')];
R = basecorrm(snapshots, radarSig);   % Estimate the antenna signals
                                      % correlation matrix.
spect2 = sdoaspc('cbf',R);  % Estimate the DOA-spectrum
                            % with conventional beamforming.
spect1 = sdoaspc('music',R,[],5);    % Estimate the DOA-spectrum with MUSIC.

figure
splot2(spect1,'',spect2)  % Plot both DOA-spectrums.
legend('Music','Conventional beamforming')
xlabel('Direction [degrees]')
ylabel('')
title('Directional spectrum')
set(gcf,'NumberTitle','off')
set(gcf,'Name','2: Comparison between MUSIC and conventional beamforming')
set(gcf,'MenuBar','none')
patch([-7 -7 -98 -98],[47.5 59.5 59.5 47.5],'w')
text(-95,58,'Targets where placed in the directions:')
text(-95,56,'25, 18 and -3 [degrees]')
text(-95,53,'The three targets are fully resolved')
text(-95,51,'in the music spectra. The clutter is')
text(-95,49,'also visible near the direction 0 [degrees]')


% printfm dbtex20a1.eps 1 8
% printfm dbtex20a2.eps 2 8

%End Of File
