function dbtex21

%DBTEX21 An example of beamforming of radar signals.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
%  (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 98xxxx  Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:46 $ $Author: svabj $.
%  $Revision: 1.2 $
%*****************************************************************************

% Script for simradarsig.!

%clear all

% ----------------------------------------------------------------------- %
% Definition of the antenna.
% ----------------------------------------------------------------------- %

lambda  = 0.03;             % wavelength.
D   = 0.45*lambda;          % Element separation.
noChannels   = 12;          % Number of digital antenna channels.
recAnt = defant('isotropULA',[noChannels,D]);


% ----------------------------------------------------------------------- %
% Definition of the waveform.
% ----------------------------------------------------------------------- %

pri = 1e-3;
noPulses = 24;
noCPI = 1;
sampleTime = 1e-6;   % SubPulseLength [s]
noRangeBins = round(pri / sampleTime);
noRangeBins = 100;
pModulation = getmod('barker','13');  % Barker-13 has sidelobes 1/13 of the main peak.
%pModulation =[];
waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);


% ----------------------------------------------------------------------- %
% Definition of the sources.
% ----------------------------------------------------------------------- %

%target = deftarget(trgType, trgPower, trgRange, trgDOA, trgVel);
trg1 = deftarget('swerling0', 10^1.2, 6000, [d2r(25); 0], 2);
trg2 = deftarget('swerling0', 10^0.6, 1000, [d2r(18); 0], -2);
trg3 = deftarget('swerling0', 10^0.8, 730000, [d2r(-3); 0], 0);

%noiseSrc = defnoise(noiseType, noisePower);
noiseSrc1 = defnoise('Gaussian', 0.3, eye(noChannels));

%clutterdef = defclutter(clutterType, clutterTypeParam, clutterPower, clutterPatchDOAs, transAnt)
clutterSrc1 = defclutter('MIT-LCE', {6000 4 50}, 10, d2r(-30):0.01:d2r(30));

%srcDef = defsources(srcList, trgCorrMx)
sources = defsources({trg1 trg2 trg3 noiseSrc1}, eye(3));
%sources = defsources({trg1 trg2 trg3 noiseSrc1 clutterSrc1}, eye(3));


% ----------------------------------------------------------------------- %
% Simulation of radar signals.
% ----------------------------------------------------------------------- %

radarSig = simradarsig(recAnt, sources, waveform, pri);


% ----------------------------------------------------------------------- %
% Signal processing and plotting.
% ----------------------------------------------------------------------- %

%----  Pulse compression ----

radarSig=pulscomp(radarSig,pModulation);

%ranAxis = (0:99)*150;
ranAxis = (1:80)*150;


%----  Beamforming : Conventional beamforming ----

%spaAxis = d2r(-10:0.5:40);
spaAxis = [];

%sigFinal = dbf(radarSig,d2r(spaAxis));
sigFinal = beamform(radarSig,spaAxis,[],'taylor',50);
spaAxis = r2d(sigFinal.doaPos);


%----  Plotting the signal  ----
sigFinal
figure
sigplot2(sigFinal,1,13:92,':',{...
  'ranAxis', ranAxis, ...
  'spaAxis', spaAxis, ...
  'scaleType', 'lin'});
ylabel('Ranges [m]')
xlabel('Direction [degrees]')
title('Conventional beamforming, 50 dB Taylor')
%shading('interp')


%----  Beamforming : Fast Fourier Transform  ----

noBeams = 128;
sigFinal = spafilt(radarSig, 'fft', {radarSig.antenna, radarSig.waveform}, [], [], chebylp(noChannels,50), [], [], noBeams);
spaAxis = (1:noBeams);


%----  Plotting the signal  ----

figure
sigplot2(sigFinal,1,13:92,':',{...
  'ranAxis', ranAxis, ...
  'spaAxis', spaAxis, ...
  'scaleType', 'lin'});
ylabel('Ranges [m]')
xlabel('Direction [index]')
title('FFT 50 dB Cheby')
%shading('interp')


%----  Beamforming : Capon  ----

spaAxis = [];
sigFinal = spafilt(radarSig, 'capon', {radarSig.antenna, radarSig.waveform});
spaAxis = r2d(sigFinal.doaPos);


%----  Plotting the signal  ----

figure
sigplot2(sigFinal,1,13:92,':',{...
  'ranAxis', ranAxis, ...
  'spaAxis', spaAxis, ...
  'scaleType', 'lin'});
ylabel('Ranges [m]')
xlabel('Direction [degrees]')
title('Capon')
%shading('interp')


%End Of File
