%DBTEX22 An example of filtering in range (pulse compression) of radar signals by the function "ranfilt".

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
%  (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 98xxxx  Svante Bjrklund (svabj).
%  Latest change: $Date: 2001/08/31 14:33:53 $ $Author: svabj $.
%  $Revision: 1.2 $
%*****************************************************************************

%function dbtex22

% Script for simradarsig.!

%clear all

% ----------------------------------------------------------------------- %
% Definition of the antenna.
% ----------------------------------------------------------------------- %

lambda  = 0.03;             % wavelength.
D   = 0.45*lambda;          % Element separation.
noChannels   = 12;          % Number of digital antenna channels.
recAnt = defant('isotropULA',[noChannels,D]);


% ----------------------------------------------------------------------- %
% Definition of the waveform.
% ----------------------------------------------------------------------- %

pri = 1e-3;
noPulses = 24;
noCPI = 1;
sampleTime = 1e-6;   % SubPulseLength [s]
noRangeBins = round(pri / sampleTime);
noRangeBins = 100;
pModulation = getmod('barker','13');  % Barker-13 has sidelobes 1/13 of the main peak.
%pModulation =[];
waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);
ranBinLen = getranbinlen(waveform)


% ----------------------------------------------------------------------- %
% Definition of the sources.
% ----------------------------------------------------------------------- %

%target = deftarget(trgType, trgPower, trgRange, trgDOA, trgVel);
trg1 = deftarget('swerling0', 10^1.2, 6000, [d2r(25); 0], 2);
trg2 = deftarget('swerling0', 10^0.6, 5300, [d2r(18); 0], -2);
trg3 = deftarget('swerling0', 10^0.8, 6500, [d2r(13); 0], 0);
  % A range bin is 150 m.

%noiseSrc = defnoise(noiseType, noisePower);
noiseSrc1 = defnoise('Gaussian', 0.3);

%clutterdef = defclutter(clutterType, clutterTypeParam, clutterPower, clutterPatchDOAs, transAnt)
clutterSrc1 = defclutter('MIT-LCE', {6000 4 50}, 10, d2r(-30):0.01:d2r(30));

%srcDef = defsources(srcList, trgCorrMx)
sources = defsources({trg1 trg2 trg3 noiseSrc1});
%sources = defsources({trg1 trg2 trg3 noiseSrc1 clutterSrc1}, eye(3));


% ----------------------------------------------------------------------- %
% Simulation of radar signals.
% ----------------------------------------------------------------------- %

radarSig = simradarsig(recAnt, sources, waveform, pri);


% ----------------------------------------------------------------------- %
% Signal processing and plotting.
% ----------------------------------------------------------------------- %



%----  Beamforming : Conventional beamforming ----

%spaAxis = d2r(-10:0.5:40);
spaAxis = [];

%sigFinal = dbf(radarSig,d2r(spaAxis));
radarSig = beamform(radarSig,spaAxis,[],'taylor',50);
spaAxis = r2d(radarSig.doaPos);




%----  Conventional pulse compression ----

%radarSig1=pulscomp(radarSig,pModulation);
radarSig1 = ranfilt(radarSig,'aconv',[],{[], [], 'sparse'});

%ranAxis = (0:99)*150;
%ranIx = 1:noRangeBins;
ranIx = 25:55;
ranAxis = (ranIx)*150;


%----  Plotting the signal  ----

figure
sigplot2(radarSig1,1,ranIx,':',{...
  'ranAxis', ranAxis, ...
  'spaAxis', spaAxis, ...
  'scaleType', 'lin'});
ylabel('Ranges [m]')
xlabel('Direction [degrees]')
title('Conventional pulse compression')
%shading('interp')


%----  Capon in range ----

radarSig2 = ranfilt(radarSig,'capon',[],{[], [], 'sparse'});

%----  Plotting the signal  ----

figure
sigplot2(radarSig2,1,ranIx,':',{...
  'ranAxis', ranAxis, ...
  'spaAxis', spaAxis, ...
  'scaleType', 'lin'});
ylabel('Ranges [m]')
xlabel('Direction [degrees]')
title('Capon in range')
%shading('interp')



%End Of File
