%DBTEX3 An example with conventional beamformning and MUSIC on the AIMT application example.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 951221 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:49 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
lambda	= 0.1;			% wavelength.
T 	= 24;			% Number of snapshots.
%N 	= 12;			% Number of digital antenna channels.

theta	= d2r([5 10])';		% Target angles. The number of targets is
				%  given by the number of target angles.
phi	= zeros(size(theta));	% Target angles.
SNR	= [10 5]';		% Signal to noise ratio in dB at each
				%  antenna element!?!
alpha	= d2r([0 0])';		% Start phases of the target signals.
dalpha	= d2r([-5 14])';		% A constant phase shift between snapshots.
				%  Means targets movements at constant velocity.
dist=Inf*ones(size(theta,1),1);	% Distances to the sources.
			

MMu	= 2;			% Number of targets that MUSIC believes in.


% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Define the antenna.
ant = defant('aimtEx');

% Generate simulated received antenna signals.
sig = compsim4(ant, lambda, T, 'const', [theta, phi, SNR, alpha, dalpha, dist], 'rndnw');

% Estimate the DOA-spectrum with MUSIC.
spect1 = sdoaspc('music',sig,d2r([-90:0.5:90]),MMu);

% Estimate the antenna signals correlation matrix.
R = ecorrm(sig);

% Estimate the DOA-spectrum with conventional beamforming.
spect2 = sdoaspc('cbf',R);


% Plot both DOA-spectrums.
splot2(spect1,' ',spect2)
axis([-90 90 -30 50])
legend('Music','Conventional beamforming')

%printfm dbtex3a.eps [] 12
