%DBTEX4 An example testing PTMF with an ULA.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 951221 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:51 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
lambda	= 0.03;			% wavelength.
D 	= 0.45*lambda;		% Element separation.
T 	= 100;			% Number of snapshots.
K 	= 12;			% Number of digital antenna channels.

theta	= d2r([-5 0])';	% Target angles. The number of targets is
				%  given by the number of target angles.
phi	= zeros(size(theta));	% Target angles.
SNR	= [10 10]';		% Signal to noise ratio in dB at each
				%  antenna element!?!
alpha	= d2r([20 210])';		% Start phases of the target signals.
dalpha	= d2r([0 -10])';	% A constant phase shift between snapshots.
				%  Means targets movements at constant velocity.
dist=Inf*ones(size(theta));	% Distances to the sources.
			
tgtModel      	= 'const';	
noiseModel     	= 'rndn';	


% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Define the antenna.
ant = defant('isotropULA',[K,D]);

% Generate simulated received antenna signals.
sig = compsim4(ant, lambda, T, tgtModel, [theta, phi, SNR, alpha, dalpha, dist, eye(size(theta,1))], noiseModel, eye(K));

% Estimate direcktions and targets signals.
[edoa, sHat, Q, doaAll] = sdoapar1('ptmf', sig, d2r([-1 1]), 5*1e-3);

% Display the result.
pdoapar(edoa)
pdoait(doaAll)
perrfun(Q)

% Plot the Q-function.
pptmfq1(sig,2,100)
view(140,70)

% fig 1
% printfm dbtex4a1.eps
% fig 2
% printfm dbtex4a2.eps
% fig 3
% printfm dbtex4a3.eps
% fig 5
% printfm dbtex4a5.eps
