function run1

%DBTEX5 This example program demonstrates the conventional signal processing chain in the AIMT application example ('aimtEx').
%
%Known Bugs:
%  It is not clear whether this example resluts in correct graphs or not.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 9xxxxx Fredrik Athley (freath).
%  Latest change: $Date: 2000/10/16 15:39:52 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %

theta   = d2r([11 5].');       % Target angles.
phi     = zeros(size(theta));    % Target angles.
SNR     = [10]'*ones(size(theta));
alpha   = d2r(0)*ones(size(theta)); % Start phases of the target signals.
dalpha  = d2r([17 39].'); % A constant phase shift between
               % snapshots. Means targets movements
               % at constant velocity.
dist    =[Inf]*ones(size(theta));   % Distances to the sources.
PRF     = 8e3;
lambda  = 0.1;
noPulses    = 16;
noRangeBins =32;
%noTries     = 1;
beampos     = d2r(-15:3:15);  % Do conventional beamforming in these
            %  directions.

% ----------------------------------------------------------------------- %
% Definition of the receiver antenna.
% ----------------------------------------------------------------------- %

ant = defant('aimtEx');

% ----------------------------------------------------------------------- %
% Simulation of radar signals.
% ----------------------------------------------------------------------- %

sig = compsim5(ant, lambda, noPulses, noRangeBins, 'const', [theta, phi, ....
               SNR, alpha, dalpha,dist], 'rndnw');

% ----------------------------------------------------------------------- %
% Simulation of channel errors.
% ----------------------------------------------------------------------- %

sig = simcherr(sig,0.1,d2r(3),0.1);

% ----------------------------------------------------------------------- %
% Signal processing.
% ----------------------------------------------------------------------- %


% -------  Estimation of number of targets.  -------

noSrc = spanosrc(sig,'mdl',13,[],'plot')

% -------  Digital beamforming.  -------

fprintf('Before beamforming. ');
sigsize(sig);
sig = dbf(sig,beampos);
fprintf('\nAfter beamforming. ');
sigsize(sig);

% -------  Pulse compression.  -------

sig = pulscomp(sig);


% -------  Doppler filter bank.  -------

sig = dfb2(sig,PRF);

% Plot. Doppler index = 1, All range gates, All beams.
figure,sigplot2(sig,1,':',':', ...
  {'spaAxis', r2d(beampos)})
xlabel('Direction [degrees]')
title('After doppler filter')
figure,sigplot2(sig,':',13,':', ...
  {'spaAxis', r2d(beampos)})
xlabel('Direction [degrees]')
title('After doppler filter')


% -------  Video integration.  -------

sig = videoint(sig);
figure,sigplot2(sig,':',13,':', ...
  {'spaAxis', r2d(beampos)})
xlabel('Direction [degrees]')
title('After Video integration')


% -------  CFAR.  -------

sig = cfar(sig);
figure,sigplot2(sig,1,':',':', ...
  {'spaAxis', r2d(beampos)})
xlabel('Direction [degrees]')
title('After CFAR')
figure,sigplot2(sig,':',13,':', ...
  {'spaAxis', r2d(beampos)})
xlabel('Direction [degrees]')
title('After CFAR')



%q = sig.signals;
%q2=getm(q,1,':',':',1,1);
%surfl(abs(q2));colormap bone;view([-37 50])
%xlabel('beam position');ylabel('range gate')
