%DBTEX51 This example program demonstrates conventional radar signbal processing.
%Description:
%  The beamforming is done first.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 9xxxxx Fredrik Athley (svabj).
%  Latest change: $Date: 2000/10/16 15:39:53 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %

theta   = d2r([10 -40]');		% Target angles.
phi     = zeros(size(theta));	% Target angles.
SNR     = [0]'* ones(size(theta));			
alpha   = d2r([0]')* ones(size(theta));	% Start phases of the target signals.
dalpha  = d2r([60 -100]');		% A constant phase shift between snapshots.
				%  Means targets movements at constant velocity.
dist    =[Inf] * ones(size(theta));% Distances to the sources.
PRF     = 8e3;
lambda = 0.1;
noPulses    = 16;
noRangeBins = 25;
noTries     = 1;
beampos     = d2r(-60:10:60);	% Do conventional beamforming in these
				%  directions.
pm=3; pn=2; pnr=1;				
subplot(pm,pn,pnr)


% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Definition of the antenna.
ant = defant('isotropULA',[12, 0.45*lambda]);

% Simulation of signals
sig = compsim5(ant, lambda, noPulses, noRangeBins, 'const', [theta, phi, SNR, alpha, dalpha,dist], 'nonoise');

% Digital beamforming
fprintf('Before beamforming. ');
sigsize(sig);
sig = dbf(sig,beampos,theta);
fprintf('\nAfter beamforming. ');
sigsize(sig);
subplot(pm,pn,pnr),pnr=pnr+1;sigplot2(sig,1,':',':');title('After beamforming.')
subplot(pm,pn,pnr),pnr=pnr+1;sigplot2(sig,':',1,':');title('After beamforming.')

% Pulse compression.
sig = pulscomp(sig);
subplot(pm,pn,pnr),pnr=pnr+1;sigplot2(sig,1,':',':');title('After pulse compression.')
subplot(pm,pn,pnr),pnr=pnr+1;sigplot2(sig,':',1,':');title('After pulse compression.')

% Doppler filter bank
sig = dfb2(sig,PRF);
subplot(pm,pn,pnr),pnr=pnr+1;sigplot2(sig,1,':',':');title('After doppler filtering.')
subplot(pm,pn,pnr),pnr=pnr+1;sigplot2(sig,':',1,':');title('After doppler filtering.')

%printfm dbtex51a.eps 1 16
