%DBTEX7 An example of beamforming on measured data from the AIMT experimental antenna.

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 970607 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:56 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
			
MMu	= 3;			% Number of targets that MUSIC believes in.
doaStart = d2r([-5 0 5]);	% Start angles for parametric DOA-estimation.

% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Define the antenna.
ant = defant('expAnt');

% Set calibration compensation to use with sigcomp1, sdoaspc, sdoapar1 etc.
setcal1('wctab','dbtex.dbc')

% Read the received antenna signals.
sig = expsig1(ant,'dbtex.dbs',1, 65:128);

% Estimate the antenna signals correlation matrix.
R = ecorrm(sig);

% Estimate the DOA-spectrums.
% Note that the methods accept both the signals or the correlation matrix.
spect1 = sdoaspc('minnorm',R,d2r(-30:0.25:30),MMu);
spect2 = sdoaspc('capon',R,d2r(-30:0.25:30));
spect3 = sdoaspc('cbf',sig,d2r(-30:0.25:30));

% Plot DOA-spectrums.
splot2(spect1,'',spect2, '',spect3)
legend('Min-norm','Capon','Conventional beamforming')

% A parametric estimation of DOA.
edoa = sdoapar1('dml',sig, doaStart);

% Display the result.
pdoapar(edoa)

% printfm dbtex7a.eps  [] 12
