%DBTEX8 An example doing statistical analysis with the AIMT experimental antenna.
%Description:
%  At the moment the same SNR is used all the time.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 970612 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:39:58 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
doaStart = d2r([-3 -1 1]);

NtotSnap = 256;
Ntrial = 8;			% The number of avaiable snapshots is
				%  256 in dbtex.dbs.
				%  8 trials with 32 snapshots in
				%  each makes a total of 256 snapshots.
NSNRtrial = 2;			% Number of different SNR. Should be get
				%  from the data file.
SNRtrial = [1 2];               % The different SNR. Should be get
				%  from the data file.


% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

AngleIndexInDoaT = 1;

% Define the antenna.
ant = defant('expAnt');
setcal1('wctab','dbtex.dbc');

Ndoa = size(doaStart,2);
doaMean = zeros(NSNRtrial,Ndoa);
doaStdDev = zeros(NSNRtrial,Ndoa);

for nSNR =1:NSNRtrial
  fprintf('nSNR = %d\n',nSNR);
  edoaAll = [];
  %SNR = ones(size(doaStart,2),1) * SNRtrial(nSNR,1);
  for nTrial = 1:Ntrial
    fprintf('  nSNR = %d, nTrial = %d, Total = %d\n', nSNR, nTrial, ...
      (nSNR-1)*Ntrial+nTrial);

    % Read the received antenna signals.
    % Unfortunately, there is only one SNR in the measured signal data.
    sig = expsig1(ant,'dbtex.dbs',1, (nTrial-1)*NtotSnap/Ntrial + ...
      (1:(NtotSnap/Ntrial)));

    % Estimate the DOA:s
    edoa = sdoapar1('dml',sig, doaStart);
    pdoapar(edoa)
    edoaAll = [ edoaAll; edoa];
  end%for nTrial
  doaMean(nSNR,:) = mean(edoaAll);
  doaStdDev(nSNR,:) = std(edoaAll);
end%for nSNR


fprintf('\nMean of DOA:s\n')
disp(r2d(doaMean))
fprintf('Standard deviation of of DOA:s\n')
disp(r2d(doaStdDev))


plot(SNRtrial,r2d(doaStdDev(:,1)), SNRtrial,r2d(doaStdDev(:,2)))
title('Standard deviation of DOA')
xlabel('SNR')
ylabel('[degrees]')
legend('Target 1', 'Target2')

%printfm dbtex8a.eps [] 12
