%DBTEX81 An example of creating an using a circular array antenna.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 980903 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:40:00 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %

  lambda	= 1;

% ----------------------------------------------------------------------- %
% Create antenna elements.
% ----------------------------------------------------------------------- %

  nElem = 8;
  elem21 = defant('isotropElem');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n

% ----------------------------------------------------------------------- %
% Create array antenna.
% ----------------------------------------------------------------------- %


  % Calulate element positions.
  radius =0.5*lambda;
  angle = linspace(0, 2*pi,nElem+1);
  angle = angle(1:(length(angle)-1));
  xPos = radius * cos(angle);
  yPos = radius * sin(angle);
  elemPos = [xPos ; yPos];

  % Plot element positions.
  plot(elemPos(1,:), elemPos(2,:),'o')
  axis('square')
  xlabel('x-position')
  ylabel('y-position')
  title('Element positions')
  for n=1:nElem
    text(elemPos(1,n), elemPos(2,n),['  ',num2str(n)])
  end%for n

  % Create the array.
  ant2 = defant('array',elemPos,[],elem2);

% ----------------------------------------------------------------------- %
% Plot an antenna pattern in two ways
% ----------------------------------------------------------------------- %

  smplPoints = linspace(-pi, pi, 361);
    % Angles in which to plot the antenna patterns.

  % Plot a rectangular antenna pattern.
  figure,spantpat3(ant2, ...
    {'lambda',lambda, ...
     'mainPointDoa', d2r(0), ...
     'smplPoints', linspace(-pi, pi, 361), ...
     'taperType', 'uniform', 'taperParam', [1 1 1 1 1 1 1 1].'})

  % Plot a polar antenna pattern.
  figure,spantpat3(ant2, ...
    {'lambda',lambda, ...
     'mainPointDoa', d2r(0), ...
     'smplPoints', smplPoints, ...
     'taperType', 'uniform', 'taperParam', [1 1 1 1 1 1 1 1].', ...
     'plotType', 'polar'})

% ----------------------------------------------------------------------- %
% Simulate some (two) signals.
% ----------------------------------------------------------------------- %
  theta	= d2r([77 100])';	% Target angles. The number of targets is
				%  given by the number of target angles.
  phi	= zeros(size(theta));	% Target angles.
  SNR	= [10 10]';		% Signal to noise ratio in dB at each
				%  antenna element!?!
  alpha	= d2r([0 -150])';	  % Start phases of the target signals.
  dalpha	= d2r([34 -66])'; % A constant phase shift between snapshots.
				%  Means targets movements at constant velocity.
  dist=Inf*ones(size(theta));	% Distances to the sources.

		
  sig = compsim4(ant2, lambda, 100, 'rndnw', [theta, ...
    phi, SNR, alpha, dalpha, dist, ...		% Generate simulated received
    eye(size(theta,1))], 'rndnw', []); 	% antenna signals



% ----------------------------------------------------------------------- %
% Estimate and plot some directional spectra.
% ----------------------------------------------------------------------- %

spect1 = sdoaspc('music',sig, smplPoints,3);	% Estimate the DOA-spectrum
						%  with MUSIC.
spect2 = sdoaspc('cbf',sig, smplPoints);	% Estimate the DOA-spectrum
						%  with conventional beamform.
figure,splot2(spect1,'',spect2)			% Plot both DOA-spectrums.
legend('Music','Conventional beamforming')

% printfm dbtex81a1.eps 1 8
% printfm dbtex81a2.eps 2 8
% printfm dbtex81a3.eps 3 8
% printfm dbtex81a4.eps 4 8
