%DBTEX9 An example of beamforming on measured data from the AIMT experimental antenna with different calibration compensation of the steering matrix.

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 970615 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:40:01 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************

% ----------------------------------------------------------------------- %
% Parameters.
% ----------------------------------------------------------------------- %
			
MMu	= 3;			% Number of targets that MUSIC believes in.
    				% The true number is 3.

% ----------------------------------------------------------------------- %
% Commands.
% ----------------------------------------------------------------------- %

% Define the antenna.
ant = defant('expAnt');

% Read the received antenna signals.
sig = expsig1(ant,'dbtex.dbs',1);

% Estimate the antenna signals correlation matrix.
R = ecorrm(sig);

% Set calibration compensation to use with spastemat, sdoaspc, sdoapar1 etc.
setcal1('wctab','dbtex.dbc')

% Estimate a DOA-spectrum.
spect1 = sdoaspc('music',R,d2r(-30:0.25:30),MMu);

% Change the calibration compensation.
setcal1('Ccmp')

% Estimate a new DOA-spectrum.
spect2 = sdoaspc('music',R,d2r(-30:0.25:30),MMu);

% Change the calibration compensation.
setcal1('wcmedel')

% Estimate a new DOA-spectrum.
spect3 = sdoaspc('music',R,d2r(-30:0.25:30),MMu);

% Plot all DOA-spectrums.
splot2(spect1,'',spect2, '',spect3,'')
legend('wctab','Ccmp','wcmedel')




%printfm dbtex9a.eps [] 12
