function sigOut = setpultrans(sigIn, pulTrans)

%SETPULTRANS Set transformation matrix for the pulse (slow-time, Doppler) dimension in a radar signal.
%
%--------
%Synopsis:
%  sigOut = setpultrans(sigIn, pulTrans)
%
%Description:
%  Set pulse (slow-time, Doppler) transformation matrix in a radar signal. 
%  This must be done after linear filtering in the pulse/Doppler/slow-time
%  dimension, i.e. Doppler filtering, to make further signal processing
%  in the pulse/Doppler/slow-time dimension possible.
%
%Output and Input:
%  sigOut (RxRadarSigT): Output radar signal.
%  sigIn (RxRadarSigT): Input radar signal.
%  pulTrans (CxMatrixT): Transformation matrix used for Doppler filtering,
%  i.e. filtering in the slow-time dimension.
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1].
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.
%   Known bugs.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990116 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:21:36 $ $Author: svabj $.
%  $Revision: 1.3 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters
% ----------------------------------------------------------------------- %

if (nargin < 2)
  error('DBT-Error: To few input parameters.')
end

% ****************** Add missing input parameters ******************


% ****************** Default values ******************


% ****************** Error check input parameters ******************

chkdtype(sigIn, 'RxRadarSigT','RxCorrMatT')
chkdtype(pulTrans, 'CxMatrixT')


% ----------------------------------------------------------------------- %
% Do the work.
% ----------------------------------------------------------------------- %

sigOut = sigIn;

if (isfield(sigOut,'trans.pulTrans'))
  % This check is necessary in case the field "trans.pulTrans" is missing in
  % the input parameter "sigIn". In this first if-branch the field exists.

  sigOut.trans.pulTrans = sigOut.trans.pulTrans * pulTrans;
else
  % In this else-branc, the field "trans.pulTrans" is missing in the
  % input parameter "sigIn".

  sigOut.trans.pulTrans = pulTrans;
end%if

%sigOut.antenna = defant('beamform',sigIn.antenna, pulTrans);
%  % This extension of the antenna definition is required for the function
%  % "stemat" to work after beamforming.


%End Of File
