function sigOut = setsparantrans(sigIn, spaRanTrans)

%SETSPARANTRANS Set space-range transformation matrix in a radar signal.
%
%--------
%Synopsis:
%  sigOut = setsparantrans(sigIn, spaRanTrans)
%
%Description:
%  Set space-range transformation matrix in a radar signal. This must be done
%  after linear filtering in the space-range dimension, i.e. (fast-time) STAP,
%  to make further beamforming or signal processing in the spatial and/or
%  range dimensions possible.
%
%  NOTE: The implementation of this function is not finnished. Now, it only 
%  returns the input signal without any modification.
%
%Output and Input:
%  sigOut (RxRadarSigT): Output radar signal.
%  sigIn (RxRadarSigT): Input radar signal.
%  spaRanTrans (CxMatrixT): Transformation matrix used.
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1].
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.
%   Known bugs.)
%
%Known Bugs:
%  The implementation of this function is not finnished. Now it only
%  returns the input signal without setting the transformation matrix.
%  This means that further processing in the dimensions in question is not 
%  possible.
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990116 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:21:39 $ $Author: svabj $.
%  $Revision: 1.3 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters
% ----------------------------------------------------------------------- %

if (nargin < 2)
  error('DBT-Error: To few input parameters.')
end

% ****************** Add missing input parameters ******************


% ****************** Default values ******************


% ****************** Error check input parameters ******************

chkdtype(sigIn, 'RxRadarSigT')
chkdtype(spaRanTrans, 'CxMatrixT')


% ----------------------------------------------------------------------- %
% Do the work.
% ----------------------------------------------------------------------- %

sigOut = sigIn;

if (0) % Not implemented yet. Below is an old implementation from 
  % "setspatrans". It can not be used.
if (isfield(sigOut,'trans.spaRanTrans'))
  % This check is necessary in case the field "trans.spaRanTrans" is missing in
  % the input parameter "sigIn". In this first if-branch the field exists.

  sigOut.trans.spaRanTrans = sigOut.trans.spaRanTrans * spaRanTrans;
else
  % In this else-branc, the field "trans.spaRanTrans" is missing in the
  % input parameter "sigIn".

  sigOut.trans.spaRanTrans = spaRanTrans;
end%if

sigOut.antenna = defant('beamform',sigIn.antenna, spaRanTrans);
  % This extension of the antenna definition is required for the function
  % "stemat" to work after beamforming.
end%if (0)

%End Of File
