function V = spapulstemat(model, doasFreqs, params)

%SPAPULSTEMAT Calculation of space-pulse (space-slow time) steering matrix.
%
%--------
%Synopsis:
%  V = spapulstemat({antenna, waveform}, {doas, freqs})
%
%Description:
%  Calculates the space-pulse (space-slow time) steering matrix for the
%  specified DOAs and frequencies.
%
%  This function is normally not called by the end user but
%  by the extension programmer that extends the toolbox DBT with new signal
%  processing methods etc.
%
%
%Output and Input:
%  V (CxMatrix): The calculated pulse steering matrix. The size is
%    (noPulses x noChan, noFreqs x noDoa), where noPulses is the number of
%    pulses, noChan is the number of antenna channels, noFreqs is the number
%    of frequencies and noDoa is the number of directions
%  antenna (AntDefT): The definition of the receiving antenna to use.
%  waveform (WaveformT): The waveform definition.
%  doas (Vector of DoaT): Directions to calculate the steering vectors at.
%  freqs (RealVectorT.'): Frequencies to calculate the steering vectors at [Hz].
%
%--------
%XXXXXXXXXXXXXXXXX.
%Synopsis:
%
%Description:
%
%Algoritm:
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990222 Svante Bjvrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:22:02 $ (17:08) $Author: svabj $.
%  $Revision: 1.5 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters.
% ----------------------------------------------------------------------- %

% ****************** Add missing input parameters ******************

% ****************** Default values ******************

% ****************** Pick out parts of input parameters ******************
antenna = model{1};
waveform = model{2};
doas = doasFreqs{1};
freqs = doasFreqs{2};

%lambda = waveform.wavelength;

spaParams = params{1};
pulParams = params{2};


% ****************** Error check input parameters ******************


% ----------------------------------------------------------------------- %
% Perform the calculations.
% ----------------------------------------------------------------------- %

A = spastemat(antenna, doas, spaParams{:});
B = pulstemat(waveform, freqs, pulParams{:});
V = kron(B,A);
