function A = sparanstemat(model, doasRanges, spaParam, ranParam)

%SPARANSTEMAT Calculation of space-range (space-fast time) steering matrix.
%
%--------
%Synopsis:
%  A = sparanstemat({antenna, waveform}, {doas, ranges}, ...
%    {lambda, focusDist, pointSubDoa, steVecFlag}, ...
%    {propSpeed, interpMethod, storageClass, boundaryMethod)
%
%Description:
%  Calculates the space-range (space-fast time) steering matrix for the 
%  specified DOAs and frequencies.
%
%  This function is normally not called by the end user but
%  by the extension programmer that extends the toolbox DBT with new signal
%  processing methods etc.
%
%
%Output and Input:
%  A (CxMatrix): The calculated pulse steering matrix. The size is 
%    (noRangeBins x  noChan, noRanges x noDoa), where noRangeBins is the
%    number of range bins, noChan is the number of antenna channels, and 
%    noRanges is the number of ranges and noDoa is the number of directions.
%  antenna (AntDefT): The definition of the receiving antenna to use.
%  waveform (WaveformT): The waveform definition.
%  doas (Vector of DoaT): Directions to calculate the steering vectors at.
%  ranges (RealVectorT.'): Ranges to calculate the steering vectors at [m].
%
%--------
%XXXXXXXXXXXXXXXXX.
%Synopsis:
%
%Description:
%
%Algoritm:
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990222 Svante Bjvrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:22:04 $ (17:08) $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************


% ----------------------------------------------------------------------- %
% Handle input parameters.
% ----------------------------------------------------------------------- %

% ****************** Add missing input parameters ******************

arginNo=2;
if (nargin < arginNo)
  error('DBT-Error: To few input parameters.')
end
arginNo = arginNo +1;


% ****************** Default values ******************


% ************* Pick out some more fields from input parameters. *************

antenna = model{1};
waveform = model{2};

doas = doasRanges{1};
ranges = doasRanges{2};

lambda = spaParam{1};

% ****************** Error check input parameters ******************


% ----------------------------------------------------------------------- %
% Perform the calculations.
% ----------------------------------------------------------------------- %


ranSteeringMat = ranstemat(waveform, ranges);
spaSteeringMat = spastemat(antenna, doas,lambda);
A = kron(ranSteeringMat,spaSteeringMat);
