function splot2(estDirSpec1, plotType1, estDirSpec2, plotType2, ...
          estDirSpec3, plotType3, estDirSpec4, plotType4)

%SPLOT2 Plots one or more DOA-spectra.
%
%--------
%Synopsis:
%  splot2(estDirSpec1)
%  splot2(estDirSpec1,plotType1)
%  splot2(estDirSpec1, plotType1, estDirSpec2, plotType2, estDirSpec3,
%    plotType3, estDirSpec4, plotType4)
%
%Description:
%  Plots one or more DOA-spectrums, either power spectrums or pseudo
%  spectrums.
%
%Output and Input:
%  estDirSpec1,2,3,4 (DoaSpecT)
%  plotType1,2,3,4 [D](StringT):  plotType1(1,1)
%    = 'd' : logaritmic y-axis or
%    = 'l' : linear y-axis.
%    = ' ' : Default y-axis type.
%  plotType1(1,2)
%    = 'a' : Angles.
%    = 's' : sin(angles).
%    = ' ' : Default x-axis type.
%  plotType1(1,3:5)= As with line specification for the usual Matlab "plot"
%    command:
%    Various line types, plot symbols and colors may be obtained  where
%    plotType1(1,3:5) is a character string made from one element
%    from any or all the following 3 colunms:
%
%           y     yellow        .     point              -     solid
%           m     magenta       o     circle             :     dotted
%           c     cyan          x     x-mark             -.    dashdot
%           r     red           +     plus               --    dashed
%           g     green         *     star
%           b     blue          s     square
%           w     white         d     diamond
%           k     black         v     triangle (down)
%                               ^     triangle (up)
%                               <     triangle (left)
%                               >     triangle (right)
%                               p     pentagram
%                               h     hexagram
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%Known Bugs:
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  plot, sigplot2

%
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%  Start        : 951220 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:22:09 $ $Author: svabj $.
%  $Revision: 1.16 $
% *****************************************************************************

% ****************** Add missing input parameters ******************

if (nargin < 2)
  plotType1 = [];
end
if (nargin < 4)
  plotType2 = [];
end
if (nargin < 6)
  plotType3 = [];
end
if (nargin < 8)
  plotType4 = [];
end


% ****************** Default values ******************

if (isempty(plotType1)) | (isempty(plotType1))
  plotType1 = '  b';
end%if
if (isempty(plotType2)) | (isempty(plotType2))
  plotType2 = '  r';
end%if
if (isempty(plotType3)) | (isempty(plotType3))
  plotType3 = '  m';
end%if
if (isempty(plotType4)) | (isempty(plotType4))
  plotType4 = '  c';
end%if


% ****************** Error check input parameters ******************

chkdtype(estDirSpec1, 'DoaSpecT')

if (nargin > 8)
  error('DBT-Error: Plot is implemeted for max 4 spectra.')
end%if


% ***************************** Plot *******************************

%holdValue = get(gcf,'NextPlot');

if (nargin >= 1)
  splot2h(estDirSpec1, plotType1)
end
hold on
if (nargin >=3)
  splot2h(estDirSpec2, plotType2)
end
if (nargin >=5)
  splot2h(estDirSpec3, plotType3)
end
if (nargin >=7)
  splot2h(estDirSpec4, plotType4)
end


%set(gcf,'NextPlot', holdValue);
%set(gcf,'NextPlot', 'new');
