function pattern = subpat(antenna,theta,theta0,poserr,taper,lambda)

% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  function pattern = subpat(antenna,theta,theta0,poserr,taper,lambda)
%
%  Calculates the antenna pattern for the subarrays (one level down from
%  the main array.
%
%  pattern  CxVectorT
%  antenna  AntDefT: : Antenna defined by defant
%  theta RealVectorT : Calculates the pattern in these directions.
%  theta0   RealScalarT : Pointing direction of the subarrays.
%  poserr       RealVectorT     : Element position errors
%  taper        RealVectorT     : Tapering of elements
%  lambda       RealScalarT     : Wavelength [m].
%
%  Start        : 9xxxxx Fredrik Athley (freath).
%  Latest change: $Date: 2000/10/16 15:22:12 $ $Author: svabj $.
%  $Revision: 1.8 $
% *****************************************************************************

global thSign
  % Defines the reference direction for the theta angle in DOA:s.
  % Defined in "defant".

subarray = antenna.element;
%lambda = subarray.lambda;
d = subarray.distElem;
K = subarray.noElem;
k = 0:K-1;

if nargin<3
  theta0 = 0;
end
if nargin<4
  poserr = 0;
end
if nargin<5
  taper = [0.5 1 0.5];
end

dmek = k*d + poserr;
steeringVec = exp(thSign*i*2*pi*dmek'/lambda*(sin(theta)-sin(theta0)));
arrayFactor = sum(diag(taper)*steeringVec);
elementFactor = sqrt(cos(theta));
pattern = elementFactor.*arrayFactor;
