function an=taylorlp(nn,r0dB,nbar)

%TAYLORLP Calculates Taylor weights.
%
%--------
%Synopsis:
%  an=taylorlp(nn,r0dB,nbar)
%
%Description
%  Calulates Taylor weights of an n-element antenna with sidelobes r0dB
%  and parameter nbar
%
%Output and Input:
%  nn (IntScalarT): Number of weight coefficients to produce.
%  r0dB (RealScalarT): Side lobe level in dB. This number is positive.
%  nbar ():
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  gettap1 chebylp bartlett blackman* boxcar* chebwin* hamming* hanning*
%  kaiser* triang*
%  (* = Part of Matlab Signal Processing Toolbox)

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 9xxxxx Lars Pettersson (larpet).
%  Latest change: $Date: 2000/10/16 15:22:13 $ $Author: svabj $.
%  $Revision: 1.5 $
% *****************************************************************************

     r0=10^(r0dB/20);
     A=acosh(r0)/pi;
     sigma=nbar/sqrt(A^2+(nbar-0.5)^2);
     if rem(nn,2)==0
       nm=nn/2;
     else
       nm=(nn+1)/2;
     end
          for n=1:nbar
			zn(nm+n-1)=sigma*sqrt(A^2+(n-0.5)^2);
			zn(nm-n)  =-zn(nm+n-1);
          end
          for n=nbar+1:nm-1
            zn(nm+n-1)=n;
            zn(nm-n)=-n;
          end
          if rem(nn,2)==0
            zn(nn-1)=nn/2;
          end
     an=zeros(1,nn);
     an(1)=1;
     for j=1:nn-1
       an(2:j+1)=an(2:j+1)-exp(i*2*pi*zn(j)/nn)*an(1:j);
     end
