function [g,h] = tayltap(SLL,nbar,N)

% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
% function [g,h] = tayltap(SLL,nbar,N)
%
% Computes a Taylor taper for a specified sidelobe level
% SLL>0 and no of elements = N
% The function has been verified by comparing the results
% with tables and plots in the following literature.
% [R.J.Mailloux, "Phased Array Antenna Handbook", 1994, fig. 3.6]
% [D.K.Barton, H.R.Ward,"Handbook of Radar Measurement,1984,
% fig. A.14]
% [M. Skolnik, "Radar Handbook", 2nd ed.,1990,table 10.9]
%
%
%  Start        : 9xxxxx Fredrik Athley (freath).
%  Latest change: $Date: 2000/10/16 15:22:14 $ $Author: svabj $.
%  $Revision: 1.7 $
% *****************************************************************************

A = 1/pi*acosh(10^(SLL/20));
sig2 = (nbar^2)/(A^2+(nbar-.5)^2);
F = zeros(1,nbar-1);
nbar_min = ceil(2*A^2+0.5);
if nbar<nbar_min
  nbar = nbar_min;
  sig2 = (nbar^2)/(A^2+(nbar-.5)^2);
  disp('The specified nbar is too small.')
  disp(['Using nbar = ',num2str(nbar)])
end

for m=1:nbar-1
  denprod=1;
  numprod=1;
  for n=1:nbar-1
    numprod=numprod*(1-(m^2)/(sig2*(A^2+(n-0.5)^2)));
    if m~=n
      denprod=denprod*(1-(m/n)^2);
    end
  end
  F(m) = (-1)^(m+1)*numprod/(2*denprod);
end

% The Taylor distribution function must be sampled at points one-half
% element spacing from the end of the distribution function
x = 1/N*(-(N-1)/2:(N-1)/2);
g = zeros(1,N);
num2 = 0;
for m=1:nbar-1
  num2 = num2 + F(m)*cos(2*pi*m*x);
end
g = (1+2*num2)/(1+2*sum(F));

% h=abs(fft(g,2^10));
% h = fftshift(h);
% h = 20*log10(h/max(h));
% plot(h);grid
% axis([0 1024 -SLL-20 5])
