function tdbt(testnr)

% [ ]Ok *** TEST ***
% of: DBT (A Matlab Toolbox for Digital Beamforming).
% Sign:     Datum:
%
% *****************************************************************************
%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  A test program for the Toolbox.
%
%  Start        : 970314 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:22:16 $ $Author: svabj $.
%  $Revision: 1.52 $
% *****************************************************************************

global thSign
  % Defines the reference direction for the theta angle in DOA:s.
  % Defined in "defant".

if (nargin < 1)
  disp('Test of A Matlab Toolbox for Digital Beamforming.')
  %disp('Don''t forget to compile mex-files before the test.')
  disp('Test 11:  Test of PTMF with the AIMT application example.')
  disp('Test 12:  Test of the function dspastemat for the aimtEx antenna.')
  disp('Test 13:  Test of recursive antenna definitions.')
  disp('Test 14:  Test of the function dspastemat for recursive antenna definitions.')
  disp('Test 16:  Comparison between ULA and LA.')
  disp('Test 17:  Test of the antenna types "array" and "beamform".')
  disp('Test 20:  Test of spectral DOA estimation after modifications.')
  disp('Test 21: ')
  disp('Test 25:  Test of conventional beamforming.')
  disp('Test 26:  Test of tapering of antenna pattern.')
  disp('Test 40:  Test of parametric DOA-estimation after modifications.')
  disp('Test 50:  Test of "expAnt" antenna with different calibration.')
  disp('Test 51:  Test of "expAnt" antenna with different calibration of steering vec.')
  disp('Test 60:  Test of different antenna types and steering matrix calculations.')
  disp('Test 101: Test of pulse code modulations.')
  disp('Test 102: Test of exchange getm, getm2, getm3 and setm with direct indexing.')
  disp('Test 103: Test of function "sigsplitdim".')
  disp('Test 120: Test of wide band signal simulation.')
  disp('Test 130: Test of range steering matrix calculation.')
  disp('Test 131: Test of space-range steering matrix calculation.')
  disp('Test : ')
  testnr=input('Choose testno: ');
  while isempty(testnr)
    testnr=input('Choose testno: ');
  end
end%if


if isstr(testnr)
  testnr = str2num(testnr)
end%if

if (testnr==1)
  % Nothing.


elseif (testnr==11)
% *****************************************************************************
% [ ]  : Test 11
% Sign:     Datum:
%
%  Test of PTMF with the AIMT application example.
%
% *****************************************************************************
% Comments:

% [ ]
% Comments:
%  Target angles d2r([-5 0 5]).
%  Start values d2r([-5 0 5]).
disp('Test 11a')
T  = 200;         % Number of snapshots.
K  = 25;       % Number of channels.

theta = d2r([-5 0 5])'; % Target angles. The number of targets is
            %  given by the number of target angles.
phi   = zeros(size(theta));   % Target angles.
SNR   = [10 10 10]';    % Signal to noise ratio in dB at each
            %  antenna element!?!
alpha = d2r([20 210 33])';    % Start phases of the target signals.
dalpha   = d2r([0 -10 150])'; % A constant phase shift between snapshots.
            %  Means targets movements at constant velocity.
dist=Inf*ones(size(theta));   % Distances to the sources.
tgtModel       = 'const';
noiseModel        = 'nonoise';
lambda = 0.1;
ant = defant('aimtEx');
sig = compsim4(ant, lambda, T, tgtModel, [theta, phi, SNR, alpha, dalpha, dist, eye(size(theta,1))], noiseModel, eye(K));
sig = msigmat2(sig, T);
[edoa, sHat, Q, doaAll] = doapar1('ptmf',sig, d2r([-5 0 5]), Inf, [], [], 5*1e-3);
pdoapar(edoa)
pdoait(doaAll)
perrfun(Q)
% Expected result :
%  In the text window: about [-5 0 5]' degrees.
%  The plot which shows the convergence of the doa parameters shall
%  show a smooth convergence to about [-5 0 5]' degrees.
%  The error function may be rough but shall decrease.
% Real result :



pause

% [ ]
disp('Test 11b')
% Comments:
%  Target angles d2r([-5 0 5]).
%  Start values d2r([-1 0 1]).
T  = 200;         % Number of snapshots.
K  = 25;       % Number of channels.

theta = d2r([-5 0 5])'; % Target angles. The number of targets is
            %  given by the number of target angles.
phi   = zeros(size(theta));   % Target angles.
SNR   = [10 10 10]';    % Signal to noise ratio in dB at each
            %  antenna element!?!
alpha = d2r([20 210 33])';    % Start phases of the target signals.
dalpha   = d2r([0 -10 150])'; % A constant phase shift between snapshots.
            %  Means targets movements at constant velocity.
dist=Inf*ones(size(theta));   % Distances to the sources.
tgtModel       = 'const';
noiseModel        = 'nonoise';
lambda = 0.1;
ant = defant('aimtEx');
sig = compsim4(ant, lambda, T, tgtModel, [theta, phi, SNR, alpha, dalpha, dist, eye(size(theta,1))], noiseModel, eye(K));
sig = msigmat2(sig, T);
[edoa, sHat, Q, doaAll] = doapar1('ptmf',sig, d2r([-1 0 1]), Inf, [], [], 5*1e-2);
pdoapar(edoa)
pdoait(doaAll)
perrfun(Q)
% Expected result :
%  In the text window: about [-5 0 5]' degrees.
%  The plot which shows the convergence of the doa parameters shall show a  convergence to about [-5 0 5]' degrees.
%  The error function probably does not decrease so much.
% Real result :




% [ ]
disp('Test 11c')
% Comments:
%  Target angles d2r([-1 0 1]).
%  Start values d2r([-.5 0 .5]).
T  = 200;         % Number of snapshots.
K  = 25;       % Number of channels.

theta = d2r([-1 0 1])'; % Target angles. The number of targets is
            %  given by the number of target angles.
phi   = zeros(size(theta));   % Target angles.
SNR   = [10 10 10]';    % Signal to noise ratio in dB at each
            %  antenna element!?!
alpha = d2r([20 210 33])';    % Start phases of the target signals.
dalpha   = d2r([0 -10 150])'; % A constant phase shift between snapshots.
            %  Means targets movements at constant velocity.
dist=Inf*ones(size(theta));   % Distances to the sources.
tgtModel       = 'const';
noiseModel        = 'nonoise';
lambda = 0.1;
ant = defant('aimtEx');
sig = compsim4(ant, lambda, T, tgtModel, [theta, phi, SNR, alpha, dalpha, dist, eye(size(theta,1))], noiseModel, eye(K));
sig = msigmat2(sig, T);
[edoa, sHat, Q, doaAll] = doapar1('ptmf',sig, d2r([-.5 0 .5]), Inf, [], [], 5*1e-4);
pdoapar(edoa)
pdoait(doaAll)
perrfun(Q)
% Expected result :
%  In the text window: about [-1 0 1]' degrees.
%  The plot which shows the convergence of the doa parameters shall show
%   a smooth convergence to about [-1 0 1]' degrees.
%  The error function shall decrease monotonically.
% Real result :




elseif (testnr==12)
% *****************************************************************************
% [ ]  : Test 12
% Sign:     Datum:
%
% Test of the function dspastemat for the aimtEx antenna
%
% *****************************************************************************
% Comments

% [ ]
% Comments
%  Test of the function dspastemat for the 'aimtEx' antenna.
disp('Test 12a')
n = 10;           % Index to SubArray to be calculated
m = 1;            % Index to target angle to be calculated

dElem = 0.05;
dSubArray = 0.1;
ant = defant('aimtEx');       % Application example antenna
theta = d2r([-20 -5 0 5 20]');      % Target angles. The no of targets is
phi = zeros(size(theta));     %  given by the no of target angles.
doas = ([theta';phi']);       % Only theta is considered as target angle
lambda = 0.1;           % Wavelength (3 GHz)
w = [0.5 1 0.5]';       % Tapering weights vector
%l1 = -j*2*pi/lambda*dElem;      % Temp variable
%l2 = -j*2*pi/lambda*dSubArray;     % Temp variable
l1 = thSign*j*2*pi/lambda*dElem;    % Temp variable
l2 = thSign*j*2*pi/lambda*dSubArray;      % Temp variable

delta_theta = 0.0000001;
th1 = theta(m) + delta_theta;
th2 = theta(m) - delta_theta;
part1 = exp((n-1)*l2*sin(th1))*(w(1)+w(2)*exp(l1*sin(th1))+w(3)*exp(2*l1*sin(th1)))*sqrt(cos(th1));
part2 = exp((n-1)*l2*sin(th2))*(w(1)+w(2)*exp(l1*sin(th2))+w(3)*exp(2*l1*sin(th2)))*sqrt(cos(th2));
Expected_Value = (part1 - part2) / (2*delta_theta);   % Numerical value
disp(['Expected value = ' num2str(Expected_Value)])

%for m=1:5
%  for n=1:25
%    th1 = theta(m) + delta_theta;
%    th2 = theta(m) - delta_theta;
%    part1 = exp((n-1)*l2*sin(th1))*(w(1)+w(2)*exp(l1*sin(th1))+w(3)*exp(2*l1*sin(th1)))*sqrt(cos(th1));
%    part2 = exp((n-1)*l2*sin(th2))*(w(1)+w(2)*exp(l1*sin(th2))+w(3)*exp(2*l1*sin(th2)))*sqrt(cos(th2));
%    AExp(n,m) = (part1 - part2) / (2*delta_theta);   % Numerical value
%  end
%end

A = dspastemat(ant,doas,lambda);
Real_Result = A(n,m);
disp(['Real value = ' num2str(Real_Result)])
%Real_Result = sum(sum(abs(A - AExp)))

% Expected result :
%   The values shall be about the same.
% Real result :



% [ ]
disp('Test 12b')
n = 22;           % Index to SubArray to be calculated
m = 4;            % Index to target angle to be calculated

delta_theta = 0.0000001;
th1 = theta(m) + delta_theta;
th2 = theta(m) - delta_theta;
part1 = exp((n-1)*l2*sin(th1))*(w(1)+w(2)*exp(l1*sin(th1))+w(3)*exp(2*l1*sin(th1)))*sqrt(cos(th1));
part2 = exp((n-1)*l2*sin(th2))*(w(1)+w(2)*exp(l1*sin(th2))+w(3)*exp(2*l1*sin(th2)))*sqrt(cos(th2));
Expected_Value = (part1 - part2) / (2*delta_theta);   % Numerical value
disp(['Expected value = ' num2str(Expected_Value)])

A = dspastemat(ant,doas,lambda);
Real_Result = A(n,m);
disp(['Real value = ' num2str(Real_Result)])

% Expected result :
%   The value shall be about the same
% Real result :




elseif (testnr==13)
% *****************************************************************************
% [ ]  : Test 13
% Sign:     Datum:
%
% Test of a recursive antenna definitions.
% ==Testing of generalized function spastemat.m (a recursive ULA, where the
% elements can be ULA:s or one-channel elements) to calculate the steering
% vector.
%
% *****************************************************************************
% Comments: Testing of generalized function to calculate the steering vector

% [ ]
disp('Test 13a')
clear all
global thSign
thSign = 1;
w      = [0.5 1 0.5]';      % Tapering weights vector
theta  = pi/4;              % Target directions
ant    = defant('aimtEx');  % Application example antenna
lambda   = 0.1;             % Wavelength of simulated radarsignal.
%Expected_Value = exp(-j*0.1*(0:24)'*2*pi/lambda*sin(theta)) * ...
%                 w' * exp(-j*0.05*(0:2)'*2*pi/lambda*sin(theta)) * ...
%                 sqrt(cos(theta));
Expected_Value = exp(thSign*j*0.1*(0:24)'*2*pi/lambda*sin(theta)) * ...
                 w' * exp(thSign*j*0.05*(0:2)'*2*pi/lambda*sin(theta)) * ...
                 sqrt(cos(theta));
Real_Result = spastemat(ant,theta,lambda);
disp(['Expected value < ' num2str(max(abs(Expected_Value))*1.5E-12)])
disp(['Real value = ' num2str(sum(abs(Expected_Value - Real_Result)))])
% Expected result : 0
%  The value should be about the same and diff should be small
% Real result :


% [ ]
disp('Test 13b')
clear all
global thSign
thSign = 1;
w1          = [0.5 1 0.5]';          % Tapering weights vector 1
w2          = [0.1 0.6 1 0.6 0.1]';  % Tapering weights vector 2
theta       = 2*pi/7;                % Target directions
lambda      = 0.0842;                % Wavelength of simulated radarsignal.
noElemMain  = 25;
noElemSub1  = 3;
noElemSub2  = 5;
distElemMain   = lambda;
distElemSub1   = lambda/3;
distElemSub2   = lambda/2;
elem     = defant('pattFuncElem', 'sqrt(cos(x(1,:)))');
subarray2 = defant('ULA', [noElemSub2, distElemSub2], elem, w2);
subarray1 = defant('ULA', [noElemSub1, distElemSub1], subarray2, w1);
ant      = defant('ULA', [noElemMain, distElemMain], subarray1, ones(noElemMain:1));
%Expected_Value = exp(-j*distElemMain*(0:noElemMain-1)'*2*pi/lambda*sin(theta)) * ...
%                 (w1' * exp(-j*distElemSub1*(0:noElemSub1-1)'*2*pi/lambda*sin(theta))) * ...
%                 (w2' * exp(-j*distElemSub2*(0:noElemSub2-1)'*2*pi/lambda*sin(theta))) * ...
%                 sqrt(cos(theta));
Expected_Value = exp(thSign*j*distElemMain*(0:noElemMain-1)'*2*pi/lambda*sin(theta)) * ...
                 (w1' * exp(thSign*j*distElemSub1*(0:noElemSub1-1)'*2*pi/lambda*sin(theta))) * ...
                 (w2' * exp(thSign*j*distElemSub2*(0:noElemSub2-1)'*2*pi/lambda*sin(theta))) * ...
                 sqrt(cos(theta));
Real_Result = spastevec(ant,theta,lambda);
disp(['Expected value < ' num2str(max(abs(Expected_Value))*8E-12)])
%disp('Expected value = 0')
disp(['Real value = ' num2str(sum(abs(Expected_Value - Real_Result)))])
% Expected result : 0
%   The value should be about the same and diff should be small
% Real result :



if(0) % Not needed. Use 13d instead!
% [ ]
disp('Test 13c')
% Comments
%  A quantitative test of a recursive ULA, where the
%  elements can be ULA:s or one-channel elements.
%  Only one of tests 13c and 13d need to be done.
  clear all
  global thSign
  thSign = 1;
  lambda = 0.2;
  elem    = defant('pattFuncElem', 'cos(x(1,:))');
  subarray = defant('ULA', [3, lambda/2], elem, [1 1 1].');
  totArray = defant('ULA', [24, 3*lambda/2], subarray, ones(24,1));
  figure
  s1 = pantpat2(totArray,[],[],[],[],[],lambda);
  ant1=totArray.element;
  figure
  s2 = pantpat2(ant1,[],[],[],[],[],lambda);
  ant2=ant1.element;
  figure
  s3 = pantpat2(ant2,[],[],[],[],[],lambda);

  %ls1=s1.specSmpl;
  %ls2=s2.specSmpl;
  %ls3=s3.specSmpl;
  %save tdbt13 s1 s2 s3
% Expected result :
%  With the aid of the following code we obtain graphs in which it
%  is possible to measure.
%  The graphs in the "Real result" section below must be in accordance
%  with the following graphs.
if (0)
  x = -90:2:90;
  y =cos(d2r(x))^2;
  plot(x,10*log10(y))

  lambda = 0.2;
  smallArray = defant('isotropULA', [3, lambda/2]);
  pantpat(smallArray,[],[],[],[],[],[],lambda);

  bigArray = defant('isotropULA', [24, 3*lambda/2]);
  pantpat2(bigArray,[],[],[],[],[],lambda);
    % This antenna pattern shall have grating lobes.
end%if (0)
% Real result :

end%if(0)




% [ ]
disp('Test 13d')
% Comments
%  A quantitative test of a recursive ULA, where the
%  elements can be ULA:s or one-channel elements.
%  This test uses results saved to file from test 13c
%  to decide success.
%  Only one of tests 13c and 13d need to be done.
% Expected result :
  clear all
  global thSign
  thSign = 1;
  load tdbt13
  ls1=s1;
  ls2=s2;
  ls3=s3;

  lambda = 0.2;
  elem    = defant('pattFuncElem', 'cos(x(1,:))');
  subarray = defant('ULA', [3, lambda/2], elem, [1 1 1].');
  totArray = defant('ULA', [24, 3*lambda/2], subarray, ones(24,1));
  figure, hold on
  s1 = pantpat2(totArray,[],[],[],[],[],lambda);
  ant1=totArray.element;
  s2 = pantpat2(ant1,[],[],[],[],[],lambda);
  ant2=ant1.element;
  s3 = pantpat2(ant2,[],[],[],[],[],lambda);
  difference = abs(sum(ls1.specSmpl-s1.specSmpl) + ...
    sum(ls2.specSmpl-s2.specSmpl) + sum(ls3.specSmpl-s3.specSmpl) );
  limit = eps;      % Ok on magic and curare.
  limit = 7.7e-11;  % Needed for hawk.
if ( difference  > limit)
  error('DBT-Error: Difference to large.')
else
  disp('Test Ok.')
end%if
% Real result :




elseif (testnr==14)
% *****************************************************************************
% [ ]  : Test 14
% Sign:     Datum:
%
% Test of the function dspastemat for recursive antenna definitions.
% ==Test of the function dspastemat for generalized ULAs
%
% *****************************************************************************
% Comments

% [ ]
% Comments
%  Test of the function dspastemat for a generalized ULA antenna.
disp('Test 14a')
format long;

n = 10;           % Index to channel to be calculated
m = 1;            % Index to target angle to be calculated

ant = defant('aimtEx');       % Application example antenna
theta = d2r([-20 -10 -5 -2 0 2 5 10 20]');      % Target angles. The no of targets is
phi = zeros(size(theta));     %  given by the no of target angles.
lambda   = 0.1;
doas = ([theta';phi']);       % Only theta is considered as target angle

AExp = dspastemat(ant,doas,lambda);

noElemMain  = 25;
noElemSub   = 3;
lambda   = 0.1;
distElemMain   = lambda;
distElemSub = lambda/2;
taper = [0.5 1 0.5]';
elem     = defant('pattFuncElem', 'sqrt(cos(x(1,:)))');
subarray = defant('ULA', [noElemSub, distElemSub], elem, taper);
ant      = defant('ULA', [noElemMain, distElemMain], subarray, ones(noElemMain:1));

AReal = dspastemat(ant,doas,lambda);

figure;
plot(theta,abs(AReal(10,:)));
hold;
plot(theta,abs(AExp(10,:)),'--c');
format short;
% Expected result :
%  The value shall be about the same
  disp('The two plots should concur.');
  disp('The yellow is expected and the blue is the real result,');
  disp('and the cyan is expected and the blue is the real result.');
% Real result :





elseif (testnr==16)
% *****************************************************************************
% [ ]  : Test 16
% Sign:     Datum:
%
% Comparison between ULA and LA.
%
% Sign: davrej    Datum: 971209
% *****************************************************************************
% Comments:
% Test 1a: Compares the steering vector for an ULA and a LA
%          that happens to be uniformal.
% Test 1b: Compares the derivative of the steering vector for an ULA and a LA
%          that happens to be uniformal.


% [ ]
disp('Test 16a: Comparison between ULA and LA steering vector')
ULAant = defant('isotropULA',[12,0.012]);
elementPositions = (0:11)'*0.012;
elem = defant('isotropElem');
LAant = defant('LA',elementPositions,[],elem);

doa=d2r(20);

ULAsteeringvector = spastevec(ULAant,doa,0.03);
LAsteeringvector = spastevec(LAant,doa,0.03);

Difference = sum(abs(LAsteeringvector) - abs(ULAsteeringvector))
Real_Result = Difference
if (Difference == 0)
  disp('Test 16a: OK')
end%if
% Expected result :
%  0 = No difference
% Real result :






% [ ]
%disp('Test 16b')
% Expected result :
% Real result :
disp('Test 16a: Comparison between ULA and LA differentiated steering vector')
ULAant = defant('isotropULA',[12,0.012]);
elementPositions = (0:11)'*0.012;
elem = defant('isotropElem');
LAant = defant('LA',elementPositions,[],elem);

doa=d2r(12.92764);

ULAdsteeringvector = dspastevec(ULAant,doa,0.03);
LAdsteeringvector = dspastevec(LAant,doa,0.03);

Difference = sum(abs(LAdsteeringvector - ULAdsteeringvector))
Real_Result = Difference
if (Difference == 0)
  disp('Test 16b: OK')
end%if

% Expected result :
%   0 = No difference
% Real result :



elseif (testnr==17)
% *****************************************************************************
% [ ]  : Test 17
% Sign:		Datum:
%
% Test of the antenna types 'array' and 'beamform'.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 17a')
% Comments
%	Test of the function "doa2rect".
  rectReal = doa2rect([pi/4 0; pi/3 pi/6].');
  rectExpect = [1/sqrt(2), 1/sqrt(2), 0; ...
     cos(pi/6)*sin(pi/3), cos(pi/6)*cos(pi/3), -sin(pi/6)].';
  if (sum(sum(abs(rectReal - rectExpect))) > eps)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :


% [ ]
disp('Test 17b')
% Comments
%	Test of the function "doa2wavevec".
  lambda = 3;
  kCalc = doa2wavevec([pi/4 0; pi/3 pi/6].',lambda);
  dir = - [35, 35, 0;...
    cos(pi/6)*sin(pi/3), cos(pi/6)*cos(pi/3), -sin(pi/6)].';
  normdir(:,1) = dir(:,1)/norm(dir(:,1));
  normdir(:,2) = dir(:,2)/norm(dir(:,2));
  kExpect = (2*pi/lambda)*normdir;
  testvar = sum(sum(abs(kCalc - kExpect)));
  if (testvar > eps)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :



% [ ]
disp('Test 17c')
% Comments
%	Comparison of the "new" 'array' antenna type (only one antenna element definition) with 'isotropULA'.
  clear all
  ant1 = defant('isotropULA',[12 0.5]);

  elem2 = defant('isotropElem');
  %elem2 = defant('pattFuncElem', 'sqrt(cos(x(1,:)))'); % To test a difference.
  ant2 = defant('array',[0:0.5:5.5],[],elem2);

  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];
  A1 = spastemat(ant1,doas,lambda,focusDist);
  A2 = spastemat(ant2,doas,lambda,focusDist);
  extraRelTol = 2; % Allow for some extra tolerance because of many
    % floating point operations and use of complex numbers (2).
  limit = extraRelTol * 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)));
  if (difference > limit)
    error('Difference to large.')
    %disp('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :


% [ ]
disp('Test 17d')
% Comments
%	Comparison of the 'array' antenna type with several antenna
%	element definitions with 'isotropULA'.
  clear all
  ant1 = defant('isotropULA',[12 0.5]);

  elem21 = defant('isotropElem');
  elem2 = cell(1,12);
  for n = 1:12, elem2{n}=elem21; end%for n
  %elem2{9}= defant('pattFuncElem', 'sqrt(cos(x(1,:)))'); % To test a difference.
  ant2 = defant('array',[0:0.5:5.5],[],elem2);

  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];
  A1 = spastemat(ant1,doas,lambda,focusDist);
  A2 = spastemat(ant2,doas,lambda,focusDist);
  extraRelTol = 2; % Allow for some extra tolerance because of many
    % floating point operations and use of complex numbers (2).
  limit = extraRelTol * 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)));
  if (difference > limit)
    error('Difference to large.')
    %disp('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :



% [ ]
disp('Test 17f')
% Comments
%	Comparison of the 'array' antenna type with several antenna
%	elements with 'aimtEx'.
  clear all
  lambda	= 0.1;
  ant1 = defant('aimtEx');

  nElem = 51;
  elem21 = defant('pattFuncElem', 'sqrt(cos(x(1,:)))');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n
  %elem2 = repmat({},1,nElem);	% Alternative way to create elem2.
  %elem2{9}= defant('pattFuncElem', 'isotropElem'); % To test a difference.
  T = zeros(nElem,25);
  for n=1:25
    T((2*n-1):(2*n-1)+2,n) = [0.5 1 0.5].';
  end%for n
  ant2 = defant('BFArray',[0:0.5:25]*lambda,[],elem2,T);

  smplPoints = d2r(-30:0.25:0);
  figure,spantpat3(ant1,{'lambda',lambda,  'smplPoints',smplPoints})
  figure,spantpat3(ant2,{'lambda',lambda,  'smplPoints',smplPoints})

  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];
  A1 = spastemat(ant1,doas,lambda,focusDist);
  A2 = spastemat(ant2,doas,lambda,focusDist);
  extraRelTol = 2; % Allow for some extra tolerance because of many
    % floating point operations and use of complex numbers (2).
  limit = extraRelTol * 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)));
  if (difference > limit)
    error('Difference to large.')
    %disp('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :



% [ ]
disp('Test 17g')
% Comments
%	.
  % Create antenna elements.
  nElem = 2;
  elem21 = defant('isotropElem');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n

  %Element positions.
  elemPos = [0 0 ; -0.25 0.25];
  plot(elemPos(1,:), elemPos(2,:),'o')
  axis('square')
  xlabel('x-position')
  ylabel('y-position')
  title('Element positions')
  for n=1:nElem
    text(elemPos(1,n), elemPos(2,n),['  ',num2str(n)])
  end%for n

  %Create array antenna.
  ant2 = defant('array',elemPos,[],elem2);

  %Test
  doas = d2r([-180 -90 0 90 180; 0 0 0 0 0; 0 0 0 0 0]);
  doa2rectReal = doa2rect(doas);
  doa2rectExpect = [0 -1 0; -1 0 0; 0 1 0; 1 0 0; 0 -1 0].';
  limit = 0.5*size(doa2rectReal,1)*size(doa2rectReal,2)*eps;
  if (sum(sum(abs(doa2rectReal - doa2rectExpect))) > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :



% [ ]
disp('Test 17h')
% Comments
%	.
  % Continuation of thest 17g.
  waveVecReal = doa2wavevec(doas,lambda);
  waveVecExpect = -1*(2*pi/lambda)*doa2rectExpect;
  %AReal = spastemat(ant2,doas,lambda);
  %AExpect = [];
  limit = 0.5*size(waveVecReal,1)*size(waveVecReal,2)*eps;
  if (sum(sum(abs(waveVecReal - waveVecExpect))) > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :


% [ ]
disp('Test 17i')
% Comments
%	.
  clear all

  % Create antenna elements.
  nElem = 2;
  elem21 = defant('isotropElem');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n

  %Element positions.
  elemPos = [0 0 ; -0.25 0.25];
  plot(elemPos(1,:), elemPos(2,:),'o')
  axis('square')
  xlabel('x-position')
  ylabel('y-position')
  title('Element positions')
  for n=1:nElem
    text(elemPos(1,n), elemPos(2,n),['  ',num2str(n)])
  end%for n

  %Create array antenna.
  ant2 = defant('array',elemPos,[],elem2);

  lambda = 1;
  %elemPos = [0 -0.25 0; 0 0.25 0].'*lambda;
  d = lambda/2;
  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  AExpect = exp(j*2*pi*(elemPos(2,:).'/lambda)*cos(doas(1,:)));
  AExpect = AExpect./AExpect(1,1);

  AReal = spastemat(ant2,doas,lambda);
  AReal = AReal./AReal(1,1);

  limit = 0.5*size(AReal,1)*size(AReal,2)*eps;
  if (sum(sum(abs(AReal - AExpect))) > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :



% [ ]
disp('Test 17j')
% Comments
%	.
  clear all

  % Create antenna elements.
  nElem = 2;
  elem21 = defant('isotropElem');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n

  %Element positions.
  elemPos = [-0.25 0.25; 0 0];
  plot(elemPos(1,:), elemPos(2,:),'o')
  axis('square')
  xlabel('x-position')
  ylabel('y-position')
  title('Element positions')
  for n=1:nElem
    text(elemPos(1,n), elemPos(2,n),['  ',num2str(n)])
  end%for n

  %Create array antenna.
  ant2 = defant('array',elemPos,[],elem2);

  lambda = 1;
  %elemPos = [0 -0.25 0; 0 0.25 0].'*lambda;
  %elemPos = [0 0.25 0; 0 -0.25 0].'*lambda;
  d = lambda/2;
  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  AExpect = exp(j*2*pi*(elemPos(1,:).'/lambda)*sin(doas(1,:)));
  AExpect = AExpect./AExpect(1,1);

  AReal = spastemat(ant2,doas,lambda);
  AReal = AReal./AReal(1,1);

  difference = sum(sum(abs(AReal - AExpect)));
  limit = 0.5*size(AReal,1)*size(AReal,2)*eps;
  if (difference > limit)
    difference
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :




% [ ]
disp('Test 17k')
% Comments
%	.
  clear all
  lambda	= 1;
  % Create antenna elements.
  nElem = 2;
  elem21 = defant('isotropElem');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n
  %Element positions.
  elemPos = [-0.25 0.25; 0 0];
  figure,plot(elemPos(1,:), elemPos(2,:),'o')
  axis('square')
  xlabel('x-position')
  ylabel('y-position')
  title('Element positions')
  for n=1:nElem
    text(elemPos(1,n), elemPos(2,n),['  ',num2str(n)])
  end%for n
  %Create array antenna.
  ant2 = defant('array',elemPos,[],elem2);
  % Plot an antenna pattern.
  smplPoints = linspace(-pi, pi, 361);
  figure,spantpat3(ant2, ...
    {'lambda',lambda, ...
     'mainPointDoa', d2r(0), ...
     'smplPoints', smplPoints, ...
     'taperType', 'uniform', 'taperParam', [1 1 1 1 1 1 1 1].', ...
     'plotType', 'polar'})
  title('Antenna pattern 17k')
% Expected result :
%	In the graph: maxima in 0 and 180 degrees, minima in +-90 degrees.
% Real result :




% [ ]
disp('Test 17l')
% Comments
%	.
  clear all
  lambda	= 1;
  % Create antenna elements.
  nElem = 2;
  elem21 = defant('isotropElem');
  elem2 = cell(1,nElem);
  for n = 1:nElem, elem2{n}=elem21; end%for n

  %Element positions.
  elemPos = [0 0 ; -0.25 0.25];
  figure,plot(elemPos(1,:), elemPos(2,:),'o')
  axis('square')
  xlabel('x-position')
  ylabel('y-position')
  title('Element positions')
  for n=1:nElem
    text(elemPos(1,n), elemPos(2,n),['  ',num2str(n)])
  end%for n
  %Create array antenna.
  ant2 = defant('array',elemPos,[],elem2);

  % Plot an antenna pattern.
  smplPoints = linspace(-pi, pi, 361);
  figure,spantpat3(ant2, ...
    {'lambda',lambda, ...
     'mainPointDoa', d2r(-90), ...
     'smplPoints', smplPoints, ...
     'taperType', 'uniform', 'taperParam', [1 1 1 1 1 1 1 1].', ...
     'plotType', 'polar'})
  title('Antenna pattern 17l')
% Expected result :
%	In the graph: maxima in +-90 degrees, minima in 0 and 180 degrees.
% Real result :




if (0)

% [ ]
disp('Test 17cc')
% Comments
%	Comparison of the 'array' antenna type with 'isotropULA'.
  clear all
  ant1 = defant('isotropULA',[12 0.5]);
  elem2 = defant('isotropElem');
  ant2 = defant('array',[0:0.5:5.5],[],elem2,ones(1,12));
  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];
  A1 = spastemat(ant1,doas,lambda,focusDist);
  A2 = spastemat(ant2,doas,lambda,focusDist);
  limit = 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)))
  if (difference > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :


% [ ]
disp('Test 17dd')
% Comments
%	Comparison of the 'array' antenna type with several antenna
%	elements with 'isotropULA'.
  clear all
  ant1 = defant('isotropULA',[12 0.5]);
  elem21 = defant('isotropElem');
  elem2 = cell(1,12);
  for n = 1:12, elem2{n}=elem21; end%for n
  ant2 = defant('array',[0:0.5:5.5],[],elem2,eye(12))
  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];
  A1 = spastemat(ant1,doas,lambda,focusDist);
  A2 = spastemat(ant2,doas,lambda,focusDist);
  limit = 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)))

  if (difference > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%	No error message.
% Real result :


% [ ]
disp('Test 17e')
% Expected result :
% Real result :

end%if (0)



elseif (testnr==20)
% *****************************************************************************
% [ ]  : Test 20
% Sign:     Datum:
%
% A simple standard test of spectral DOA estimation after modifications.
%
% The aim of this test is to discover run-time errors and large
% calculation errors, not to check that the result is right.
%
% Trying to test a large part of DBT.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 20a')
% Comments
%   Test of all spectral DOA estimation methods for run-time errors
%   using sdoaspc.
  lambda = 0.03;        	% wavelength.
  D   	 = 0.45*lambda;    	% Element separation.
  T   	 = 24;      		% Number of snapshots.
  K  	 = 12;       		% Number of digital antenna channels.
  theta  = d2r([25 40])';  	% Target angles. The number of targets is
            			%  given by the number of target angles.
  phi    = zeros(size(theta));  % Target angles.
  SNR    = [10 5]';     	% Signal to noise ratio in dB at each
            			%  antenna element!?!
  alpha  = d2r([0 16])';      	% Start phases of the target signals.
  dalpha = d2r([34 -13])';  	% A constant phase shift between snapshots.
            			%  Means targets movements at constant velocity.
  dist = Inf*ones(size(theta)); % Distances to the sources.
  tgtModel   = 'const';  	% Target type to simulate.
  noiseModel = 'rndn';   	% Noise type to simulate.
  MMu        = 2;        	% Number of targets that MUSIC believes in.
if(0)
  ant = defant('isotropULA',[K,D]); % Define the antenna.
  sig = compsim4(ant, lambda, T, tgtModel, [theta, ...
    phi, SNR, alpha, dalpha, dist, ...    
    eye(size(theta,1))], noiseModel, eye(K));
    % Generate simulated received antenna signals.
else
  global thSign;
  load tdbt20
  ls1=s1;
  ls2=s2;
  ls3=s3;
  ls4=s4;
  ls5=s5;
end%if(0)
  figure, hold on
  s1 = sdoaspc('cbf',sig);
  s2 = sdoaspc('capon',sig);
  s3 = sdoaspc('music',sig,[],MMu);
  s4 = sdoaspc('minnorm2',sig,[],MMu);
  s5 = sdoaspc('minnorm',sig,[],MMu);
  splot2(s1,'  y');
  splot2(s2,'  m');
  splot2(s3,'  c');
  splot2(s4,'  g');
  splot2(s5,'  r');
  legend('cbf','capon','music','minnorm2','minnorm')
  %save tdbt20 sig s1 s2 s3 s4 s5

  %  sum(ls1.specSmpl-s1.specSmpl)
  %  sum(ls2.specSmpl-s2.specSmpl)
  %  sum(ls3.specSmpl-s3.specSmpl)
  %  sum(ls4.specSmpl-s4.specSmpl)
  %  sum(ls5.specSmpl-s5.specSmpl)

  difference = abs((sum(ls1.specSmpl-s1.specSmpl) + ...
    sum(ls2.specSmpl-s2.specSmpl) + ...
    sum(ls3.specSmpl-s3.specSmpl) + ...
    sum(ls4.specSmpl-s4.specSmpl) + ...
    sum(ls5.specSmpl-s5.specSmpl)));
  %limit = eps;	% Ok on magic and curare.
  limit = 1.6e-12;	% Needed for hawk.
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if

% Expected result :
%  All graphs should look normal.
%  No error message.
% Real result :





elseif (testnr==21)
% *****************************************************************************
% [ ]  : Test 21
% Sign:     Datum:
%
% Continuation of test 20. Test for rangeIx <> 1.
%
% This test is probably obsolete.
%
% *****************************************************************************

% [ ]
disp('Test 21a')
% Comments
%  Test for rangeIx <> 1.

% Testing
  theta   = d2r([10 -40]'); % Target angles.
  phi     = zeros(size(theta));  % Target angles.
  SNR     = [0]'* ones(size(theta));
  alpha   = d2r([0]')* ones(size(theta));% Start phases of the target signals.
  dalpha  = d2r([60 -100]');  % A constant phase shift between snapshots.
  dist    = [Inf] * ones(size(theta));% Distances to the sources.
  PRF     = 8e3;
  lambda  = 0.1;
  noPulses    = 16;
  noRangeBins = 25;
  %noTries    = 1;
  beampos     = d2r(-60:10:60);  % Do conventional beamforming in these dir:s.
  ant = defant('isotropULA',[12, 0.45*lambda]);
  sig = compsim5(ant, lambda, noPulses, noRangeBins, 'const', [theta, phi, ...
    SNR,   alpha, dalpha,dist], 'nonoise');
  figure, hold on
  splot2(doaspc1('cbf',sig,[],[],[],7));
  splot2(doaspc1('capon',sig,[],[],[],7));
  splot2(doaspc1('music',sig,[],[],[],7,[],MMu));
  splot2(doaspc1('minnorm',sig,[],[],[],7,[],MMu));
  splot2(doaspc1('minnorm2',sig,[],[],[],7,[],MMu));
% Expected result :
%  All graphs should look normal.
%  Printed on screen (if this statement is on a comment line in ecorrm):
%       rangeIx=7, trialIx=1. No other value of rangeIx
%  and trialIx.
% Real result :





elseif (testnr==25)
% *****************************************************************************
% [ ]  : Test 25
% Sign:     Datum:
%
% Test of conventional beamforming.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 25a')
% Comments
  lambda = 0.03;        % wavelength.
  D      = 0.45*lambda; % Element separation.
  T      = 24;       	% Number of snapshots.
  K      = 12;       	% Number of digital antenna channels.
  theta  = d2r([25 50])';  % Target angles. The number of targets is
            		   %  given by the number of target angles.
  phi = zeros(size(theta));   	% Target angles.
  SNR = [10 5]';     		% Signal to noise ratio in dB at each
            			%  antenna element!?!
  alpha  = d2r([0 16])';     	% Start phases of the target signals.
  dalpha= d2r([34 -13])';  	% A constant phase shift between snapshots.
            			%  Means targets movements at constant velocity.
  dist=Inf*ones(size(theta)); 	% Distances to the sources.
  tgtModel        = 'const';  	% Target type to simulate.
  noiseModel      = 'rndn';   	% Noise type to simulate.
  MMu = 2;        		% Number of targets that MUSIC believes in.
  ant = defant('isotropULA',[K,D]); % Define the antenna.
  sig = compsim4(ant, lambda, T, tgtModel, ...  % Generate simulated received
    [theta, phi, SNR, alpha, dalpha, dist, ...  % antenna signals.
    eye(size(theta,1))], noiseModel, eye(K));
  figure, hold on
  s1 = sdoaspc('cbf',sig);
  s2 = sdoaspc('cbf',sig,[],'taylor',20);
  s3 = sdoaspc('cbf',sig,[],'taylor',30);
  s4 = sdoaspc('cbf',sig,[],'taylor',40);
  splot2(s1,'',s2,'',s3,'',s4)
  legend('uniform','tayl20','tayl30','tayl40')

% Expected result :
%  There should be two peaks in each graph.
%  The side lobe level should decrease with each additional graph.
%  Ideally (with only one target) the side lobe level should be 13dB,
%  20dB, 30dB and 40dB.
% Real result :





elseif (testnr==26)
% *****************************************************************************
% [ ]  : Test 26
% Sign:     Datum:
%
% Test of tapering of antenna pattern.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 26a')
% Comments
  lambda = 0.03;     % wavelength.
  D   = 0.45*lambda;    % Element separation.
  T   = 24;       % Number of snapshots.
  K   = 12;       % Number of digital antenna channels.
  ant = defant('isotropULA',[K,D]); % Define the antenna.

  figure,pantpat2(ant,'uniform',[],[],[],[],lambda);
  figure,pantpat2(ant,'taylor',20,[],[],[],lambda);
  figure,pantpat2(ant,'taylor',30,[],[],[],lambda);
  figure,pantpat2(ant,'taylor',40,[],[],[],lambda);
  legend('uniform','tayl20','tayl30','tayl40')

% Expected result :
%  The side lobe level should decrease with each additional graph.
%  Ideally the side lobe level should be 13dB,
%  20dB, 30dB and 40dB.
% Real result :





elseif (testnr==40)
% *****************************************************************************
% [ ]  : Test 40
% Sign:     Datum:
%
% A simple standard test of paramtric DOA esimation after modifications.
%
% The aim of this test is to discover run-time errors and large
% calculation errors, not to check that the result is right.
%
% Trying to test a large part of DBT.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 40a')
% Comments
%   Test of all parametric DOA estimation methods for run-time errors
%   using sdoapar.
  %more off
  global thSign;
  load tdbt20
  load tdbt40
  ldoa1 = doa1;
  ldoa2 = doa2;
  ldoa3 = doa3;
  ldoa4 = doa4;
  ldoa5 = doa5;
  ldoa6 = doa6;
  ldoa7 = doa7;

  doa1 = sdoapar1('dml',sig, d2r([26 39]));
  doa2 = sdoapar1('sml',sig, d2r([26 39]));
  doa3 = sdoapar1('ptmf',sig, d2r([26 39]),1e-4);
  [doa3, sHat, Q, doaHatAllIt]  = sdoapar1('ptmf',sig, d2r([26 39]),1e-4);
  [doa4, dummy] = sdoapar1('wsf',sig, d2r([26 39]));
  doa5 = sdoapar1('ssf',sig, d2r([26 39]));
  doa6 = sdoapar1('rmusic',sig, 2);
  doa7 = sdoapar1('esprit',sig, 2);
  fprintf('DML: '),pdoapar(doa1)
  fprintf('SML: '),pdoapar(doa2)
  fprintf('PTMF: '),pdoapar(doa3)
  fprintf('WSF: '),pdoapar(doa4)
  fprintf('SSF: '),pdoapar(doa5)
  fprintf('Root Music: '),pdoapar(doa6)
  fprintf('Esprit: '),pdoapar(doa7)
  %save tdbt40 doa1 doa2 doa3 doa4 doa5 doa6 doa7

  testVar = (sum(((ldoa1)-(doa1))) + ...
  sum(((ldoa2)-(doa2))) + ...
  sum(((ldoa3)-(doa3))) + ...
  sum(((ldoa4)-(doa4))) + ...
  sum(((ldoa5)-(doa5))) + ...
  sum(((ldoa6)-(doa6))) + ...
  sum(((ldoa7)-(doa7))) );
  %limit = eps;    	% Ok on magic and curare.
  limit = 8.8e-10;	% Needed for hawk.
  if ( abs(testVar) > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if

  if (0) % This code can be used if doapar1 is used instead of sdoapar1.
  if ( abs((sum(ldoa1.doa-doa1.doa) + ...
  sum(ldoa2.doa-doa2.doa) + ...
  sum(ldoa3.doa-doa3.doa) + ...
  sum(ldoa4.doa-doa4.doa) + ...
  sum(ldoa5.doa-doa5.doa) + ...
  sum(ldoa6.doa-doa6.doa) + ...
  sum(ldoa7.doa-doa7.doa)) ) > eps)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
  end%if (0)

% Expected result :
%  The estimated DOA:s should be near 25 and 40 degrees.
%  No error message.
% Real result :





elseif (testnr==50)
% *****************************************************************************
% [ ]  : Test 50
% Sign:     Datum:
%
% Test of the AIMT experimental antenna with different choices of
% calibration compensation (on the steering vector or on
% the signals).
% One spectral DOA estimation method is used.
% The resulting DOA-spectra is checked to be the same as before.
% They are not checked to be right. This test is useful to run after
% changes in the code have been made.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 50a')
% Comments
dbcfile = 'dbtex.dbc';
dbsfile = 'dbtex.dbs';
noPeaks = 3;
doas = d2r(-30:0.5:30);
measNo = 1;

ant = defant('expAnt');
setcal1('wctab',dbcfile)
sig = expsig1(ant,dbsfile,measNo);

load tdbt15
ls1=s1;
ls2=s2;
ls3=s3;
ls4=s4;
figure;

sig1 = sigcomp2(sig,dbcfile,'nocomp',[],'nocomp',0);
R1 = ecorrm(sig1);
setcal1('wctab',[],'nearfldcomp')
s1=sdoaspc('music',R1,doas,noPeaks);
splot2(s1,'  y')
r2d(doapeak(s1,'amir',noPeaks))

sig2 = sigcomp2(sig,dbcfile,'Ccmp',[],'nearfldcomp',0);
R2 = ecorrm(sig2);
setcal1('nocomp',[],'nocomp')
s2=sdoaspc('music',R2,doas,noPeaks);
splot2(s2,'  b')
r2d(doapeak(s2,'amir',noPeaks))

sig3 = sigcomp2(sig,dbcfile,'Ccmp',[],'nocomp',0);
R3 = ecorrm(sig3);
setcal1('nocomp',[],'nearfldcomp')
s3=sdoaspc('music',R3,doas,noPeaks);
splot2(s3,'  c')
r2d(doapeak(s3,'amir',noPeaks))

sig4 = sigcomp2(sig,dbcfile,'nocomp',[],'nearfldcomp',0);
R4 = ecorrm(sig4);
setcal1('wctab',[],'nocomp')
s4=sdoaspc('music',R4,doas,noPeaks);
splot2(s4,'  r')
r2d(doapeak(s4,'amir',noPeaks))

legend('sig:nocomp,nocomp.', 'sig:Ccmp,nearfld.','sig:Ccmp,nocomp.','sig:nocomp,nearfld.')

%save tdbt15 s1 s2 s3 s4

difference = abs((sum(ls1.specSmpl-s1.specSmpl) + ...
  sum(ls2.specSmpl-s2.specSmpl) + ...
  sum(ls3.specSmpl-s3.specSmpl) + ...
  sum(ls4.specSmpl-s4.specSmpl) ));
%limit = eps;   % Ok on magic and curare.
limit = 9.6e-9;	% Needed for hawk.
if (difference  > limit)
  error('DBT-Error: Difference to large.')
else
  disp('  Test OK.')
end%if

% Expected result :
%  The four graphs shall "look good" with three peaks each at angles
%  approx. -4, 0 and 1.5 degrees. The numerical values returned for
%  the four cases should also be -4, 0 and 1.5 degrees.
%  No error messages.
% Real result :





elseif (testnr==51)
% *****************************************************************************
% [ ]  : Test 51
% Sign:     Datum:
%
% Test of the AIMT experimental antenna with different choices of
% calibration compensation (wctab, Ccmp or wcmedel) on the STEERING VECTOR.
% One spectral DOA estimation method is used.
% The resulting DOA-spectra is checked to be the same as before.
% They are not checked to be right. This test is useful to run after
% changes in the code have been made.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 51a')
% Comments
%   The most of the following code is currently (R1-6-3) the same as in
%   dbtex9.m.
  MMu = 3;        % Number of targets that MUSIC believes in.
    % The true number is 3.
  ant = defant('expAnt');
  sig = expsig1(ant,'dbtex.dbs',1);

  load tdbt51
  ls1=s1;
  ls2=s2;
  ls3=s3;

  R = ecorrm(sig);
  setcal1('wctab','dbtex.dbc')
  s1 = sdoaspc('music',R,d2r(-30:0.25:30),MMu);
  setcal1('Ccmp')
  s2 = sdoaspc('music',R,d2r(-30:0.25:30),MMu);
  setcal1('wcmedel')
  s3 = sdoaspc('music',R,d2r(-30:0.25:30),MMu);

  hold on
  splot2(s1,'  y')
  splot2(s2, '  m')
  splot2(s3,'  c')
  legend('wctab','Ccmp','wcmedel')
  difference = abs( sum(ls1.specSmpl-s1.specSmpl) + ...
    sum(ls2.specSmpl-s2.specSmpl) + ...
    sum(ls3.specSmpl-s3.specSmpl) )
  %limit = eps;   % Ok on magic and curare.
  limit = 7.0e-9;	% Needed for hawk.
  %save tdbt51 s1 s2 s3

  if ( difference  > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if

% Expected result :
%  No error message.
% Real result :




elseif (testnr==52)
% *****************************************************************************
% [ ]  : Test 52
% Sign:     Datum:
%
% Test of the AIMT experimental antenna with different choices of
% calibration compensation on the SIGNALS.
% One spectral DOA estimation method is used.
% The resulting DOA-spectra is checked to be the same as before.
% They are not checked to be right. This test is useful to run after
% changes in the code have been made.
%
% *****************************************************************************

% Not implemented yet.




elseif (testnr==60)
% *****************************************************************************
% [ ]  : Test 60
% Sign:     Datum:
%
% Test of different antenna types and steering matrix calculations.
%
% The results are checked to be the same as before.
% They are not checked to be right. This test is useful to run after
% changes in the code have been made.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 60a')
% Comments
%  'isotropULA'
  lambda = 1.37;
  distElem = lambda/2;
  noElem = 37;
  beamSpaceTrans = ones(noElem,1);
  doas = d2r([-180 -156 -90 -67.45 -27.234 -1 0 1 pi 43.43 90 134 180]);
% Isotrop ULA using recursive definition:
  elem = defant('isotropElem');
  ant1  = defant('ULA', [noElem, distElem], elem, beamSpaceTrans);
% Isotrop ULA using special implementation:
  ant2 = defant('isotropULA', [noElem, distElem]);
  a1 = spastemat(ant1, doas, lambda);
  a2 = spastemat(ant2, doas, lambda);
  %max(max(abs(a1-a2)));
% Expected result :
  disp(['Expected value < '])
  disp(eps)
% Real result :
  disp(['Real value = ' ])
  disp(max(max(abs(a1-a2))))




% [ ]
disp('Test 60b')
% Comments
%	'isotropElem'
  clear all
  ant1 = defant('isotropElem');
  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];

if (0)	% 1 = generate test data. 0 = Use test data.
  A1b = spastemat(ant1,doas,lambda,focusDist);
  save tdbt60 A1b -APPEND
else
  load tdbt60
  A1 = A1b;
  A2 = spastemat(ant1,doas,lambda,focusDist);
  extraRelTol = 2; % Allow for some extra tolerance because of many
    % floating point operations and use of complex numbers (2).
  limit = extraRelTol * 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)));
  if (difference > limit)
    error('Difference to large.')
    %disp('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
end%if(0)
% Expected result :
%	No error message.
% Real result :



% [ ]
disp('Test 60c')
% Comments
%	'pattFuncElem'
  clear all
  ant1 = defant('pattFuncElem', 'cos(x(1,:)).^2');
  doas = d2r([-180, -179, -135, -127, -90, -39, 0, ...
    21, 22, 45, 78, 90, 167 ,180]);
  lambda = 4.67;
  focusDist = [];

if (0)	% 1 = generate test data. 0 = Use test data.
  A1c = spastemat(ant1,doas,lambda,focusDist);
  save tdbt60 A1c -APPEND
else
  load tdbt60
  A1 = A1c;
  A2 = spastemat(ant1,doas,lambda,focusDist);
  extraRelTol = 2; % Allow for some extra tolerance because of many
    % floating point operations and use of complex numbers (2).
  limit = extraRelTol * 0.5*size(A1,1)*size(A1,2)*eps;
  difference = sum(sum(abs(A1-A2)));
  if (difference > limit)
    error('Difference to large.')
    %disp('Difference to large.')
  else
    disp('  Test Ok.')
  end%if
end%if(0)
% Expected result :
%	No error message.
% Real result :



% [ ]


disp('Test 60d')
% Comments
%	'aimtEx'

% Expected result :
% Real result :



% [ ]
disp('Test 60e')
% Comments
%	'expAnt'

% Expected result :
% Real result :


if(0)
% [ ]
disp('Test 60ff: Comparison between iso2DArr and LA steering vector')
% Comments
%  Test of 'iso2DArr'
%       Implementation of the test is not finnished.
  lambda = 1.37;
  distElem = lambda/2;
  noElem = 37;
  beamSpaceTrans = ones(noElem,1);
  doas = d2r([-180 -156 -90 -67.45 -27.234 -1 0 1 pi 43.43 90 134 180]);
  elementPositions = [ ; zeros(1,noElem)];
% Antenna type 'LA':
  elem = defant('isotropElem');
  LAant = defant('LA',elementPositions(1,:).',[],elem);
% Antenna type 'iso2DArr':
  ant2 = defant('');

% Expected result :
% Real result :


% Expected result :
% Real result :


% ...
end%if(0)




elseif (testnr==101)
% *****************************************************************************
% [ ]  : Test 101
% Sign:   Datum:
%
% Test of pulse code modulations.
%
% *****************************************************************************
% Comments

% [ ]
% Comments
% Test of Frank Codes.
disp('Test 101a')
  clear all
  code16Calc = getmod('frank',4);
  code16Expect = [1, 1, 1, 1,   1, i, -1, -i,   1, -1, 1, -1,   1 -i, -1, i].';
  extraRelTol = 2;  % Allow for some extra tolerance because of many
    % floating point operations.
  limit = extraRelTol * 0.5 * size(code16Calc,1)*size(code16Expect,2)*eps;
  difference = sum(sum(abs(code16Calc-code16Expect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of Frank Codes.
disp('Test 101b')
  clear all
  codeCalc = getmod('frank',1);
  codeExpect = 1;
  extraRelTol = 2;  % Allow for some extra tolerance because of many
    % floating point operations.
  limit = extraRelTol * 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of Barker Codes.
disp('Test 101c')
  clear all
  codeCalc = getmod('barker','4b');
  codeExpect = [1, 1, 1, -1].';
  limit = 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of Barker Codes.
disp('Test 101d')
  clear all
  codeCalc = getmod('barker','13');
  codeExpect = [1, 1, 1, 1, 1, -1, -1, 1, 1, -1, 1, -1, 1].';
  limit = 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of a phaseshift of pi radians of the code.
disp('Test 101e')
  clear all
  codeCalc = getmod('barker','11',1);
  codeExpect = -1*[1,1,1,-1,-1,-1,1,-1,-1,1,-1].';
  limit = 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of a fliparound (permutation) of the code.
disp('Test 101f')
  clear all
  codeOrder = 8; % The length of the Frank code is codeOrder^2.
  codeCalc = getmod('frank',8,[],1);
  codeExpect = exp(i*2*pi*(1/codeOrder)*([1:codeOrder]-1).'*([1:codeOrder]-1));
    % A Frank code.
  codeExpect = codeExpect(:);
  codeExpect = flipud(codeExpect);
  limit = 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of rectangular code.
disp('Test 101g')
  clear all
  codeCalc = getmod('rect',7,1,1);
  codeExpect = -1*[1 1 1 1 1 1 1].';
  limit = 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :


% [ ]
% Comments
% Test of a Chirp (linear FM) code.
disp('Test 101h')
  clear all
  len = 29;
  maxFDev = 1e6;
  fSamp = 3.225e6;
  codeCalc = getmod('chirp',[maxFDev,fSamp,len]);
  param = maxFDev * fSamp / len;
  codeExpect = exp(i*pi*param*([1:len]*(1/fSamp)).^2).';
  extraRelTol = 7 *2; % Allow for some extra tolerance because of many
    % floating point operations (7) and use of complex numbers (2).
  limit = extraRelTol* 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :



% [ ]
% Comments
% Test 2 of a Chirp (linear FM) code.
disp('Test 101i')
  clear all
  len = 1024;		% Number of samples.
  maxFDev = 500;	% Maximum frequency deviation [Hz].
  fSamp = 2000;		% Sampling frequency [Hz].
  Ts = 1/fSamp;		% Sampling time [s].
  t = linspace(0, Ts*len, len);
  codeCalc = getmod('chirp',[maxFDev,fSamp,len]);
  realSig = real(codeCalc);
  figure,plot(t,realSig)
  title('Time signal')
  xlabel('Time [s]')

  %freqEst = 1/(2*pi) * diff(unwrap(angle(codeCalc))) * fSamp;	% [Hz]
  freqEst = estlocalfreq(codeCalc, fSamp);
  figure, plot(t,[0;freqEst])
  title('Frequency estimation')
  xlabel('Time [s]')
  ylabel('Frequency [Hz]')

  spect = fftshift(fft(realSig));
  f = linspace(-fSamp/2,fSamp/2,len);
  figure,plot(f,(spect))
  title('Frequency spectrum')
  xlabel('Frequency [Hz]')

% Expected result :
% The frequency of the time signal shall increase.
% The estimation of frequency shall be a straight line with upward
% direction an through origo (from 0 Hz to 500 Hz).
% The frequency spectrum shall reside mainly within +- 500 Hz.
% Real result :



% [ ]
disp('Test 101aa')
% Expected result :
% Real result :



elseif (testnr==102)
% *****************************************************************************
% [ ]  : Test 102
% Sign:   Datum:
%
% Test of exchange of calls to getm, getm2, getm3 and setm with direct
% indexing in Matlab 5.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 102a')
% Comments
%   Comparision of setm and Matlab 5 direct indexing.
  clear A B
  A(:,:,1) = [1 2 3; 4 5 6];
  A(:,:,2) = [7 8 9; 10 11 12];
  B = A;
  A(1,':',2) = [20 21 22];
  B = setm(B, [20 21 22], 1,':',2);
  %limit = 0.5*prod(size(A))*eps;
  if (~all(all(all((A == B),1),2),3))
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%   No error message.
% Real result :

% [ ]
disp('Test 102b')
% Comments
%   Comparision of setm and Matlab 5 direct indexing.
  % [3 2 2 4]
  clear A B
  A(:,:,1,4) = [1 2; 4 5; 7 8];
  A(:,:,2,4) = [10 11; 13 14; 16 17];
  B = A;
  A(2,':',':',4) = [20 21; 23 24];
  B = setm(B, [20 21; 23 24], 2,':',':',4);
  if (~all(all(all(all((A == B),1),2),3),4))
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
%   No error message.
% Real result :


if (0)
% [ ]
disp('Test 102c')
% Comments
%   Comparision of setm and Matlab 5 direct indexing.


  if (~all(all(all(all((A == B),1),2),3),4))
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if

% Expected result :
%   No error message.
% Real result :
end%if (0)



elseif (testnr==103)
% *****************************************************************************
% [ ]  : Test 103
% Sign:   Datum:
%
% Test of function "sigsplitdim".
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 103a')
% Comments
%   Test of function "sigsplitdim"
  clear s s2
  s = RxRadarSigT;
  s.signals = ones([4 6 8 1 1]);
  s2 = sigsplitdim(s,1,2,4);
  size(s2.signals)
% Expected result :
%   2 6 8 2
%   No error message.
% Real result :


% [ ]
disp('Test 103b')
% Comments
%   Test of function "sigsplitdim"
  clear s s2
  s = RxRadarSigT;
  s.signals = ones([4 6 8 1 1 1]);
  s2 = sigsplitdim(s,3,4,5);
  size(s2.signals)

% Expected result :
%   4 6 4  1 2
%   No error message.
% Real result :


% [ ]
disp('Test 103c')
% Comments
%   Test of function "sigsplitdim"
  clear s s2
  s = RxRadarSigT;
  s.signals = ones([4 6 8 1 1 1]);
  s2 = sigsplitdim(s,2,2,6);
  size(s2.signals)

% Expected result :
%   4 2 8 1 1 3
%   No error message.
% Real result :



elseif (testnr==120)
% *****************************************************************************
% [ ]  : Test 120
% Sign:   Datum:
%
% Test of wide band signal simulation.
%
% *****************************************************************************
% Comments

% [ ]
% Comments
% Test of wide band signal simulation.
  disp('Test 120a')
  clear all
  propSpeed = speedoflight;		% [m/s].
  carrierFreq = 3e9		        % [Hz].
  lambda = propSpeed / carrierFreq;     % Wavelength [m].
  distElem 	= 0.45*lambda;		% Element separation.
  noChan 	= 12;			% Number of digital antenna channels.
  antenna = defant('isotropULA',[noChan,distElem]);	% Define the antenna.
  bandwidth = carrierFreq*0.9		% [Hz].
  noTimes = 16;				% Number of time samples.
  noTrials = 1;
  noSrc = 1;
  srcSignals = [ones(1,noTimes/2), 2*ones(1,(noTimes/2))];
  srcSignals(1) = srcSignals(1) + j*eps;
  srcDoas = d2r([67]);		% Target angles [radians]. The number of
				%   targets is
				%   given by the number of target angles.
  srcPowers = ones(noSrc,1);
  srcCorr = [];
  orthSig = [];
  %[sigOut, sourceSigTime, noiseSigTime] = simwideband(srcType, antenna,
  %  carrierFreq, bandwidth, noTimes, noTrials, srcSignals, srcDoas,
  %  srcPowers, srcCorr, orthSig, propSpeed)
  sig = simwideband('det',antenna,carrierFreq, bandwidth, noTimes, ...
    noTrials, srcSignals, srcDoas, srcPowers, {srcCorr}, orthSig, propSpeed);
  figure, sigplot2(sig,':',1,':',...
     {'pulAxis', sig.waveform.sampleTime*(sig.pulIx-1)/1e-12})
  ylabel('Time [ps]')
  irot
  %printfm simwide1a.ps 10 8
% Expected result :
%   Time delay from antenna element m to m+n is equal to
%     tau = (n*0.45/carrierFreq)*sin(srcDoas)
%   For srcDoas = 40 degress, tau = n*9.642e10-11 s.
  disp(['Expected delays = ' num2str(((1:(noChan-1))*0.45/carrierFreq)*sin(srcDoas)/1e-12) 'ps'])
% Real result :


% [ ]
% Comments
% Test of wide band signal simulation.
disp('Test 120b')
% Expected result :
% Real result :


% [ ]
% Comments
% Test of wide band signal simulation.
disp('Test 120c')
% Expected result :
% Real result :


if (0)
% [ ]
% Comments
% Test of a Chirp (linear FM) code.
disp('Test 120h')
  clear all
  len = 29;
  maxFDev = 1e6;
  fSamp = 3.225e6;
  codeCalc = getmod('chirp',[maxFDev,fSamp,len]);
  param = maxFDev * fSamp / len;
  codeExpect = exp(i*pi*param*([1:len]*(1/fSamp)).^2).';
  extraRelTol = 7 *2; % Allow for some extra tolerance because of many
    % floating point operations (7) and use of complex numbers (2).
  limit = extraRelTol* 0.5*size(codeCalc,1)*size(codeExpect,2)*eps;
  difference = sum(sum(abs(codeCalc-codeExpect)));
  if (difference > limit)
    error('DBT-Error: Difference to large.')
  else
    disp('  Test Ok.')
  end%if
% Expected result :
% No error message.
% Real result :
end%if (0)



elseif (testnr==130)
% *****************************************************************************
% [ ]  : Test 130
% Sign:   Datum:
%
% Test of range steering matrix calculation.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 130a')
  lambda = 0.1;		% [m]
  noRangeBins = 8;
  noPulses = 2;
  pModulation = [4 3 2].';
  sampleTime = 1e-6;	% [s]
  waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);
  %rangeBinLen = (speedoflight * sampleTime)/2;	% = 149.8962 [m]
  rangeBinLen = getranbinlen(waveform,speedoflight);	% = 149.8962 [m]
    % Max unambiguous range is 8 * 149.8962 = 1199.2 m.
  ranges = 400;		% [m]. Should land up in range bin 3.
  A = ranstemat(waveform, ranges);
% Expected result :
  B = [0 0 4 3 2 0 0 0].';
% Real result :
  limit = 0.5*size(A,1)*size(A,2)*eps;
  difference = sum(sum(abs(A-B)));
  if (difference > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if


% [ ]
disp('Test 130b')
% Several ranges in the same call. First range bin. Last range bin. Exactly in middle of range bin, Exactly at range bin border.
  lambda = 0.1;		% [m]
  noRangeBins = 8;
  noPulses = 2;
  pModulation = [4 3 2].';
  sampleTime = 1e-6;	% [s]
  waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);
  %rangeBinLen = (speedoflight * sampleTime)/2;	% = 149.8962 [m]
  rangeBinLen = getranbinlen(waveform,speedoflight);	% = 149.8962 [m]
    % Max unambiguous range is 8 * 149.8962 = 1199.2 m.
  ranges = [0, 74, 75.1, 150, 290, 323, 890, 1199, 1200, 1050, 1040, 1215];
    % [m]. Start range bins are: 1 1 1 2 2 3 6 8 9 8 7 9.
  A = ranstemat(waveform, ranges);
% Expected result :
  B = [4 3 2 0 0 0 0 0 ; 4 3 2 0 0 0 0 0 ; 4 3 2 0 0 0 0 0; 0 4 3 2 0 0 0 0;...
       0 4 3 2 0 0 0 0 ; 0 0 4 3 2 0 0 0 ; ...
       0 0 0 0 0 4 3 2 ; ...
       3 2 0 0 0 0 0 4 ; 4 3 2 0 0 0 0 0 ; 3 2 0 0 0 0 0 4 ; 2 0 0 0 0 0 4 3;...
       4 3 2 0 0 0 0 0 ].';
% Real result :
  limit = 0.5*size(A,1)*size(A,2)*eps;
  difference = sum(sum(abs(A-A)));
  if (difference > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if



elseif (testnr==131)
% *****************************************************************************
% [ ]  : Test 131
% Sign:   Datum:
%
% Test of space-range steering matrix calculation.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 131a')
% Space parameters
  lambda = 0.1;		% [m]
  noElem = 2;
  distElem = 0.5*lambda;
  antenna = defant('isotropULA',[noElem, distElem]);
  doas = d2r(55);

% Range parameters
  noRangeBins = 6;
  noPulses = 2;
  pModulation = [4 3 2].';
  sampleTime = 1e-6;	% [s]
  waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);
  %rangeBinLen = (speedoflight * sampleTime)/2;	% = 149.8962 [m]
  rangeBinLen = getranbinlen(waveform,speedoflight);	% = 149.8962 [m]
    % Max unambiguous range is 8 * 149.8962 = 1199.2 m.
  ranges = 400;		% [m]. Should land up in range bin 3.

% Steering matrix calculation
  A = sparanstemat({antenna, waveform}, {doas,ranges}, {lambda});
  A.'
% Expected result :
  AExp = [1; -0.84289752545115 + 0.53807412276408i];
  B = [[0 0 ], [0 0 ], 4* AExp.', 3* AExp.', 2* AExp.', [0 0 ]].';
  B.'

% Real result :
  limit = 0.5*size(A,1)*size(A,2)*eps
  difference = sum(sum(abs(A-B)))
  if (difference > limit)
    %error('Difference to large.')
    dbtwarning('Difference to large.')
  else
    disp('  Test Ok.')
  end%if



% [ ]
disp('Test 131b')
% Space parameters
  lambda = 0.1;		% [m]
  noElem = 2;
  distElem = 0.5*lambda;
  antenna = defant('isotropULA',[noElem, distElem]);
  doas = d2r([55, -127, 193]);

% Range parameters
  noRangeBins = 6;
  noPulses = 2;
  pModulation = [4 3 2].';
  sampleTime = 1e-6;	% [s]
  waveform = defwave(lambda, noRangeBins, noPulses, pModulation, sampleTime);
  %rangeBinLen = (speedoflight * sampleTime)/2;	% = 149.8962 [m]
  rangeBinLen = getranbinlen(waveform,speedoflight);	% = 149.8962 [m]
    % Max unambiguous range is 8 * 149.8962 = 1199.2 m.
  ranges = [400, 74];	% [m]. Should land up in range bin 1 and 3.

% Steering matrix calculation
  A = sparanstemat({antenna, waveform}, {doas,ranges}, {lambda});
  A = (abs(A) > 0);
% Expected result :
  % A (6*2, 2*3) = (12,6) matrix with block of size (2,3) and elements 0 and 1.
   B =[	0	0	0	1	1	1 ;
	0	0	0	1	1	1 ;
	0	0	0	1	1	1 ;
	0	0	0	1	1	1 ;
	1	1	1	1	1	1 ;
	1	1	1	1	1	1 ;
	1	1	1	0	0	0 ;
	1	1	1	0	0	0 ;
	1	1	1	0	0	0 ;
	1	1	1	0	0	0 ;
	0	0	0	0	0	0 ;
	0	0	0	0	0	0 ];
	
% Real result :
  limit = 0.5*size(A,1)*size(A,2)*eps;
  difference = sum(sum(abs(A-B)));
  if (difference > limit)
    error('Difference to large.')
  else
    disp('  Test Ok.')
  end%if




elseif (testnr==999)
% *****************************************************************************
% [ ]  : Test 999
% Sign:   Datum:
%
% Template for tests.
%
% *****************************************************************************
% Comments

% [ ]
disp('Test 999a')
% Expected result :
% Real result :

% [ ]
disp('Test 999b')
% Expected result :
% Real result :





else
  disp('Incorrect testnumber.');
end
