function [timeMsg, timeDiv] = crTimeStr(timeInSec)

%CRTIMESTR Construct a time-string used by the functions "eetimeloop" and "eetimeend".
%  
%--------
%Synopsis:
%  [timeMsg, timeDiv] = crTimeStr(timeInSec)
%
%Description:
%  Construct a time-string. This function is used by the functions
%  "eetimeloop" and "eetimeend".
%
%Output and Input:
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  eetimeloop, eetimeend


%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 000306 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:40:09 $ $Author: svabj $.
%  $Revision: 1.2 $
% *****************************************************************************


if timeInSec/3600 < 1   % Less then one hour
   if timeInSec/60 < 1  % Less then one minute
      timeDiv = 1;               % Time in seconds
      timeMsg = 'sec.';
   else
      timeDiv = 60;              % Time in minutes
      timeMsg = 'min.';
   end%if
else
   timeDiv = 3600;               % Time in hours
   timeMsg = 'hour.';
end%if

%endfunction crTimeStr
