function B = dftopm(N,M)

%DFTOPM generates a DFT operator matrix B such that the discrete 1D-Fourier
%  transform of a spatial vector x is given by X = B*x. The DFT is defined 
%  in the same way as the Matlab standard fft.
% 
%  B = dftopm(N,M)
%  Size of operator matrix (M x N).
%  N = # spatial samples.
%  M = # frequency samples.
%
%  The inverse discrete Fourier transform matrix is 
%  Bi = conj(dftopm(N,N))/N
%
%See Also
%  dftopm2d, dftmtx

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : xxxxx Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:40:09 $ $Author: svabj $.
%  $Revision: 1.4 $
% *****************************************************************************

if (nargin < 2)
  M = N;
end;  

B = exp(-i*2*pi*(1/M)*(0:M-1).' * (0:N-1));
