function B = dftopm2d(K,N)

%DFTOPM2D generates a DFT operator matrix B such that the discrete 2D-Fourier
%  transform of a spatial matrix x is given by X = reshape(B*x(:),M,M).
%  The DFT is defined in the same way as the Matlab standard fft2.
% 
%  B = dftopm2d(N,M)B
%  K = # spatial samples. x is (K x K).
%  N = # frequency samples. X is (N x N).
%
%See Also
%  dftopm, dftmtx

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : xxxxxx Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:40:10 $ $Author: svabj $.
%  $Revision: 1.3 $
% *****************************************************************************

if (nargin < 2)
  N = K;
end;  

B1=dftopm(K,N);
B = kron(B1,B1);
