function eeTimeVarOut = eetimeend(eeTimeVarIn)

%EETIMEEND End estimation of execution time.
%
%--------
%Synopsis:
%  eeTimeVarOut = eetimeend(eeTimeVarIn)
%
%Description:
%  End estimation of execution time.
%  For the use of this function see the help text of function "eetimebegin".
%
%Output and Input:
%  eeTimeVarOut (): Same as "eeTimeVarIn" but as output.
%  eeTimeVarIn (): A structure variable containing information for the 
%    functions "eetimebegin", "eetimepreloop", "eetimeloop" and "eetimeend"
%    and it should not be manipulated directly by the user.
%    This variable is here the output of the function "eetimeloop".
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  eetimebegin, eetimepreloop, eetimeloop, radio/wideex3


%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 990222 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:40:12 $ $Author: svabj $.
%  $Revision: 1.5 $
% *****************************************************************************


if (~isfield(eeTimeVarIn,'loop'))
  error('The function "eetimebegin" must be called before "eetimepreloop".')
end%if

% **************** Display final execution time ****************

eeTimeVarOut = eeTimeVarIn;

eeTimeVarOut.elapTime = etime(clock,eeTimeVarIn.startClock);

%fprintf('Total execution time was %d hours.\n',eeTimeVarOut.elapTime/3600)

[timeMsg, timeDiv] = crTimeStr(eeTimeVarOut.elapTime);
fprintf(['Total execution time was %.1f ', timeMsg, ' \n'], ...
  eeTimeVarOut.elapTime/timeDiv)
