function Y = weightcols(X,weights)

%WEIGHTCOLS Weights the columns of a matrix.
%
%--------
%Synopsis:
%  Y = weightcols(X,weights)
%
%Description:
%  Weights each column of the two-dimensional matrix "X" with a weight
%  from "weights". The same weight is applied to all rows of the same column. 
%  This is equal to
%    Y = X*diag(weights)
%
%Output and Input:
%  Y (CxMatrixT): The output matrix.
%  X (CxMatrixT): The matrix, whose columns to weight.
%  weights (CxVectorT): The weights to use. Length of this vector must be
%    equal to the number of columns in "X".
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Examples:
%
%Software Quality:
%  (About what is done to ascertain software quality. What tests are done.)
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  weightrows

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 981126 Svante Bjrklund (svabj).
%  Latest change: $Date: 2001/08/31 15:06:35 $ $Author: svabj $.
%  $Revision: 1.7 $
% *****************************************************************************


if (length(weights)>1000)
  Y = full(X*(diag(sparse(weights)))); 
else
  Y = full(X*sparse(diag(weights)));
end%if
   
