function  N = vecnorm2(vectors)

%VECNORM2 Computes the euclidean norm (2-norm) of several vectors.
%
%--------
%Synopsis:
%  N = vecnorm2(vectors)
%
%Description:
%  Computes the euclidean norm (2-norm) of several vectors.
%
%Output and Input:
%  N (RealVectorT.'): The calculated norms as a row vector.
%  vectors (RealMatrixT): The vectors to calculate the norm for. Several
%    column vectors are collected in a matrix. 
%
%--------
%Notations:
%  Data type names are shown in parentheses and they start with a capital
%  letter and end with a capital T. Data type definitions can be found in [1]
%  or by "help dbtdata".
%  [D] = This parameter can be omitted and then a default value is used.
%  When the [D]-input parameter is not the last used in the call, it must be
%  given the value [], i.e. an empty matrix.
%  ... = There can be more parameters. They are explained under respective
%  metod or choice.
%
%Known Bugs:
%
%References:
%  [1]: Bjrklund S.: "DBT, A MATLAB Toolbox for Radar Signal Processing.
%    Reference Guide", FOA-D--9x-00xxx-408--SE, To be published.
%
%See Also:
%  norm

%   *  DBT, A Matlab Toolbox for Radar Signal Processing  *
% (c) FOA 1994-2000. See the file dbtright.m for copyright notice.
%
%  Start        : 980515 Svante Bjrklund (svabj).
%  Latest change: $Date: 2000/10/16 15:22:19 $ $Author: svabj $.
%  $Revision: 1.5 $
% *****************************************************************************

N = sqrt(sum(abs(vectors).^2));
